.materialize-red.lighten-5 {
  background-color: #fdeaeb !important; }

.materialize-red-text.text-lighten-5 {
  color: #fdeaeb !important; }

.materialize-red.lighten-4 {
  background-color: #f8c1c3 !important; }

.materialize-red-text.text-lighten-4 {
  color: #f8c1c3 !important; }

.materialize-red.lighten-3 {
  background-color: #f3989b !important; }

.materialize-red-text.text-lighten-3 {
  color: #f3989b !important; }

.materialize-red.lighten-2 {
  background-color: #ee6e73 !important; }

.materialize-red-text.text-lighten-2 {
  color: #ee6e73 !important; }

.materialize-red.lighten-1 {
  background-color: #ea454b !important; }

.materialize-red-text.text-lighten-1 {
  color: #ea454b !important; }

.materialize-red {
  background-color: #e51c23 !important; }

.materialize-red-text {
  color: #e51c23 !important; }

.materialize-red.darken-1 {
  background-color: #d0181e !important; }

.materialize-red-text.text-darken-1 {
  color: #d0181e !important; }

.materialize-red.darken-2 {
  background-color: #b9151b !important; }

.materialize-red-text.text-darken-2 {
  color: #b9151b !important; }

.materialize-red.darken-3 {
  background-color: #a21318 !important; }

.materialize-red-text.text-darken-3 {
  color: #a21318 !important; }

.materialize-red.darken-4 {
  background-color: #8b1014 !important; }

.materialize-red-text.text-darken-4 {
  color: #8b1014 !important; }

.red.lighten-5 {
  background-color: #FFEBEE !important; }

.red-text.text-lighten-5 {
  color: #FFEBEE !important; }

.red.lighten-4 {
  background-color: #FFCDD2 !important; }

.red-text.text-lighten-4 {
  color: #FFCDD2 !important; }

.red.lighten-3 {
  background-color: #EF9A9A !important; }

.red-text.text-lighten-3 {
  color: #EF9A9A !important; }

.red.lighten-2 {
  background-color: #E57373 !important; }

.red-text.text-lighten-2 {
  color: #E57373 !important; }

.red.lighten-1 {
  background-color: #EF5350 !important; }

.red-text.text-lighten-1 {
  color: #EF5350 !important; }

.red {
  background-color: #F44336 !important; }

.red-text {
  color: #F44336 !important; }

.red.darken-1 {
  background-color: #E53935 !important; }

.red-text.text-darken-1 {
  color: #E53935 !important; }

.red.darken-2 {
  background-color: #D32F2F !important; }

.red-text.text-darken-2 {
  color: #D32F2F !important; }

.red.darken-3 {
  background-color: #C62828 !important; }

.red-text.text-darken-3 {
  color: #C62828 !important; }

.red.darken-4 {
  background-color: #B71C1C !important; }

.red-text.text-darken-4 {
  color: #B71C1C !important; }

.red.accent-1 {
  background-color: #FF8A80 !important; }

.red-text.text-accent-1 {
  color: #FF8A80 !important; }

.red.accent-2 {
  background-color: #FF5252 !important; }

.red-text.text-accent-2 {
  color: #FF5252 !important; }

.red.accent-3 {
  background-color: #FF1744 !important; }

.red-text.text-accent-3 {
  color: #FF1744 !important; }

.red.accent-4 {
  background-color: #D50000 !important; }

.red-text.text-accent-4 {
  color: #D50000 !important; }

.pink.lighten-5 {
  background-color: #fce4ec !important; }

.pink-text.text-lighten-5 {
  color: #fce4ec !important; }

.pink.lighten-4 {
  background-color: #f8bbd0 !important; }

.pink-text.text-lighten-4 {
  color: #f8bbd0 !important; }

.pink.lighten-3 {
  background-color: #f48fb1 !important; }

.pink-text.text-lighten-3 {
  color: #f48fb1 !important; }

.pink.lighten-2 {
  background-color: #f06292 !important; }

.pink-text.text-lighten-2 {
  color: #f06292 !important; }

.pink.lighten-1 {
  background-color: #ec407a !important; }

.pink-text.text-lighten-1 {
  color: #ec407a !important; }

.pink {
  background-color: #e91e63 !important; }

.pink-text {
  color: #e91e63 !important; }

.pink.darken-1 {
  background-color: #d81b60 !important; }

.pink-text.text-darken-1 {
  color: #d81b60 !important; }

.pink.darken-2 {
  background-color: #c2185b !important; }

.pink-text.text-darken-2 {
  color: #c2185b !important; }

.pink.darken-3 {
  background-color: #ad1457 !important; }

.pink-text.text-darken-3 {
  color: #ad1457 !important; }

.pink.darken-4 {
  background-color: #880e4f !important; }

.pink-text.text-darken-4 {
  color: #880e4f !important; }

.pink.accent-1 {
  background-color: #ff80ab !important; }

.pink-text.text-accent-1 {
  color: #ff80ab !important; }

.pink.accent-2 {
  background-color: #ff4081 !important; }

.pink-text.text-accent-2 {
  color: #ff4081 !important; }

.pink.accent-3 {
  background-color: #f50057 !important; }

.pink-text.text-accent-3 {
  color: #f50057 !important; }

.pink.accent-4 {
  background-color: #c51162 !important; }

.pink-text.text-accent-4 {
  color: #c51162 !important; }

.purple.lighten-5 {
  background-color: #f3e5f5 !important; }

.purple-text.text-lighten-5 {
  color: #f3e5f5 !important; }

.purple.lighten-4 {
  background-color: #e1bee7 !important; }

.purple-text.text-lighten-4 {
  color: #e1bee7 !important; }

.purple.lighten-3 {
  background-color: #ce93d8 !important; }

.purple-text.text-lighten-3 {
  color: #ce93d8 !important; }

.purple.lighten-2 {
  background-color: #ba68c8 !important; }

.purple-text.text-lighten-2 {
  color: #ba68c8 !important; }

.purple.lighten-1 {
  background-color: #ab47bc !important; }

.purple-text.text-lighten-1 {
  color: #ab47bc !important; }

.purple {
  background-color: #9c27b0 !important; }

.purple-text {
  color: #9c27b0 !important; }

.purple.darken-1 {
  background-color: #8e24aa !important; }

.purple-text.text-darken-1 {
  color: #8e24aa !important; }

.purple.darken-2 {
  background-color: #7b1fa2 !important; }

.purple-text.text-darken-2 {
  color: #7b1fa2 !important; }

.purple.darken-3 {
  background-color: #6a1b9a !important; }

.purple-text.text-darken-3 {
  color: #6a1b9a !important; }

.purple.darken-4 {
  background-color: #4a148c !important; }

.purple-text.text-darken-4 {
  color: #4a148c !important; }

.purple.accent-1 {
  background-color: #ea80fc !important; }

.purple-text.text-accent-1 {
  color: #ea80fc !important; }

.purple.accent-2 {
  background-color: #e040fb !important; }

.purple-text.text-accent-2 {
  color: #e040fb !important; }

.purple.accent-3 {
  background-color: #d500f9 !important; }

.purple-text.text-accent-3 {
  color: #d500f9 !important; }

.purple.accent-4 {
  background-color: #aa00ff !important; }

.purple-text.text-accent-4 {
  color: #aa00ff !important; }

.deep-purple.lighten-5 {
  background-color: #ede7f6 !important; }

.deep-purple-text.text-lighten-5 {
  color: #ede7f6 !important; }

.deep-purple.lighten-4 {
  background-color: #d1c4e9 !important; }

.deep-purple-text.text-lighten-4 {
  color: #d1c4e9 !important; }

.deep-purple.lighten-3 {
  background-color: #b39ddb !important; }

.deep-purple-text.text-lighten-3 {
  color: #b39ddb !important; }

.deep-purple.lighten-2 {
  background-color: #9575cd !important; }

.deep-purple-text.text-lighten-2 {
  color: #9575cd !important; }

.deep-purple.lighten-1 {
  background-color: #7e57c2 !important; }

.deep-purple-text.text-lighten-1 {
  color: #7e57c2 !important; }

.deep-purple {
  background-color: #673ab7 !important; }

.deep-purple-text {
  color: #673ab7 !important; }

.deep-purple.darken-1 {
  background-color: #5e35b1 !important; }

.deep-purple-text.text-darken-1 {
  color: #5e35b1 !important; }

.deep-purple.darken-2 {
  background-color: #512da8 !important; }

.deep-purple-text.text-darken-2 {
  color: #512da8 !important; }

.deep-purple.darken-3 {
  background-color: #4527a0 !important; }

.deep-purple-text.text-darken-3 {
  color: #4527a0 !important; }

.deep-purple.darken-4 {
  background-color: #311b92 !important; }

.deep-purple-text.text-darken-4 {
  color: #311b92 !important; }

.deep-purple.accent-1 {
  background-color: #b388ff !important; }

.deep-purple-text.text-accent-1 {
  color: #b388ff !important; }

.deep-purple.accent-2 {
  background-color: #7c4dff !important; }

.deep-purple-text.text-accent-2 {
  color: #7c4dff !important; }

.deep-purple.accent-3 {
  background-color: #651fff !important; }

.deep-purple-text.text-accent-3 {
  color: #651fff !important; }

.deep-purple.accent-4 {
  background-color: #6200ea !important; }

.deep-purple-text.text-accent-4 {
  color: #6200ea !important; }

.indigo.lighten-5 {
  background-color: #e8eaf6 !important; }

.indigo-text.text-lighten-5 {
  color: #e8eaf6 !important; }

.indigo.lighten-4 {
  background-color: #c5cae9 !important; }

.indigo-text.text-lighten-4 {
  color: #c5cae9 !important; }

.indigo.lighten-3 {
  background-color: #9fa8da !important; }

.indigo-text.text-lighten-3 {
  color: #9fa8da !important; }

.indigo.lighten-2 {
  background-color: #7986cb !important; }

.indigo-text.text-lighten-2 {
  color: #7986cb !important; }

.indigo.lighten-1 {
  background-color: #5c6bc0 !important; }

.indigo-text.text-lighten-1 {
  color: #5c6bc0 !important; }

.indigo {
  background-color: #3f51b5 !important; }

.indigo-text {
  color: #3f51b5 !important; }

.indigo.darken-1 {
  background-color: #3949ab !important; }

.indigo-text.text-darken-1 {
  color: #3949ab !important; }

.indigo.darken-2 {
  background-color: #303f9f !important; }

.indigo-text.text-darken-2 {
  color: #303f9f !important; }

.indigo.darken-3 {
  background-color: #283593 !important; }

.indigo-text.text-darken-3 {
  color: #283593 !important; }

.indigo.darken-4 {
  background-color: #1a237e !important; }

.indigo-text.text-darken-4 {
  color: #1a237e !important; }

.indigo.accent-1 {
  background-color: #8c9eff !important; }

.indigo-text.text-accent-1 {
  color: #8c9eff !important; }

.indigo.accent-2 {
  background-color: #536dfe !important; }

.indigo-text.text-accent-2 {
  color: #536dfe !important; }

.indigo.accent-3 {
  background-color: #3d5afe !important; }

.indigo-text.text-accent-3 {
  color: #3d5afe !important; }

.indigo.accent-4 {
  background-color: #304ffe !important; }

.indigo-text.text-accent-4 {
  color: #304ffe !important; }

.blue.lighten-5 {
  background-color: #E3F2FD !important; }

.blue-text.text-lighten-5 {
  color: #E3F2FD !important; }

.blue.lighten-4 {
  background-color: #BBDEFB !important; }

.blue-text.text-lighten-4 {
  color: #BBDEFB !important; }

.blue.lighten-3 {
  background-color: #90CAF9 !important; }

.blue-text.text-lighten-3 {
  color: #90CAF9 !important; }

.blue.lighten-2 {
  background-color: #64B5F6 !important; }

.blue-text.text-lighten-2 {
  color: #64B5F6 !important; }

.blue.lighten-1 {
  background-color: #42A5F5 !important; }

.blue-text.text-lighten-1 {
  color: #42A5F5 !important; }

.blue {
  background-color: #2196F3 !important; }

.blue-text {
  color: #2196F3 !important; }

.blue.darken-1 {
  background-color: #1E88E5 !important; }

.blue-text.text-darken-1 {
  color: #1E88E5 !important; }

.blue.darken-2 {
  background-color: #1976D2 !important; }

.blue-text.text-darken-2 {
  color: #1976D2 !important; }

.blue.darken-3 {
  background-color: #1565C0 !important; }

.blue-text.text-darken-3 {
  color: #1565C0 !important; }

.blue.darken-4 {
  background-color: #0D47A1 !important; }

.blue-text.text-darken-4 {
  color: #0D47A1 !important; }

.blue.accent-1 {
  background-color: #82B1FF !important; }

.blue-text.text-accent-1 {
  color: #82B1FF !important; }

.blue.accent-2 {
  background-color: #448AFF !important; }

.blue-text.text-accent-2 {
  color: #448AFF !important; }

.blue.accent-3 {
  background-color: #2979FF !important; }

.blue-text.text-accent-3 {
  color: #2979FF !important; }

.blue.accent-4 {
  background-color: #2962FF !important; }

.blue-text.text-accent-4 {
  color: #2962FF !important; }

.light-blue.lighten-5 {
  background-color: #e1f5fe !important; }

.light-blue-text.text-lighten-5 {
  color: #e1f5fe !important; }

.light-blue.lighten-4 {
  background-color: #b3e5fc !important; }

.light-blue-text.text-lighten-4 {
  color: #b3e5fc !important; }

.light-blue.lighten-3 {
  background-color: #81d4fa !important; }

.light-blue-text.text-lighten-3 {
  color: #81d4fa !important; }

.light-blue.lighten-2 {
  background-color: #4fc3f7 !important; }

.light-blue-text.text-lighten-2 {
  color: #4fc3f7 !important; }

.light-blue.lighten-1 {
  background-color: #29b6f6 !important; }

.light-blue-text.text-lighten-1 {
  color: #29b6f6 !important; }

.light-blue {
  background-color: #03a9f4 !important; }

.light-blue-text {
  color: #03a9f4 !important; }

.light-blue.darken-1 {
  background-color: #039be5 !important; }

.light-blue-text.text-darken-1 {
  color: #039be5 !important; }

.light-blue.darken-2 {
  background-color: #0288d1 !important; }

.light-blue-text.text-darken-2 {
  color: #0288d1 !important; }

.light-blue.darken-3 {
  background-color: #0277bd !important; }

.light-blue-text.text-darken-3 {
  color: #0277bd !important; }

.light-blue.darken-4 {
  background-color: #01579b !important; }

.light-blue-text.text-darken-4 {
  color: #01579b !important; }

.light-blue.accent-1 {
  background-color: #80d8ff !important; }

.light-blue-text.text-accent-1 {
  color: #80d8ff !important; }

.light-blue.accent-2 {
  background-color: #40c4ff !important; }

.light-blue-text.text-accent-2 {
  color: #40c4ff !important; }

.light-blue.accent-3 {
  background-color: #00b0ff !important; }

.light-blue-text.text-accent-3 {
  color: #00b0ff !important; }

.light-blue.accent-4 {
  background-color: #0091ea !important; }

.light-blue-text.text-accent-4 {
  color: #0091ea !important; }

.cyan.lighten-5 {
  background-color: #e0f7fa !important; }

.cyan-text.text-lighten-5 {
  color: #e0f7fa !important; }

.cyan.lighten-4 {
  background-color: #b2ebf2 !important; }

.cyan-text.text-lighten-4 {
  color: #b2ebf2 !important; }

.cyan.lighten-3 {
  background-color: #80deea !important; }

.cyan-text.text-lighten-3 {
  color: #80deea !important; }

.cyan.lighten-2 {
  background-color: #4dd0e1 !important; }

.cyan-text.text-lighten-2 {
  color: #4dd0e1 !important; }

.cyan.lighten-1 {
  background-color: #26c6da !important; }

.cyan-text.text-lighten-1 {
  color: #26c6da !important; }

.cyan {
  background-color: #00bcd4 !important; }

.cyan-text {
  color: #00bcd4 !important; }

.cyan.darken-1 {
  background-color: #00acc1 !important; }

.cyan-text.text-darken-1 {
  color: #00acc1 !important; }

.cyan.darken-2 {
  background-color: #0097a7 !important; }

.cyan-text.text-darken-2 {
  color: #0097a7 !important; }

.cyan.darken-3 {
  background-color: #00838f !important; }

.cyan-text.text-darken-3 {
  color: #00838f !important; }

.cyan.darken-4 {
  background-color: #006064 !important; }

.cyan-text.text-darken-4 {
  color: #006064 !important; }

.cyan.accent-1 {
  background-color: #84ffff !important; }

.cyan-text.text-accent-1 {
  color: #84ffff !important; }

.cyan.accent-2 {
  background-color: #18ffff !important; }

.cyan-text.text-accent-2 {
  color: #18ffff !important; }

.cyan.accent-3 {
  background-color: #00e5ff !important; }

.cyan-text.text-accent-3 {
  color: #00e5ff !important; }

.cyan.accent-4 {
  background-color: #00b8d4 !important; }

.cyan-text.text-accent-4 {
  color: #00b8d4 !important; }

.teal.lighten-5 {
  background-color: #e0f2f1 !important; }

.teal-text.text-lighten-5 {
  color: #e0f2f1 !important; }

.teal.lighten-4 {
  background-color: #b2dfdb !important; }

.teal-text.text-lighten-4 {
  color: #b2dfdb !important; }

.teal.lighten-3 {
  background-color: #80cbc4 !important; }

.teal-text.text-lighten-3 {
  color: #80cbc4 !important; }

.teal.lighten-2 {
  background-color: #4db6ac !important; }

.teal-text.text-lighten-2 {
  color: #4db6ac !important; }

.teal.lighten-1 {
  background-color: #26a69a !important; }

.teal-text.text-lighten-1 {
  color: #26a69a !important; }

.teal {
  background-color: #009688 !important; }

.teal-text {
  color: #009688 !important; }

.teal.darken-1 {
  background-color: #00897b !important; }

.teal-text.text-darken-1 {
  color: #00897b !important; }

.teal.darken-2 {
  background-color: #00796b !important; }

.teal-text.text-darken-2 {
  color: #00796b !important; }

.teal.darken-3 {
  background-color: #00695c !important; }

.teal-text.text-darken-3 {
  color: #00695c !important; }

.teal.darken-4 {
  background-color: #004d40 !important; }

.teal-text.text-darken-4 {
  color: #004d40 !important; }

.teal.accent-1 {
  background-color: #a7ffeb !important; }

.teal-text.text-accent-1 {
  color: #a7ffeb !important; }

.teal.accent-2 {
  background-color: #64ffda !important; }

.teal-text.text-accent-2 {
  color: #64ffda !important; }

.teal.accent-3 {
  background-color: #1de9b6 !important; }

.teal-text.text-accent-3 {
  color: #1de9b6 !important; }

.teal.accent-4 {
  background-color: #00bfa5 !important; }

.teal-text.text-accent-4 {
  color: #00bfa5 !important; }

.green.lighten-5 {
  background-color: #E8F5E9 !important; }

.green-text.text-lighten-5 {
  color: #E8F5E9 !important; }

.green.lighten-4 {
  background-color: #C8E6C9 !important; }

.green-text.text-lighten-4 {
  color: #C8E6C9 !important; }

.green.lighten-3 {
  background-color: #A5D6A7 !important; }

.green-text.text-lighten-3 {
  color: #A5D6A7 !important; }

.green.lighten-2 {
  background-color: #81C784 !important; }

.green-text.text-lighten-2 {
  color: #81C784 !important; }

.green.lighten-1 {
  background-color: #66BB6A !important; }

.green-text.text-lighten-1 {
  color: #66BB6A !important; }

.green {
  background-color: #4CAF50 !important; }

.green-text {
  color: #4CAF50 !important; }

.green.darken-1 {
  background-color: #43A047 !important; }

.green-text.text-darken-1 {
  color: #43A047 !important; }

.green.darken-2 {
  background-color: #388E3C !important; }

.green-text.text-darken-2 {
  color: #388E3C !important; }

.green.darken-3 {
  background-color: #2E7D32 !important; }

.green-text.text-darken-3 {
  color: #2E7D32 !important; }

.green.darken-4 {
  background-color: #1B5E20 !important; }

.green-text.text-darken-4 {
  color: #1B5E20 !important; }

.green.accent-1 {
  background-color: #B9F6CA !important; }

.green-text.text-accent-1 {
  color: #B9F6CA !important; }

.green.accent-2 {
  background-color: #69F0AE !important; }

.green-text.text-accent-2 {
  color: #69F0AE !important; }

.green.accent-3 {
  background-color: #00E676 !important; }

.green-text.text-accent-3 {
  color: #00E676 !important; }

.green.accent-4 {
  background-color: #00C853 !important; }

.green-text.text-accent-4 {
  color: #00C853 !important; }

.light-green.lighten-5 {
  background-color: #f1f8e9 !important; }

.light-green-text.text-lighten-5 {
  color: #f1f8e9 !important; }

.light-green.lighten-4 {
  background-color: #dcedc8 !important; }

.light-green-text.text-lighten-4 {
  color: #dcedc8 !important; }

.light-green.lighten-3 {
  background-color: #c5e1a5 !important; }

.light-green-text.text-lighten-3 {
  color: #c5e1a5 !important; }

.light-green.lighten-2 {
  background-color: #aed581 !important; }

.light-green-text.text-lighten-2 {
  color: #aed581 !important; }

.light-green.lighten-1 {
  background-color: #9ccc65 !important; }

.light-green-text.text-lighten-1 {
  color: #9ccc65 !important; }

.light-green {
  background-color: #8bc34a !important; }

.light-green-text {
  color: #8bc34a !important; }

.light-green.darken-1 {
  background-color: #7cb342 !important; }

.light-green-text.text-darken-1 {
  color: #7cb342 !important; }

.light-green.darken-2 {
  background-color: #689f38 !important; }

.light-green-text.text-darken-2 {
  color: #689f38 !important; }

.light-green.darken-3 {
  background-color: #558b2f !important; }

.light-green-text.text-darken-3 {
  color: #558b2f !important; }

.light-green.darken-4 {
  background-color: #33691e !important; }

.light-green-text.text-darken-4 {
  color: #33691e !important; }

.light-green.accent-1 {
  background-color: #ccff90 !important; }

.light-green-text.text-accent-1 {
  color: #ccff90 !important; }

.light-green.accent-2 {
  background-color: #b2ff59 !important; }

.light-green-text.text-accent-2 {
  color: #b2ff59 !important; }

.light-green.accent-3 {
  background-color: #76ff03 !important; }

.light-green-text.text-accent-3 {
  color: #76ff03 !important; }

.light-green.accent-4 {
  background-color: #64dd17 !important; }

.light-green-text.text-accent-4 {
  color: #64dd17 !important; }

.lime.lighten-5 {
  background-color: #f9fbe7 !important; }

.lime-text.text-lighten-5 {
  color: #f9fbe7 !important; }

.lime.lighten-4 {
  background-color: #f0f4c3 !important; }

.lime-text.text-lighten-4 {
  color: #f0f4c3 !important; }

.lime.lighten-3 {
  background-color: #e6ee9c !important; }

.lime-text.text-lighten-3 {
  color: #e6ee9c !important; }

.lime.lighten-2 {
  background-color: #dce775 !important; }

.lime-text.text-lighten-2 {
  color: #dce775 !important; }

.lime.lighten-1 {
  background-color: #d4e157 !important; }

.lime-text.text-lighten-1 {
  color: #d4e157 !important; }

.lime {
  background-color: #cddc39 !important; }

.lime-text {
  color: #cddc39 !important; }

.lime.darken-1 {
  background-color: #c0ca33 !important; }

.lime-text.text-darken-1 {
  color: #c0ca33 !important; }

.lime.darken-2 {
  background-color: #afb42b !important; }

.lime-text.text-darken-2 {
  color: #afb42b !important; }

.lime.darken-3 {
  background-color: #9e9d24 !important; }

.lime-text.text-darken-3 {
  color: #9e9d24 !important; }

.lime.darken-4 {
  background-color: #827717 !important; }

.lime-text.text-darken-4 {
  color: #827717 !important; }

.lime.accent-1 {
  background-color: #f4ff81 !important; }

.lime-text.text-accent-1 {
  color: #f4ff81 !important; }

.lime.accent-2 {
  background-color: #eeff41 !important; }

.lime-text.text-accent-2 {
  color: #eeff41 !important; }

.lime.accent-3 {
  background-color: #c6ff00 !important; }

.lime-text.text-accent-3 {
  color: #c6ff00 !important; }

.lime.accent-4 {
  background-color: #aeea00 !important; }

.lime-text.text-accent-4 {
  color: #aeea00 !important; }

.yellow.lighten-5 {
  background-color: #fffde7 !important; }

.yellow-text.text-lighten-5 {
  color: #fffde7 !important; }

.yellow.lighten-4 {
  background-color: #fff9c4 !important; }

.yellow-text.text-lighten-4 {
  color: #fff9c4 !important; }

.yellow.lighten-3 {
  background-color: #fff59d !important; }

.yellow-text.text-lighten-3 {
  color: #fff59d !important; }

.yellow.lighten-2 {
  background-color: #fff176 !important; }

.yellow-text.text-lighten-2 {
  color: #fff176 !important; }

.yellow.lighten-1 {
  background-color: #ffee58 !important; }

.yellow-text.text-lighten-1 {
  color: #ffee58 !important; }

.yellow {
  background-color: #ffeb3b !important; }

.yellow-text {
  color: #ffeb3b !important; }

.yellow.darken-1 {
  background-color: #fdd835 !important; }

.yellow-text.text-darken-1 {
  color: #fdd835 !important; }

.yellow.darken-2 {
  background-color: #fbc02d !important; }

.yellow-text.text-darken-2 {
  color: #fbc02d !important; }

.yellow.darken-3 {
  background-color: #f9a825 !important; }

.yellow-text.text-darken-3 {
  color: #f9a825 !important; }

.yellow.darken-4 {
  background-color: #f57f17 !important; }

.yellow-text.text-darken-4 {
  color: #f57f17 !important; }

.yellow.accent-1 {
  background-color: #ffff8d !important; }

.yellow-text.text-accent-1 {
  color: #ffff8d !important; }

.yellow.accent-2 {
  background-color: #ffff00 !important; }

.yellow-text.text-accent-2 {
  color: #ffff00 !important; }

.yellow.accent-3 {
  background-color: #ffea00 !important; }

.yellow-text.text-accent-3 {
  color: #ffea00 !important; }

.yellow.accent-4 {
  background-color: #ffd600 !important; }

.yellow-text.text-accent-4 {
  color: #ffd600 !important; }

.amber.lighten-5 {
  background-color: #fff8e1 !important; }

.amber-text.text-lighten-5 {
  color: #fff8e1 !important; }

.amber.lighten-4 {
  background-color: #ffecb3 !important; }

.amber-text.text-lighten-4 {
  color: #ffecb3 !important; }

.amber.lighten-3 {
  background-color: #ffe082 !important; }

.amber-text.text-lighten-3 {
  color: #ffe082 !important; }

.amber.lighten-2 {
  background-color: #ffd54f !important; }

.amber-text.text-lighten-2 {
  color: #ffd54f !important; }

.amber.lighten-1 {
  background-color: #ffca28 !important; }

.amber-text.text-lighten-1 {
  color: #ffca28 !important; }

.amber {
  background-color: #ffc107 !important; }

.amber-text {
  color: #ffc107 !important; }

.amber.darken-1 {
  background-color: #ffb300 !important; }

.amber-text.text-darken-1 {
  color: #ffb300 !important; }

.amber.darken-2 {
  background-color: #ffa000 !important; }

.amber-text.text-darken-2 {
  color: #ffa000 !important; }

.amber.darken-3 {
  background-color: #ff8f00 !important; }

.amber-text.text-darken-3 {
  color: #ff8f00 !important; }

.amber.darken-4 {
  background-color: #ff6f00 !important; }

.amber-text.text-darken-4 {
  color: #ff6f00 !important; }

.amber.accent-1 {
  background-color: #ffe57f !important; }

.amber-text.text-accent-1 {
  color: #ffe57f !important; }

.amber.accent-2 {
  background-color: #ffd740 !important; }

.amber-text.text-accent-2 {
  color: #ffd740 !important; }

.amber.accent-3 {
  background-color: #ffc400 !important; }

.amber-text.text-accent-3 {
  color: #ffc400 !important; }

.amber.accent-4 {
  background-color: #ffab00 !important; }

.amber-text.text-accent-4 {
  color: #ffab00 !important; }

.orange.lighten-5 {
  background-color: #fff3e0 !important; }

.orange-text.text-lighten-5 {
  color: #fff3e0 !important; }

.orange.lighten-4 {
  background-color: #ffe0b2 !important; }

.orange-text.text-lighten-4 {
  color: #ffe0b2 !important; }

.orange.lighten-3 {
  background-color: #ffcc80 !important; }

.orange-text.text-lighten-3 {
  color: #ffcc80 !important; }

.orange.lighten-2 {
  background-color: #ffb74d !important; }

.orange-text.text-lighten-2 {
  color: #ffb74d !important; }

.orange.lighten-1 {
  background-color: #ffa726 !important; }

.orange-text.text-lighten-1 {
  color: #ffa726 !important; }

.orange {
  background-color: #ff9800 !important; }

.orange-text {
  color: #ff9800 !important; }

.orange.darken-1 {
  background-color: #fb8c00 !important; }

.orange-text.text-darken-1 {
  color: #fb8c00 !important; }

.orange.darken-2 {
  background-color: #f57c00 !important; }

.orange-text.text-darken-2 {
  color: #f57c00 !important; }

.orange.darken-3 {
  background-color: #ef6c00 !important; }

.orange-text.text-darken-3 {
  color: #ef6c00 !important; }

.orange.darken-4 {
  background-color: #e65100 !important; }

.orange-text.text-darken-4 {
  color: #e65100 !important; }

.orange.accent-1 {
  background-color: #ffd180 !important; }

.orange-text.text-accent-1 {
  color: #ffd180 !important; }

.orange.accent-2 {
  background-color: #ffab40 !important; }

.orange-text.text-accent-2 {
  color: #ffab40 !important; }

.orange.accent-3 {
  background-color: #ff9100 !important; }

.orange-text.text-accent-3 {
  color: #ff9100 !important; }

.orange.accent-4 {
  background-color: #ff6d00 !important; }

.orange-text.text-accent-4 {
  color: #ff6d00 !important; }

.deep-orange.lighten-5 {
  background-color: #fbe9e7 !important; }

.deep-orange-text.text-lighten-5 {
  color: #fbe9e7 !important; }

.deep-orange.lighten-4 {
  background-color: #ffccbc !important; }

.deep-orange-text.text-lighten-4 {
  color: #ffccbc !important; }

.deep-orange.lighten-3 {
  background-color: #ffab91 !important; }

.deep-orange-text.text-lighten-3 {
  color: #ffab91 !important; }

.deep-orange.lighten-2 {
  background-color: #ff8a65 !important; }

.deep-orange-text.text-lighten-2 {
  color: #ff8a65 !important; }

.deep-orange.lighten-1 {
  background-color: #ff7043 !important; }

.deep-orange-text.text-lighten-1 {
  color: #ff7043 !important; }

.deep-orange {
  background-color: #ff5722 !important; }

.deep-orange-text {
  color: #ff5722 !important; }

.deep-orange.darken-1 {
  background-color: #f4511e !important; }

.deep-orange-text.text-darken-1 {
  color: #f4511e !important; }

.deep-orange.darken-2 {
  background-color: #e64a19 !important; }

.deep-orange-text.text-darken-2 {
  color: #e64a19 !important; }

.deep-orange.darken-3 {
  background-color: #d84315 !important; }

.deep-orange-text.text-darken-3 {
  color: #d84315 !important; }

.deep-orange.darken-4 {
  background-color: #bf360c !important; }

.deep-orange-text.text-darken-4 {
  color: #bf360c !important; }

.deep-orange.accent-1 {
  background-color: #ff9e80 !important; }

.deep-orange-text.text-accent-1 {
  color: #ff9e80 !important; }

.deep-orange.accent-2 {
  background-color: #ff6e40 !important; }

.deep-orange-text.text-accent-2 {
  color: #ff6e40 !important; }

.deep-orange.accent-3 {
  background-color: #ff3d00 !important; }

.deep-orange-text.text-accent-3 {
  color: #ff3d00 !important; }

.deep-orange.accent-4 {
  background-color: #dd2c00 !important; }

.deep-orange-text.text-accent-4 {
  color: #dd2c00 !important; }

.brown.lighten-5 {
  background-color: #efebe9 !important; }

.brown-text.text-lighten-5 {
  color: #efebe9 !important; }

.brown.lighten-4 {
  background-color: #d7ccc8 !important; }

.brown-text.text-lighten-4 {
  color: #d7ccc8 !important; }

.brown.lighten-3 {
  background-color: #bcaaa4 !important; }

.brown-text.text-lighten-3 {
  color: #bcaaa4 !important; }

.brown.lighten-2 {
  background-color: #a1887f !important; }

.brown-text.text-lighten-2 {
  color: #a1887f !important; }

.brown.lighten-1 {
  background-color: #8d6e63 !important; }

.brown-text.text-lighten-1 {
  color: #8d6e63 !important; }

.brown {
  background-color: #795548 !important; }

.brown-text {
  color: #795548 !important; }

.brown.darken-1 {
  background-color: #6d4c41 !important; }

.brown-text.text-darken-1 {
  color: #6d4c41 !important; }

.brown.darken-2 {
  background-color: #5d4037 !important; }

.brown-text.text-darken-2 {
  color: #5d4037 !important; }

.brown.darken-3 {
  background-color: #4e342e !important; }

.brown-text.text-darken-3 {
  color: #4e342e !important; }

.brown.darken-4 {
  background-color: #3e2723 !important; }

.brown-text.text-darken-4 {
  color: #3e2723 !important; }

.blue-grey.lighten-5 {
  background-color: #eceff1 !important; }

.blue-grey-text.text-lighten-5 {
  color: #eceff1 !important; }

.blue-grey.lighten-4 {
  background-color: #cfd8dc !important; }

.blue-grey-text.text-lighten-4 {
  color: #cfd8dc !important; }

.blue-grey.lighten-3 {
  background-color: #b0bec5 !important; }

.blue-grey-text.text-lighten-3 {
  color: #b0bec5 !important; }

.blue-grey.lighten-2 {
  background-color: #90a4ae !important; }

.blue-grey-text.text-lighten-2 {
  color: #90a4ae !important; }

.blue-grey.lighten-1 {
  background-color: #78909c !important; }

.blue-grey-text.text-lighten-1 {
  color: #78909c !important; }

.blue-grey {
  background-color: #607d8b !important; }

.blue-grey-text {
  color: #607d8b !important; }

.blue-grey.darken-1 {
  background-color: #546e7a !important; }

.blue-grey-text.text-darken-1 {
  color: #546e7a !important; }

.blue-grey.darken-2 {
  background-color: #455a64 !important; }

.blue-grey-text.text-darken-2 {
  color: #455a64 !important; }

.blue-grey.darken-3 {
  background-color: #37474f !important; }

.blue-grey-text.text-darken-3 {
  color: #37474f !important; }

.blue-grey.darken-4 {
  background-color: #263238 !important; }

.blue-grey-text.text-darken-4 {
  color: #263238 !important; }

.grey.lighten-5 {
  background-color: #fafafa !important; }

.grey-text.text-lighten-5 {
  color: #fafafa !important; }

.grey.lighten-4 {
  background-color: #f5f5f5 !important; }

.grey-text.text-lighten-4 {
  color: #f5f5f5 !important; }

.grey.lighten-3 {
  background-color: #eeeeee !important; }

.grey-text.text-lighten-3 {
  color: #eeeeee !important; }

.grey.lighten-2 {
  background-color: #e0e0e0 !important; }

.grey-text.text-lighten-2 {
  color: #e0e0e0 !important; }

.grey.lighten-1 {
  background-color: #bdbdbd !important; }

.grey-text.text-lighten-1 {
  color: #bdbdbd !important; }

.grey {
  background-color: #9e9e9e !important; }

.grey-text {
  color: #9e9e9e !important; }

.grey.darken-1 {
  background-color: #757575 !important; }

.grey-text.text-darken-1 {
  color: #757575 !important; }

.grey.darken-2 {
  background-color: #616161 !important; }

.grey-text.text-darken-2 {
  color: #616161 !important; }

.grey.darken-3 {
  background-color: #424242 !important; }

.grey-text.text-darken-3 {
  color: #424242 !important; }

.grey.darken-4 {
  background-color: #212121 !important; }

.grey-text.text-darken-4 {
  color: #212121 !important; }

.shades.black {
  background-color: #000000 !important; }

.shades-text.text-black {
  color: #000000 !important; }

.shades.white {
  background-color: #FFFFFF !important; }

.shades-text.text-white {
  color: #FFFFFF !important; }

.shades.transparent {
  background-color: transparent !important; }

.shades-text.text-transparent {
  color: transparent !important; }

.black {
  background-color: #000000 !important; }

.black-text {
  color: #000000 !important; }

.white {
  background-color: #FFFFFF !important; }

.white-text {
  color: #FFFFFF !important; }

.transparent {
  background-color: transparent !important; }

.transparent-text {
  color: transparent !important; }

/*** Colors ***/
/*** Badges ***/
/*** Buttons ***/
/*** Cards ***/
/*** Collapsible ***/
/*** Dropdown ***/
/*** Fonts ***/
/*** Forms ***/
/*** Global ***/
/*** Navbar ***/
/*** SideNav ***/
/*** Photo Slider ***/
/*** Tabs ***/
/*** Tables ***/
/*** Toasts ***/
/*** Typography ***/
/*** Collections ***/
/* Progress Bar */
/*! normalize.css v3.0.2 | MIT License | git.io/normalize */
/**
 * 1. Set default font family to sans-serif.
 * 2. Prevent iOS text size adjust after orientation change, without disabling
 *    user zoom.
 */
html {
  font-family: sans-serif;
  /* 1 */
  -ms-text-size-adjust: 100%;
  /* 2 */
  -webkit-text-size-adjust: 100%;
  /* 2 */ }

/**
 * Remove default margin.
 */
body {
  margin: 0; }

/* HTML5 display definitions
   ========================================================================== */
/**
 * Correct `block` display not defined for any HTML5 element in IE 8/9.
 * Correct `block` display not defined for `details` or `summary` in IE 10/11
 * and Firefox.
 * Correct `block` display not defined for `main` in IE 11.
 */
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
menu,
nav,
section,
summary {
  display: block; }

/**
 * 1. Correct `inline-block` display not defined in IE 8/9.
 * 2. Normalize vertical alignment of `progress` in Chrome, Firefox, and Opera.
 */
audio,
canvas,
progress,
video {
  display: inline-block;
  /* 1 */
  vertical-align: baseline;
  /* 2 */ }

/**
 * Prevent modern browsers from displaying `audio` without controls.
 * Remove excess height in iOS 5 devices.
 */
audio:not([controls]) {
  display: none;
  height: 0; }

/**
 * Address `[hidden]` styling not present in IE 8/9/10.
 * Hide the `template` element in IE 8/9/11, Safari, and Firefox < 22.
 */
[hidden],
template {
  display: none; }

/* Links
   ========================================================================== */
/**
 * Remove the gray background color from active links in IE 10.
 */
a {
  background-color: transparent; }

/**
 * Improve readability when focused and also mouse hovered in all browsers.
 */
a:active,
a:hover {
  outline: 0; }

/* Text-level semantics
   ========================================================================== */
/**
 * Address styling not present in IE 8/9/10/11, Safari, and Chrome.
 */
abbr[title] {
  border-bottom: 1px dotted; }

/**
 * Address style set to `bolder` in Firefox 4+, Safari, and Chrome.
 */
b,
strong {
  font-weight: bold; }

/**
 * Address styling not present in Safari and Chrome.
 */
dfn {
  font-style: italic; }

/**
 * Address variable `h1` font-size and margin within `section` and `article`
 * contexts in Firefox 4+, Safari, and Chrome.
 */
h1 {
  font-size: 2em;
  margin: 0.67em 0; }

/**
 * Address styling not present in IE 8/9.
 */
mark {
  background: #ff0;
  color: #000; }

/**
 * Address inconsistent and variable font size in all browsers.
 */
small {
  font-size: 80%; }

/**
 * Prevent `sub` and `sup` affecting `line-height` in all browsers.
 */
sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline; }

sup {
  top: -0.5em; }

sub {
  bottom: -0.25em; }

/* Embedded content
   ========================================================================== */
/**
 * Remove border when inside `a` element in IE 8/9/10.
 */
img {
  border: 0; }

/**
 * Correct overflow not hidden in IE 9/10/11.
 */
svg:not(:root) {
  overflow: hidden; }

/* Grouping content
   ========================================================================== */
/**
 * Address margin not present in IE 8/9 and Safari.
 */
figure {
  margin: 1em 40px; }

/**
 * Address differences between Firefox and other browsers.
 */
hr {
  box-sizing: content-box;
  height: 0; }

/**
 * Contain overflow in all browsers.
 */
pre {
  overflow: auto; }

/**
 * Address odd `em`-unit font size rendering in all browsers.
 */
code,
kbd,
pre,
samp {
  font-family: monospace, monospace;
  font-size: 1em; }

/* Forms
   ========================================================================== */
/**
 * Known limitation: by default, Chrome and Safari on OS X allow very limited
 * styling of `select`, unless a `border` property is set.
 */
/**
 * 1. Correct color not being inherited.
 *    Known issue: affects color of disabled elements.
 * 2. Correct font properties not being inherited.
 * 3. Address margins set differently in Firefox 4+, Safari, and Chrome.
 */
button,
input,
optgroup,
select,
textarea {
  color: inherit;
  /* 1 */
  font: inherit;
  /* 2 */
  margin: 0;
  /* 3 */ }

/**
 * Address `overflow` set to `hidden` in IE 8/9/10/11.
 */
button {
  overflow: visible; }

/**
 * Address inconsistent `text-transform` inheritance for `button` and `select`.
 * All other form control elements do not inherit `text-transform` values.
 * Correct `button` style inheritance in Firefox, IE 8/9/10/11, and Opera.
 * Correct `select` style inheritance in Firefox.
 */
button,
select {
  text-transform: none; }

/**
 * 1. Avoid the WebKit bug in Android 4.0.* where (2) destroys native `audio`
 *    and `video` controls.
 * 2. Correct inability to style clickable `input` types in iOS.
 * 3. Improve usability and consistency of cursor style between image-type
 *    `input` and others.
 */
/* 1 */
html input[type="button"],
button,
input[type="reset"],
input[type="submit"] {
  -webkit-appearance: button;
  /* 2 */
  cursor: pointer;
  /* 3 */ }

/**
 * Re-set default cursor for disabled elements.
 */
button[disabled],
html input[disabled] {
  cursor: default; }

/**
 * Remove inner padding and border in Firefox 4+.
 */
button::-moz-focus-inner,
input::-moz-focus-inner {
  border: 0;
  padding: 0; }

/**
 * Address Firefox 4+ setting `line-height` on `input` using `!important` in
 * the UA stylesheet.
 */
input {
  line-height: normal; }

/**
 * It's recommended that you don't attempt to style these elements.
 * Firefox's implementation doesn't respect box-sizing, padding, or width.
 *
 * 1. Address box sizing set to `content-box` in IE 8/9/10.
 * 2. Remove excess padding in IE 8/9/10.
 */
input[type="checkbox"],
input[type="radio"] {
  box-sizing: border-box;
  /* 1 */
  padding: 0;
  /* 2 */ }

/**
 * Fix the cursor style for Chrome's increment/decrement buttons. For certain
 * `font-size` values of the `input`, it causes the cursor style of the
 * decrement button to change from `default` to `text`.
 */
input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
  height: auto; }

/**
 * 1. Address `appearance` set to `searchfield` in Safari and Chrome.
 * 2. Address `box-sizing` set to `border-box` in Safari and Chrome
 *    (include `-moz` to future-proof).
 */
input[type="search"] {
  -webkit-appearance: textfield;
  /* 1 */
  /* 2 */
  box-sizing: content-box; }

/**
 * Remove inner padding and search cancel button in Safari and Chrome on OS X.
 * Safari (but not Chrome) clips the cancel button when the search input has
 * padding (and `textfield` appearance).
 */
input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none; }

/**
 * Define consistent border, margin, and padding.
 */
fieldset {
  border: 1px solid #c0c0c0;
  margin: 0 2px;
  padding: 0.35em 0.625em 0.75em; }

/**
 * 1. Correct `color` not being inherited in IE 8/9/10/11.
 * 2. Remove padding so people aren't caught out if they zero out fieldsets.
 */
legend {
  border: 0;
  /* 1 */
  padding: 0;
  /* 2 */ }

/**
 * Remove default vertical scrollbar in IE 8/9/10/11.
 */
textarea {
  overflow: auto; }

/**
 * Don't inherit the `font-weight` (applied by a rule above).
 * NOTE: the default cannot safely be changed in Chrome and Safari on OS X.
 */
optgroup {
  font-weight: bold; }

/* Tables
   ========================================================================== */
/**
 * Remove most spacing between table cells.
 */
table {
  border-collapse: collapse;
  border-spacing: 0; }

td,
th {
  padding: 0; }

html {
  box-sizing: border-box; }

*, *:before, *:after {
  box-sizing: inherit; }

ul {
  list-style-type: none; }

a {
  color: #039be5;
  text-decoration: none;
  -webkit-tap-highlight-color: transparent; }

.valign-wrapper {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-align: center;
  -ms-flex-align: center;
  -webkit-box-align: center;
          align-items: center; }
  .valign-wrapper .valign {
    display: block; }

ul {
  padding: 0; }
  ul li {
    list-style-type: none; }

.clearfix {
  clear: both; }

.z-depth-0 {
  box-shadow: none !important; }

.z-depth-1, nav, .card-panel, .card, .toast, .btn, .btn-large, .btn-floating, .dropdown-content, .collapsible, .side-nav, .select2-container--default.select2-container--open, .select2-container .select2-dropdown {
  box-shadow: 0 2px 5px 0 rgba(0, 0, 0, 0.16), 0 2px 10px 0 rgba(0, 0, 0, 0.12); }

.z-depth-1-half, .btn:hover, .btn-large:hover, .btn-floating:hover {
  box-shadow: 0 5px 11px 0 rgba(0, 0, 0, 0.18), 0 4px 15px 0 rgba(0, 0, 0, 0.15); }

.z-depth-2 {
  box-shadow: 0 8px 17px 0 rgba(0, 0, 0, 0.2), 0 6px 20px 0 rgba(0, 0, 0, 0.19); }

.z-depth-3 {
  box-shadow: 0 12px 15px 0 rgba(0, 0, 0, 0.24), 0 17px 50px 0 rgba(0, 0, 0, 0.19); }

.z-depth-4, .modal {
  box-shadow: 0 16px 28px 0 rgba(0, 0, 0, 0.22), 0 25px 55px 0 rgba(0, 0, 0, 0.21); }

.z-depth-5 {
  box-shadow: 0 27px 24px 0 rgba(0, 0, 0, 0.2), 0 40px 77px 0 rgba(0, 0, 0, 0.22); }

.hoverable:hover {
  -webkit-transition: box-shadow .25s;
  transition: box-shadow .25s;
  box-shadow: 0 8px 17px 0 rgba(0, 0, 0, 0.2), 0 6px 20px 0 rgba(0, 0, 0, 0.19); }

.divider, .header .side-nav li:after {
  height: 1px;
  overflow: hidden;
  background-color: #e0e0e0; }

blockquote {
  margin: 20px 0;
  padding-left: 1.5rem;
  border-left: 5px solid #ee6e73; }

i {
  line-height: inherit; }
  i.left {
    float: left;
    margin-right: 15px; }
  i.right {
    float: right;
    margin-left: 15px; }
  i.tiny {
    font-size: 1rem; }
  i.small {
    font-size: 2rem; }
  i.medium {
    font-size: 4rem; }
  i.large {
    font-size: 6rem; }

img.responsive-img,
video.responsive-video {
  max-width: 100%;
  height: auto; }

.pagination li {
  float: left;
  font-size: 1.2rem;
  padding: 0 10px;
  line-height: 30px;
  border-radius: 2px;
  text-align: center; }
  .pagination li a {
    color: #444; }
  .pagination li.active a, .pagination .body-home .header .side-nav li.nav-home a, .body-home .header .side-nav .pagination li.nav-home a, .pagination .body-products .header .side-nav li.subnav-products a, .body-products .header .side-nav .pagination li.subnav-products a, .pagination .body-attributes .header .side-nav li.subnav-attributes a, .body-attributes .header .side-nav .pagination li.subnav-attributes a, .pagination .body-categories .header .side-nav li.subnav-categories a, .body-categories .header .side-nav .pagination li.subnav-categories a, .pagination .body-orders .header .side-nav li.subnav-orders a, .body-orders .header .side-nav .pagination li.subnav-orders a, .pagination .body-payments .header .side-nav li.subnav-payments a, .body-payments .header .side-nav .pagination li.subnav-payments a, .pagination .body-customers .header .side-nav li.subnav-customers a, .body-customers .header .side-nav .pagination li.subnav-customers a, .pagination .body-discounts .header .side-nav li.subnav-discounts a, .body-discounts .header .side-nav .pagination li.subnav-discounts a, .pagination .body-vouchers .header .side-nav li.subnav-vouchers a, .body-vouchers .header .side-nav .pagination li.subnav-vouchers a, .pagination .body-sales .header .side-nav li.subnav-sales a, .body-sales .header .side-nav .pagination li.subnav-sales a {
    color: #fff; }
  .pagination li.active, .pagination .body-home .header .side-nav li.nav-home, .body-home .header .side-nav .pagination li.nav-home, .pagination .body-products .header .side-nav li.subnav-products, .body-products .header .side-nav .pagination li.subnav-products, .pagination .body-attributes .header .side-nav li.subnav-attributes, .body-attributes .header .side-nav .pagination li.subnav-attributes, .pagination .body-categories .header .side-nav li.subnav-categories, .body-categories .header .side-nav .pagination li.subnav-categories, .pagination .body-orders .header .side-nav li.subnav-orders, .body-orders .header .side-nav .pagination li.subnav-orders, .pagination .body-payments .header .side-nav li.subnav-payments, .body-payments .header .side-nav .pagination li.subnav-payments, .pagination .body-customers .header .side-nav li.subnav-customers, .body-customers .header .side-nav .pagination li.subnav-customers, .pagination .body-discounts .header .side-nav li.subnav-discounts, .body-discounts .header .side-nav .pagination li.subnav-discounts, .pagination .body-vouchers .header .side-nav li.subnav-vouchers, .body-vouchers .header .side-nav .pagination li.subnav-vouchers, .pagination .body-sales .header .side-nav li.subnav-sales, .body-sales .header .side-nav .pagination li.subnav-sales {
    background-color: #ee6e73; }
  .pagination li.disabled a {
    cursor: default;
    color: #999; }
  .pagination li i {
    font-size: 2rem; }

.pagination li.pages ul li {
  display: inline-block;
  float: none; }

@media only screen and (max-width: 992px) {
  .pagination {
    width: 100%; }
    .pagination li.prev,
    .pagination li.next {
      width: 10%; }
    .pagination li.pages {
      width: 80%;
      overflow: hidden;
      white-space: nowrap; } }

.parallax-container {
  position: relative;
  overflow: hidden;
  height: 500px; }

.parallax {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  z-index: -1; }
  .parallax img {
    display: none;
    position: absolute;
    left: 50%;
    bottom: 0;
    min-width: 100%;
    min-height: 100%;
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
    -webkit-transform: translateX(-50%);
            transform: translateX(-50%); }

.pin-top, .pin-bottom {
  position: relative; }

.pinned {
  position: fixed !important; }

/*********************
  Transition Classes
**********************/
ul.staggered-list li {
  opacity: 0; }

.fade-in {
  opacity: 0;
  -webkit-transform-origin: 0 50%;
          transform-origin: 0 50%; }

/*********************
  Media Query Classes
**********************/
@media only screen and (max-width: 600px) {
  .hide-on-small-only, .hide-on-small-and-down {
    display: none !important; } }

@media only screen and (max-width: 992px) {
  .hide-on-med-and-down {
    display: none !important; } }

@media only screen and (min-width: 601px) {
  .hide-on-med-and-up {
    display: none !important; } }

@media only screen and (min-width: 600px) and (max-width: 992px) {
  .hide-on-med-only {
    display: none !important; } }

@media only screen and (min-width: 993px) {
  .hide-on-large-only {
    display: none !important; } }

@media only screen and (min-width: 993px) {
  .show-on-large {
    display: initial !important; } }

@media only screen and (min-width: 600px) and (max-width: 992px) {
  .show-on-medium {
    display: initial !important; } }

@media only screen and (max-width: 600px) {
  .show-on-small {
    display: initial !important; } }

@media only screen and (min-width: 601px) {
  .show-on-medium-and-up {
    display: initial !important; } }

@media only screen and (max-width: 992px) {
  .show-on-medium-and-down {
    display: initial !important; } }

@media only screen and (max-width: 600px) {
  .center-on-small-only {
    text-align: center; } }

footer.page-footer {
  margin-top: 20px;
  padding-top: 20px;
  background-color: #ee6e73; }
  footer.page-footer .footer-copyright {
    overflow: hidden;
    height: 50px;
    line-height: 50px;
    color: rgba(255, 255, 255, 0.8);
    background-color: rgba(51, 51, 51, 0.08); }

table, th, td {
  border: none; }

table {
  width: 100%;
  display: table; }
  table.bordered > thead > tr,
  table.bordered > tbody > tr {
    border-bottom: 1px solid #d0d0d0; }
  table.striped > tbody > tr:nth-child(odd) {
    background-color: #f2f2f2; }
  table.striped > tbody > tr > td {
    border-radius: 0px; }
  table.hoverable > tbody > tr {
    -webkit-transition: background-color 0.25s ease;
    transition: background-color 0.25s ease; }
    table.hoverable > tbody > tr:hover {
      background-color: #f2f2f2; }
  table.centered thead tr th, table.centered tbody tr td {
    text-align: center; }

thead {
  border-bottom: 1px solid #d0d0d0; }

td, th {
  padding: 15px 5px;
  display: table-cell;
  text-align: left;
  vertical-align: middle;
  border-radius: 2px; }

@media only screen and (max-width: 992px) {
  table.responsive-table {
    width: 100%;
    border-collapse: collapse;
    border-spacing: 0;
    display: block;
    position: relative;
    /* sort out borders */ }
    table.responsive-table th,
    table.responsive-table td {
      margin: 0;
      vertical-align: top; }
    table.responsive-table th {
      text-align: left; }
    table.responsive-table thead {
      display: block;
      float: left; }
      table.responsive-table thead tr {
        display: block;
        padding: 0 10px 0 0; }
        table.responsive-table thead tr th::before {
          content: "\00a0"; }
    table.responsive-table tbody {
      display: block;
      width: auto;
      position: relative;
      overflow-x: auto;
      white-space: nowrap; }
      table.responsive-table tbody tr {
        display: inline-block;
        vertical-align: top; }
    table.responsive-table th {
      display: block;
      text-align: right; }
    table.responsive-table td {
      display: block;
      min-height: 1.25em;
      text-align: left; }
    table.responsive-table tr {
      padding: 0 10px; }
    table.responsive-table thead {
      border: 0;
      border-right: 1px solid #d0d0d0; }
    table.responsive-table.bordered th {
      border-bottom: 0;
      border-left: 0; }
    table.responsive-table.bordered td {
      border-left: 0;
      border-right: 0;
      border-bottom: 0; }
    table.responsive-table.bordered tr {
      border: 0; }
    table.responsive-table.bordered tbody tr {
      border-right: 1px solid #d0d0d0; } }

.collection {
  margin: 0.5rem 0 1rem 0;
  border: 1px solid #e0e0e0;
  border-radius: 2px;
  overflow: hidden;
  position: relative; }
  .collection .collection-item {
    background-color: #fff;
    line-height: 1.5rem;
    padding: 10px 20px;
    margin: 0;
    border-bottom: 1px solid #e0e0e0; }
    .collection .collection-item.avatar {
      min-height: 84px;
      padding-left: 72px;
      position: relative; }
      .collection .collection-item.avatar .circle {
        position: absolute;
        width: 42px;
        height: 42px;
        overflow: hidden;
        left: 15px;
        display: inline-block;
        vertical-align: middle; }
      .collection .collection-item.avatar i.circle {
        font-size: 18px;
        line-height: 42px;
        color: #fff;
        background-color: #999;
        text-align: center; }
      .collection .collection-item.avatar .title {
        font-size: 16px; }
      .collection .collection-item.avatar p {
        margin: 0; }
      .collection .collection-item.avatar .secondary-content {
        position: absolute;
        top: 16px;
        right: 16px; }
    .collection .collection-item:last-child {
      border-bottom: none; }
    .collection .collection-item.active, .collection .body-home .header .side-nav li.collection-item.nav-home, .body-home .header .side-nav .collection li.collection-item.nav-home, .collection .body-products .header .side-nav li.collection-item.subnav-products, .body-products .header .side-nav .collection li.collection-item.subnav-products, .collection .body-attributes .header .side-nav li.collection-item.subnav-attributes, .body-attributes .header .side-nav .collection li.collection-item.subnav-attributes, .collection .body-categories .header .side-nav li.collection-item.subnav-categories, .body-categories .header .side-nav .collection li.collection-item.subnav-categories, .collection .body-orders .header .side-nav li.collection-item.subnav-orders, .body-orders .header .side-nav .collection li.collection-item.subnav-orders, .collection .body-payments .header .side-nav li.collection-item.subnav-payments, .body-payments .header .side-nav .collection li.collection-item.subnav-payments, .collection .body-customers .header .side-nav li.collection-item.subnav-customers, .body-customers .header .side-nav .collection li.collection-item.subnav-customers, .collection .body-discounts .header .side-nav li.collection-item.subnav-discounts, .body-discounts .header .side-nav .collection li.collection-item.subnav-discounts, .collection .body-vouchers .header .side-nav li.collection-item.subnav-vouchers, .body-vouchers .header .side-nav .collection li.collection-item.subnav-vouchers, .collection .body-sales .header .side-nav li.collection-item.subnav-sales, .body-sales .header .side-nav .collection li.collection-item.subnav-sales, .collection form label.collection-item, form .collection label.collection-item {
      background-color: #26a69a;
      color: #eafaf9; }
  .collection a.collection-item {
    display: block;
    -webkit-transition: 0.25s;
    transition: 0.25s;
    color: #26a69a; }
    .collection a.collection-item:not(.active):not(.body-home .header .side-nav li.nav-home):not(.body-products .header .side-nav li.subnav-products):not(.body-attributes .header .side-nav li.subnav-attributes):not(.body-categories .header .side-nav li.subnav-categories):not(.body-orders .header .side-nav li.subnav-orders):not(.body-payments .header .side-nav li.subnav-payments):not(.body-customers .header .side-nav li.subnav-customers):not(.body-discounts .header .side-nav li.subnav-discounts):not(.body-vouchers .header .side-nav li.subnav-vouchers):not(.body-sales .header .side-nav li.subnav-sales):not(form label):hover {
      background-color: #ddd; }
  .collection.with-header .collection-header {
    background-color: #fff;
    border-bottom: 1px solid #e0e0e0;
    padding: 10px 20px; }
  .collection.with-header .collection-item {
    padding-left: 30px; }
  .collection.with-header .collection-item.avatar {
    padding-left: 72px; }

.secondary-content {
  float: right;
  color: #26a69a; }

span.badge {
  min-width: 3rem;
  padding: 0 6px;
  text-align: center;
  font-size: 1rem;
  line-height: inherit;
  color: #757575;
  position: absolute;
  right: 15px;
  box-sizing: border-box; }
  span.badge.new {
    font-weight: 300;
    font-size: 0.8rem;
    color: #fff;
    background-color: #26a69a;
    border-radius: 2px; }
  span.badge.new:after {
    content: " new"; }

.video-container {
  position: relative;
  padding-bottom: 56.25%;
  padding-top: 30px;
  height: 0;
  overflow: hidden; }
  .video-container.no-controls {
    padding-top: 0; }
  .video-container iframe, .video-container object, .video-container embed {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%; }

.progress {
  position: relative;
  height: 4px;
  display: block;
  width: 100%;
  background-color: #acece6;
  border-radius: 2px;
  margin: 0.5rem 0 1rem 0;
  overflow: hidden; }
  .progress .determinate {
    position: absolute;
    background-color: inherit;
    top: 0;
    left: 0;
    bottom: 0;
    background-color: #26a69a;
    -webkit-transition: width 0.3s linear;
    transition: width 0.3s linear; }
  .progress .indeterminate {
    background-color: #26a69a; }
    .progress .indeterminate:before {
      content: '';
      position: absolute;
      background-color: inherit;
      top: 0;
      left: 0;
      bottom: 0;
      will-change: left, right;
      -webkit-animation: indeterminate 2.1s cubic-bezier(0.65, 0.815, 0.735, 0.395) infinite;
      animation: indeterminate 2.1s cubic-bezier(0.65, 0.815, 0.735, 0.395) infinite; }
    .progress .indeterminate:after {
      content: '';
      position: absolute;
      background-color: inherit;
      top: 0;
      left: 0;
      bottom: 0;
      will-change: left, right;
      -webkit-animation: indeterminate-short 2.1s cubic-bezier(0.165, 0.84, 0.44, 1) infinite;
      animation: indeterminate-short 2.1s cubic-bezier(0.165, 0.84, 0.44, 1) infinite;
      -webkit-animation-delay: 1.15s;
      animation-delay: 1.15s; }

@-webkit-keyframes indeterminate {
  0% {
    left: -35%;
    right: 100%; }
  60% {
    left: 100%;
    right: -90%; }
  100% {
    left: 100%;
    right: -90%; } }

@keyframes indeterminate {
  0% {
    left: -35%;
    right: 100%; }
  60% {
    left: 100%;
    right: -90%; }
  100% {
    left: 100%;
    right: -90%; } }

@-webkit-keyframes indeterminate-short {
  0% {
    left: -200%;
    right: 100%; }
  60% {
    left: 107%;
    right: -8%; }
  100% {
    left: 107%;
    right: -8%; } }

@keyframes indeterminate-short {
  0% {
    left: -200%;
    right: 100%; }
  60% {
    left: 107%;
    right: -8%; }
  100% {
    left: 107%;
    right: -8%; } }

/*******************
  Utility Classes
*******************/
.hide {
  display: none !important; }

.left-align {
  text-align: left; }

.right-align {
  text-align: right; }

.center, .center-align {
  text-align: center; }

.left {
  float: left !important; }

.right {
  float: right !important; }

.no-select, input[type=range], input[type=range] + .thumb {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.circle {
  border-radius: 50%; }

.center-block {
  display: block;
  margin-left: auto;
  margin-right: auto; }

.truncate {
  display: block;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis; }

.no-padding {
  padding: 0 !important; }

@font-face {
  font-family: "Material-Design-Icons";
  src: url("../fonts/Material-Design-Icons.eot?#iefix") format("embedded-opentype"), url("../fonts/Material-Design-Icons.woff2") format("woff2"), url("../fonts/Material-Design-Icons.woff") format("woff"), url("../fonts/Material-Design-Icons.ttf") format("truetype"), url("../fonts/Material-Design-Icons.svg#Material-Design-Icons") format("svg");
  font-weight: normal;
  font-style: normal; }

[class^="mdi-"], [class*="mdi-"] {
  speak: none;
  display: inline-block;
  font-family: "Material-Design-Icons";
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-rendering: auto;
  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  -webkit-transform: translate(0, 0);
          transform: translate(0, 0); }
  [class^="mdi-"]:before, [class*="mdi-"]:before {
    display: inline-block;
    speak: none;
    text-decoration: inherit; }
  [class^="mdi-"].pull-left, [class*="mdi-"].pull-left {
    margin-right: .3em; }
  [class^="mdi-"].pull-right, [class*="mdi-"].pull-right {
    margin-left: .3em; }
  [class^="mdi-"].mdi-lg:before, [class^="mdi-"].mdi-lg:after, [class*="mdi-"].mdi-lg:before, [class*="mdi-"].mdi-lg:after {
    font-size: 1.33333333em;
    line-height: 0.75em;
    vertical-align: -15%; }
  [class^="mdi-"].mdi-2x:before, [class^="mdi-"].mdi-2x:after, [class*="mdi-"].mdi-2x:before, [class*="mdi-"].mdi-2x:after {
    font-size: 2em; }
  [class^="mdi-"].mdi-3x:before, [class^="mdi-"].mdi-3x:after, [class*="mdi-"].mdi-3x:before, [class*="mdi-"].mdi-3x:after {
    font-size: 3em; }
  [class^="mdi-"].mdi-4x:before, [class^="mdi-"].mdi-4x:after, [class*="mdi-"].mdi-4x:before, [class*="mdi-"].mdi-4x:after {
    font-size: 4em; }
  [class^="mdi-"].mdi-5x:before, [class^="mdi-"].mdi-5x:after, [class*="mdi-"].mdi-5x:before, [class*="mdi-"].mdi-5x:after {
    font-size: 5em; }

[class^="mdi-device-signal-cellular-"]:after,
[class^="mdi-device-battery-"]:after,
[class^="mdi-device-battery-charging-"]:after,
[class^="mdi-device-signal-cellular-connected-no-internet-"]:after,
[class^="mdi-device-signal-wifi-"]:after,
[class^="mdi-device-signal-wifi-statusbar-not-connected"]:after,
.mdi-device-network-wifi:after {
  opacity: .3;
  position: absolute;
  left: 0;
  top: 0;
  z-index: 1;
  display: inline-block;
  speak: none;
  text-decoration: inherit; }

[class^="mdi-device-signal-cellular-"]:after {
  content: "\e758"; }

[class^="mdi-device-battery-"]:after {
  content: "\e735"; }

[class^="mdi-device-battery-charging-"]:after {
  content: "\e733"; }

[class^="mdi-device-signal-cellular-connected-no-internet-"]:after {
  content: "\e75d"; }

[class^="mdi-device-signal-wifi-"]:after, .mdi-device-network-wifi:after {
  content: "\e765"; }

[class^="mdi-device-signal-wifi-statusbasr-not-connected"]:after {
  content: "\e8f7"; }

.mdi-device-signal-cellular-off:after, .mdi-device-signal-cellular-null:after, .mdi-device-signal-cellular-no-sim:after, .mdi-device-signal-wifi-off:after, .mdi-device-signal-wifi-4-bar:after, .mdi-device-signal-cellular-4-bar:after, .mdi-device-battery-alert:after, .mdi-device-signal-cellular-connected-no-internet-4-bar:after, .mdi-device-battery-std:after, .mdi-device-battery-full .mdi-device-battery-unknown:after {
  content: ""; }

.mdi-fw {
  width: 1.28571429em;
  text-align: center; }

.mdi-ul {
  padding-left: 0;
  margin-left: 2.14285714em;
  list-style-type: none; }

.mdi-ul > li {
  position: relative; }

.mdi-li {
  position: absolute;
  left: -2.14285714em;
  width: 2.14285714em;
  top: 0.14285714em;
  text-align: center; }

.mdi-li.mdi-lg {
  left: -1.85714286em; }

.mdi-border {
  padding: .2em .25em .15em;
  border: solid 0.08em #eeeeee;
  border-radius: .1em; }

.mdi-spin {
  -webkit-animation: mdi-spin 2s infinite linear;
  animation: mdi-spin 2s infinite linear;
  -webkit-transform-origin: 50% 50%;
  transform-origin: 50% 50%; }

.mdi-pulse {
  -webkit-animation: mdi-spin 1s steps(8) infinite;
  animation: mdi-spin 1s steps(8) infinite;
  -webkit-transform-origin: 50% 50%;
  transform-origin: 50% 50%; }

@-webkit-keyframes mdi-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  100% {
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg); } }

@keyframes mdi-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }
  100% {
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg); } }

.mdi-rotate-90 {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
  -webkit-transform: rotate(90deg);
  transform: rotate(90deg); }

.mdi-rotate-180 {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=2);
  -webkit-transform: rotate(180deg);
  transform: rotate(180deg); }

.mdi-rotate-270 {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=3);
  -webkit-transform: rotate(270deg);
  transform: rotate(270deg); }

.mdi-flip-horizontal {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1);
  -webkit-transform: scale(-1, 1);
  transform: scale(-1, 1); }

.mdi-flip-vertical {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1);
  -webkit-transform: scale(1, -1);
  transform: scale(1, -1); }

:root .mdi-rotate-90,
:root .mdi-rotate-180,
:root .mdi-rotate-270,
:root .mdi-flip-horizontal,
:root .mdi-flip-vertical {
  -webkit-filter: none;
          filter: none; }

.mdi-stack {
  position: relative;
  display: inline-block;
  width: 2em;
  height: 2em;
  line-height: 2em;
  vertical-align: middle; }

.mdi-stack-1x,
.mdi-stack-2x {
  position: absolute;
  left: 0;
  width: 100%;
  text-align: center; }

.mdi-stack-1x {
  line-height: inherit; }

.mdi-stack-2x {
  font-size: 2em; }

.mdi-inverse {
  color: #ffffff; }

/* Start Icons */
.mdi-action-3d-rotation:before {
  content: "\e600"; }

.mdi-action-accessibility:before {
  content: "\e601"; }

.mdi-action-account-balance-wallet:before {
  content: "\e602"; }

.mdi-action-account-balance:before {
  content: "\e603"; }

.mdi-action-account-box:before {
  content: "\e604"; }

.mdi-action-account-child:before {
  content: "\e605"; }

.mdi-action-account-circle:before {
  content: "\e606"; }

.mdi-action-add-shopping-cart:before {
  content: "\e607"; }

.mdi-action-alarm-add:before {
  content: "\e608"; }

.mdi-action-alarm-off:before {
  content: "\e609"; }

.mdi-action-alarm-on:before {
  content: "\e60a"; }

.mdi-action-alarm:before {
  content: "\e60b"; }

.mdi-action-android:before {
  content: "\e60c"; }

.mdi-action-announcement:before {
  content: "\e60d"; }

.mdi-action-aspect-ratio:before {
  content: "\e60e"; }

.mdi-action-assessment:before {
  content: "\e60f"; }

.mdi-action-assignment-ind:before {
  content: "\e610"; }

.mdi-action-assignment-late:before {
  content: "\e611"; }

.mdi-action-assignment-return:before {
  content: "\e612"; }

.mdi-action-assignment-returned:before {
  content: "\e613"; }

.mdi-action-assignment-turned-in:before {
  content: "\e614"; }

.mdi-action-assignment:before {
  content: "\e615"; }

.mdi-action-autorenew:before {
  content: "\e616"; }

.mdi-action-backup:before {
  content: "\e617"; }

.mdi-action-book:before {
  content: "\e618"; }

.mdi-action-bookmark-outline:before {
  content: "\e619"; }

.mdi-action-bookmark:before {
  content: "\e61a"; }

.mdi-action-bug-report:before {
  content: "\e61b"; }

.mdi-action-cached:before {
  content: "\e61c"; }

.mdi-action-check-circle:before {
  content: "\e61d"; }

.mdi-action-class:before {
  content: "\e61e"; }

.mdi-action-credit-card:before {
  content: "\e61f"; }

.mdi-action-dashboard:before {
  content: "\e620"; }

.mdi-action-delete:before {
  content: "\e621"; }

.mdi-action-description:before {
  content: "\e622"; }

.mdi-action-dns:before {
  content: "\e623"; }

.mdi-action-done-all:before {
  content: "\e624"; }

.mdi-action-done:before {
  content: "\e625"; }

.mdi-action-event:before {
  content: "\e626"; }

.mdi-action-exit-to-app:before {
  content: "\e627"; }

.mdi-action-explore:before {
  content: "\e628"; }

.mdi-action-extension:before {
  content: "\e629"; }

.mdi-action-face-unlock:before {
  content: "\e62a"; }

.mdi-action-favorite-outline:before {
  content: "\e62b"; }

.mdi-action-favorite:before {
  content: "\e62c"; }

.mdi-action-find-in-page:before {
  content: "\e62d"; }

.mdi-action-find-replace:before {
  content: "\e62e"; }

.mdi-action-flip-to-back:before {
  content: "\e62f"; }

.mdi-action-flip-to-front:before {
  content: "\e630"; }

.mdi-action-get-app:before {
  content: "\e631"; }

.mdi-action-grade:before {
  content: "\e632"; }

.mdi-action-group-work:before {
  content: "\e633"; }

.mdi-action-help:before {
  content: "\e634"; }

.mdi-action-highlight-remove:before {
  content: "\e635"; }

.mdi-action-history:before {
  content: "\e636"; }

.mdi-action-home:before {
  content: "\e637"; }

.mdi-action-https:before {
  content: "\e638"; }

.mdi-action-info-outline:before {
  content: "\e639"; }

.mdi-action-info:before {
  content: "\e63a"; }

.mdi-action-input:before {
  content: "\e63b"; }

.mdi-action-invert-colors:before {
  content: "\e63c"; }

.mdi-action-label-outline:before {
  content: "\e63d"; }

.mdi-action-label:before {
  content: "\e63e"; }

.mdi-action-language:before {
  content: "\e63f"; }

.mdi-action-launch:before {
  content: "\e640"; }

.mdi-action-list:before {
  content: "\e641"; }

.mdi-action-lock-open:before {
  content: "\e642"; }

.mdi-action-lock-outline:before {
  content: "\e643"; }

.mdi-action-lock:before {
  content: "\e644"; }

.mdi-action-loyalty:before {
  content: "\e645"; }

.mdi-action-markunread-mailbox:before {
  content: "\e646"; }

.mdi-action-note-add:before {
  content: "\e647"; }

.mdi-action-open-in-browser:before {
  content: "\e648"; }

.mdi-action-open-in-new:before {
  content: "\e649"; }

.mdi-action-open-with:before {
  content: "\e64a"; }

.mdi-action-pageview:before {
  content: "\e64b"; }

.mdi-action-payment:before {
  content: "\e64c"; }

.mdi-action-perm-camera-mic:before {
  content: "\e64d"; }

.mdi-action-perm-contact-cal:before {
  content: "\e64e"; }

.mdi-action-perm-data-setting:before {
  content: "\e64f"; }

.mdi-action-perm-device-info:before {
  content: "\e650"; }

.mdi-action-perm-identity:before {
  content: "\e651"; }

.mdi-action-perm-media:before {
  content: "\e652"; }

.mdi-action-perm-phone-msg:before {
  content: "\e653"; }

.mdi-action-perm-scan-wifi:before {
  content: "\e654"; }

.mdi-action-picture-in-picture:before {
  content: "\e655"; }

.mdi-action-polymer:before {
  content: "\e656"; }

.mdi-action-print:before {
  content: "\e657"; }

.mdi-action-query-builder:before {
  content: "\e658"; }

.mdi-action-question-answer:before {
  content: "\e659"; }

.mdi-action-receipt:before {
  content: "\e65a"; }

.mdi-action-redeem:before {
  content: "\e65b"; }

.mdi-action-reorder:before {
  content: "\e65c"; }

.mdi-action-report-problem:before {
  content: "\e65d"; }

.mdi-action-restore:before {
  content: "\e65e"; }

.mdi-action-room:before {
  content: "\e65f"; }

.mdi-action-schedule:before {
  content: "\e660"; }

.mdi-action-search:before {
  content: "\e661"; }

.mdi-action-settings-applications:before {
  content: "\e662"; }

.mdi-action-settings-backup-restore:before {
  content: "\e663"; }

.mdi-action-settings-bluetooth:before {
  content: "\e664"; }

.mdi-action-settings-cell:before {
  content: "\e665"; }

.mdi-action-settings-display:before {
  content: "\e666"; }

.mdi-action-settings-ethernet:before {
  content: "\e667"; }

.mdi-action-settings-input-antenna:before {
  content: "\e668"; }

.mdi-action-settings-input-component:before {
  content: "\e669"; }

.mdi-action-settings-input-composite:before {
  content: "\e66a"; }

.mdi-action-settings-input-hdmi:before {
  content: "\e66b"; }

.mdi-action-settings-input-svideo:before {
  content: "\e66c"; }

.mdi-action-settings-overscan:before {
  content: "\e66d"; }

.mdi-action-settings-phone:before {
  content: "\e66e"; }

.mdi-action-settings-power:before {
  content: "\e66f"; }

.mdi-action-settings-remote:before {
  content: "\e670"; }

.mdi-action-settings-voice:before {
  content: "\e671"; }

.mdi-action-settings:before {
  content: "\e672"; }

.mdi-action-shop-two:before {
  content: "\e673"; }

.mdi-action-shop:before {
  content: "\e674"; }

.mdi-action-shopping-basket:before {
  content: "\e675"; }

.mdi-action-shopping-cart:before {
  content: "\e676"; }

.mdi-action-speaker-notes:before {
  content: "\e677"; }

.mdi-action-spellcheck:before {
  content: "\e678"; }

.mdi-action-star-rate:before {
  content: "\e679"; }

.mdi-action-stars:before {
  content: "\e67a"; }

.mdi-action-store:before {
  content: "\e67b"; }

.mdi-action-subject:before {
  content: "\e67c"; }

.mdi-action-supervisor-account:before {
  content: "\e67d"; }

.mdi-action-swap-horiz:before {
  content: "\e67e"; }

.mdi-action-swap-vert-circle:before {
  content: "\e67f"; }

.mdi-action-swap-vert:before {
  content: "\e680"; }

.mdi-action-system-update-tv:before {
  content: "\e681"; }

.mdi-action-tab-unselected:before {
  content: "\e682"; }

.mdi-action-tab:before {
  content: "\e683"; }

.mdi-action-theaters:before {
  content: "\e684"; }

.mdi-action-thumb-down:before {
  content: "\e685"; }

.mdi-action-thumb-up:before {
  content: "\e686"; }

.mdi-action-thumbs-up-down:before {
  content: "\e687"; }

.mdi-action-toc:before {
  content: "\e688"; }

.mdi-action-today:before {
  content: "\e689"; }

.mdi-action-track-changes:before {
  content: "\e68a"; }

.mdi-action-translate:before {
  content: "\e68b"; }

.mdi-action-trending-down:before {
  content: "\e68c"; }

.mdi-action-trending-neutral:before {
  content: "\e68d"; }

.mdi-action-trending-up:before {
  content: "\e68e"; }

.mdi-action-turned-in-not:before {
  content: "\e68f"; }

.mdi-action-turned-in:before {
  content: "\e690"; }

.mdi-action-verified-user:before {
  content: "\e691"; }

.mdi-action-view-agenda:before {
  content: "\e692"; }

.mdi-action-view-array:before {
  content: "\e693"; }

.mdi-action-view-carousel:before {
  content: "\e694"; }

.mdi-action-view-column:before {
  content: "\e695"; }

.mdi-action-view-day:before {
  content: "\e696"; }

.mdi-action-view-headline:before {
  content: "\e697"; }

.mdi-action-view-list:before {
  content: "\e698"; }

.mdi-action-view-module:before {
  content: "\e699"; }

.mdi-action-view-quilt:before {
  content: "\e69a"; }

.mdi-action-view-stream:before {
  content: "\e69b"; }

.mdi-action-view-week:before {
  content: "\e69c"; }

.mdi-action-visibility-off:before {
  content: "\e69d"; }

.mdi-action-visibility:before {
  content: "\e69e"; }

.mdi-action-wallet-giftcard:before {
  content: "\e69f"; }

.mdi-action-wallet-membership:before {
  content: "\e6a0"; }

.mdi-action-wallet-travel:before {
  content: "\e6a1"; }

.mdi-action-work:before {
  content: "\e6a2"; }

.mdi-alert-error:before {
  content: "\e6a3"; }

.mdi-alert-warning:before {
  content: "\e6a4"; }

.mdi-av-album:before {
  content: "\e6a5"; }

.mdi-av-closed-caption:before {
  content: "\e6a6"; }

.mdi-av-equalizer:before {
  content: "\e6a7"; }

.mdi-av-explicit:before {
  content: "\e6a8"; }

.mdi-av-fast-forward:before {
  content: "\e6a9"; }

.mdi-av-fast-rewind:before {
  content: "\e6aa"; }

.mdi-av-games:before {
  content: "\e6ab"; }

.mdi-av-hearing:before {
  content: "\e6ac"; }

.mdi-av-high-quality:before {
  content: "\e6ad"; }

.mdi-av-loop:before {
  content: "\e6ae"; }

.mdi-av-mic-none:before {
  content: "\e6af"; }

.mdi-av-mic-off:before {
  content: "\e6b0"; }

.mdi-av-mic:before {
  content: "\e6b1"; }

.mdi-av-movie:before {
  content: "\e6b2"; }

.mdi-av-my-library-add:before {
  content: "\e6b3"; }

.mdi-av-my-library-books:before {
  content: "\e6b4"; }

.mdi-av-my-library-music:before {
  content: "\e6b5"; }

.mdi-av-new-releases:before {
  content: "\e6b6"; }

.mdi-av-not-interested:before {
  content: "\e6b7"; }

.mdi-av-pause-circle-fill:before {
  content: "\e6b8"; }

.mdi-av-pause-circle-outline:before {
  content: "\e6b9"; }

.mdi-av-pause:before {
  content: "\e6ba"; }

.mdi-av-play-arrow:before {
  content: "\e6bb"; }

.mdi-av-play-circle-fill:before {
  content: "\e6bc"; }

.mdi-av-play-circle-outline:before {
  content: "\e6bd"; }

.mdi-av-play-shopping-bag:before {
  content: "\e6be"; }

.mdi-av-playlist-add:before {
  content: "\e6bf"; }

.mdi-av-queue-music:before {
  content: "\e6c0"; }

.mdi-av-queue:before {
  content: "\e6c1"; }

.mdi-av-radio:before {
  content: "\e6c2"; }

.mdi-av-recent-actors:before {
  content: "\e6c3"; }

.mdi-av-repeat-one:before {
  content: "\e6c4"; }

.mdi-av-repeat:before {
  content: "\e6c5"; }

.mdi-av-replay:before {
  content: "\e6c6"; }

.mdi-av-shuffle:before {
  content: "\e6c7"; }

.mdi-av-skip-next:before {
  content: "\e6c8"; }

.mdi-av-skip-previous:before {
  content: "\e6c9"; }

.mdi-av-snooze:before {
  content: "\e6ca"; }

.mdi-av-stop:before {
  content: "\e6cb"; }

.mdi-av-subtitles:before {
  content: "\e6cc"; }

.mdi-av-surround-sound:before {
  content: "\e6cd"; }

.mdi-av-timer:before {
  content: "\e6ce"; }

.mdi-av-video-collection:before {
  content: "\e6cf"; }

.mdi-av-videocam-off:before {
  content: "\e6d0"; }

.mdi-av-videocam:before {
  content: "\e6d1"; }

.mdi-av-volume-down:before {
  content: "\e6d2"; }

.mdi-av-volume-mute:before {
  content: "\e6d3"; }

.mdi-av-volume-off:before {
  content: "\e6d4"; }

.mdi-av-volume-up:before {
  content: "\e6d5"; }

.mdi-av-web:before {
  content: "\e6d6"; }

.mdi-communication-business:before {
  content: "\e6d7"; }

.mdi-communication-call-end:before {
  content: "\e6d8"; }

.mdi-communication-call-made:before {
  content: "\e6d9"; }

.mdi-communication-call-merge:before {
  content: "\e6da"; }

.mdi-communication-call-missed:before {
  content: "\e6db"; }

.mdi-communication-call-received:before {
  content: "\e6dc"; }

.mdi-communication-call-split:before {
  content: "\e6dd"; }

.mdi-communication-call:before {
  content: "\e6de"; }

.mdi-communication-chat:before {
  content: "\e6df"; }

.mdi-communication-clear-all:before {
  content: "\e6e0"; }

.mdi-communication-comment:before {
  content: "\e6e1"; }

.mdi-communication-contacts:before {
  content: "\e6e2"; }

.mdi-communication-dialer-sip:before {
  content: "\e6e3"; }

.mdi-communication-dialpad:before {
  content: "\e6e4"; }

.mdi-communication-dnd-on:before {
  content: "\e6e5"; }

.mdi-communication-email:before {
  content: "\e6e6"; }

.mdi-communication-forum:before {
  content: "\e6e7"; }

.mdi-communication-import-export:before {
  content: "\e6e8"; }

.mdi-communication-invert-colors-off:before {
  content: "\e6e9"; }

.mdi-communication-invert-colors-on:before {
  content: "\e6ea"; }

.mdi-communication-live-help:before {
  content: "\e6eb"; }

.mdi-communication-location-off:before {
  content: "\e6ec"; }

.mdi-communication-location-on:before {
  content: "\e6ed"; }

.mdi-communication-message:before {
  content: "\e6ee"; }

.mdi-communication-messenger:before {
  content: "\e6ef"; }

.mdi-communication-no-sim:before {
  content: "\e6f0"; }

.mdi-communication-phone:before {
  content: "\e6f1"; }

.mdi-communication-portable-wifi-off:before {
  content: "\e6f2"; }

.mdi-communication-quick-contacts-dialer:before {
  content: "\e6f3"; }

.mdi-communication-quick-contacts-mail:before {
  content: "\e6f4"; }

.mdi-communication-ring-volume:before {
  content: "\e6f5"; }

.mdi-communication-stay-current-landscape:before {
  content: "\e6f6"; }

.mdi-communication-stay-current-portrait:before {
  content: "\e6f7"; }

.mdi-communication-stay-primary-landscape:before {
  content: "\e6f8"; }

.mdi-communication-stay-primary-portrait:before {
  content: "\e6f9"; }

.mdi-communication-swap-calls:before {
  content: "\e6fa"; }

.mdi-communication-textsms:before {
  content: "\e6fb"; }

.mdi-communication-voicemail:before {
  content: "\e6fc"; }

.mdi-communication-vpn-key:before {
  content: "\e6fd"; }

.mdi-content-add-box:before {
  content: "\e6fe"; }

.mdi-content-add-circle-outline:before {
  content: "\e6ff"; }

.mdi-content-add-circle:before {
  content: "\e700"; }

.mdi-content-add:before {
  content: "\e701"; }

.mdi-content-archive:before {
  content: "\e702"; }

.mdi-content-backspace:before {
  content: "\e703"; }

.mdi-content-block:before {
  content: "\e704"; }

.mdi-content-clear:before {
  content: "\e705"; }

.mdi-content-content-copy:before {
  content: "\e706"; }

.mdi-content-content-cut:before {
  content: "\e707"; }

.mdi-content-content-paste:before {
  content: "\e708"; }

.mdi-content-create:before {
  content: "\e709"; }

.mdi-content-drafts:before {
  content: "\e70a"; }

.mdi-content-filter-list:before {
  content: "\e70b"; }

.mdi-content-flag:before {
  content: "\e70c"; }

.mdi-content-forward:before {
  content: "\e70d"; }

.mdi-content-gesture:before {
  content: "\e70e"; }

.mdi-content-inbox:before {
  content: "\e70f"; }

.mdi-content-link:before {
  content: "\e710"; }

.mdi-content-mail:before {
  content: "\e711"; }

.mdi-content-markunread:before {
  content: "\e712"; }

.mdi-content-redo:before {
  content: "\e713"; }

.mdi-content-remove-circle-outline:before {
  content: "\e714"; }

.mdi-content-remove-circle:before {
  content: "\e715"; }

.mdi-content-remove:before {
  content: "\e716"; }

.mdi-content-reply-all:before {
  content: "\e717"; }

.mdi-content-reply:before {
  content: "\e718"; }

.mdi-content-report:before {
  content: "\e719"; }

.mdi-content-save:before {
  content: "\e71a"; }

.mdi-content-select-all:before {
  content: "\e71b"; }

.mdi-content-send:before {
  content: "\e71c"; }

.mdi-content-sort:before {
  content: "\e71d"; }

.mdi-content-text-format:before {
  content: "\e71e"; }

.mdi-content-undo:before {
  content: "\e71f"; }

.mdi-editor-attach-file:before {
  content: "\e776"; }

.mdi-editor-attach-money:before {
  content: "\e777"; }

.mdi-editor-border-all:before {
  content: "\e778"; }

.mdi-editor-border-bottom:before {
  content: "\e779"; }

.mdi-editor-border-clear:before {
  content: "\e77a"; }

.mdi-editor-border-color:before {
  content: "\e77b"; }

.mdi-editor-border-horizontal:before {
  content: "\e77c"; }

.mdi-editor-border-inner:before {
  content: "\e77d"; }

.mdi-editor-border-left:before {
  content: "\e77e"; }

.mdi-editor-border-outer:before {
  content: "\e77f"; }

.mdi-editor-border-right:before {
  content: "\e780"; }

.mdi-editor-border-style:before {
  content: "\e781"; }

.mdi-editor-border-top:before {
  content: "\e782"; }

.mdi-editor-border-vertical:before {
  content: "\e783"; }

.mdi-editor-format-align-center:before {
  content: "\e784"; }

.mdi-editor-format-align-justify:before {
  content: "\e785"; }

.mdi-editor-format-align-left:before {
  content: "\e786"; }

.mdi-editor-format-align-right:before {
  content: "\e787"; }

.mdi-editor-format-bold:before {
  content: "\e788"; }

.mdi-editor-format-clear:before {
  content: "\e789"; }

.mdi-editor-format-color-fill:before {
  content: "\e78a"; }

.mdi-editor-format-color-reset:before {
  content: "\e78b"; }

.mdi-editor-format-color-text:before {
  content: "\e78c"; }

.mdi-editor-format-indent-decrease:before {
  content: "\e78d"; }

.mdi-editor-format-indent-increase:before {
  content: "\e78e"; }

.mdi-editor-format-italic:before {
  content: "\e78f"; }

.mdi-editor-format-line-spacing:before {
  content: "\e790"; }

.mdi-editor-format-list-bulleted:before {
  content: "\e791"; }

.mdi-editor-format-list-numbered:before {
  content: "\e792"; }

.mdi-editor-format-paint:before {
  content: "\e793"; }

.mdi-editor-format-quote:before {
  content: "\e794"; }

.mdi-editor-format-size:before {
  content: "\e795"; }

.mdi-editor-format-strikethrough:before {
  content: "\e796"; }

.mdi-editor-format-textdirection-l-to-r:before {
  content: "\e797"; }

.mdi-editor-format-textdirection-r-to-l:before {
  content: "\e798"; }

.mdi-editor-format-underline:before {
  content: "\e799"; }

.mdi-editor-functions:before {
  content: "\e79a"; }

.mdi-editor-insert-chart:before {
  content: "\e79b"; }

.mdi-editor-insert-comment:before {
  content: "\e79c"; }

.mdi-editor-insert-drive-file:before {
  content: "\e79d"; }

.mdi-editor-insert-emoticon:before {
  content: "\e79e"; }

.mdi-editor-insert-invitation:before {
  content: "\e79f"; }

.mdi-editor-insert-link:before {
  content: "\e7a0"; }

.mdi-editor-insert-photo:before {
  content: "\e7a1"; }

.mdi-editor-merge-type:before {
  content: "\e7a2"; }

.mdi-editor-mode-comment:before {
  content: "\e7a3"; }

.mdi-editor-mode-edit:before {
  content: "\e7a4"; }

.mdi-editor-publish:before {
  content: "\e7a5"; }

.mdi-editor-vertical-align-bottom:before {
  content: "\e7a6"; }

.mdi-editor-vertical-align-center:before {
  content: "\e7a7"; }

.mdi-editor-vertical-align-top:before {
  content: "\e7a8"; }

.mdi-editor-wrap-text:before {
  content: "\e7a9"; }

.mdi-file-attachment:before {
  content: "\e7aa"; }

.mdi-file-cloud-circle:before {
  content: "\e7ab"; }

.mdi-file-cloud-done:before {
  content: "\e7ac"; }

.mdi-file-cloud-download:before {
  content: "\e7ad"; }

.mdi-file-cloud-off:before {
  content: "\e7ae"; }

.mdi-file-cloud-queue:before {
  content: "\e7af"; }

.mdi-file-cloud-upload:before {
  content: "\e7b0"; }

.mdi-file-cloud:before {
  content: "\e7b1"; }

.mdi-file-file-download:before {
  content: "\e7b2"; }

.mdi-file-file-upload:before {
  content: "\e7b3"; }

.mdi-file-folder-open:before {
  content: "\e7b4"; }

.mdi-file-folder-shared:before {
  content: "\e7b5"; }

.mdi-file-folder:before {
  content: "\e7b6"; }

.mdi-device-access-alarm:before {
  content: "\e720"; }

.mdi-device-access-alarms:before {
  content: "\e721"; }

.mdi-device-access-time:before {
  content: "\e722"; }

.mdi-device-add-alarm:before {
  content: "\e723"; }

.mdi-device-airplanemode-off:before {
  content: "\e724"; }

.mdi-device-airplanemode-on:before {
  content: "\e725"; }

.mdi-device-battery-20:before {
  content: "\e726"; }

.mdi-device-battery-30:before {
  content: "\e727"; }

.mdi-device-battery-50:before {
  content: "\e728"; }

.mdi-device-battery-60:before {
  content: "\e729"; }

.mdi-device-battery-80:before {
  content: "\e72a"; }

.mdi-device-battery-90:before {
  content: "\e72b"; }

.mdi-device-battery-alert:before {
  content: "\e72c"; }

.mdi-device-battery-charging-20:before {
  content: "\e72d"; }

.mdi-device-battery-charging-30:before {
  content: "\e72e"; }

.mdi-device-battery-charging-50:before {
  content: "\e72f"; }

.mdi-device-battery-charging-60:before {
  content: "\e730"; }

.mdi-device-battery-charging-80:before {
  content: "\e731"; }

.mdi-device-battery-charging-90:before {
  content: "\e732"; }

.mdi-device-battery-charging-full:before {
  content: "\e733"; }

.mdi-device-battery-full:before {
  content: "\e734"; }

.mdi-device-battery-std:before {
  content: "\e735"; }

.mdi-device-battery-unknown:before {
  content: "\e736"; }

.mdi-device-bluetooth-connected:before {
  content: "\e737"; }

.mdi-device-bluetooth-disabled:before {
  content: "\e738"; }

.mdi-device-bluetooth-searching:before {
  content: "\e739"; }

.mdi-device-bluetooth:before {
  content: "\e73a"; }

.mdi-device-brightness-auto:before {
  content: "\e73b"; }

.mdi-device-brightness-high:before {
  content: "\e73c"; }

.mdi-device-brightness-low:before {
  content: "\e73d"; }

.mdi-device-brightness-medium:before {
  content: "\e73e"; }

.mdi-device-data-usage:before {
  content: "\e73f"; }

.mdi-device-developer-mode:before {
  content: "\e740"; }

.mdi-device-devices:before {
  content: "\e741"; }

.mdi-device-dvr:before {
  content: "\e742"; }

.mdi-device-gps-fixed:before {
  content: "\e743"; }

.mdi-device-gps-not-fixed:before {
  content: "\e744"; }

.mdi-device-gps-off:before {
  content: "\e745"; }

.mdi-device-location-disabled:before {
  content: "\e746"; }

.mdi-device-location-searching:before {
  content: "\e747"; }

.mdi-device-multitrack-audio:before {
  content: "\e748"; }

.mdi-device-network-cell:before {
  content: "\e749"; }

.mdi-device-network-wifi:before {
  content: "\e74a"; }

.mdi-device-nfc:before {
  content: "\e74b"; }

.mdi-device-now-wallpaper:before {
  content: "\e74c"; }

.mdi-device-now-widgets:before {
  content: "\e74d"; }

.mdi-device-screen-lock-landscape:before {
  content: "\e74e"; }

.mdi-device-screen-lock-portrait:before {
  content: "\e74f"; }

.mdi-device-screen-lock-rotation:before {
  content: "\e750"; }

.mdi-device-screen-rotation:before {
  content: "\e751"; }

.mdi-device-sd-storage:before {
  content: "\e752"; }

.mdi-device-settings-system-daydream:before {
  content: "\e753"; }

.mdi-device-signal-cellular-0-bar:before {
  content: "\e754"; }

.mdi-device-signal-cellular-1-bar:before {
  content: "\e755"; }

.mdi-device-signal-cellular-2-bar:before {
  content: "\e756"; }

.mdi-device-signal-cellular-3-bar:before {
  content: "\e757"; }

.mdi-device-signal-cellular-4-bar:before {
  content: "\e758"; }

.mdi-signal-wifi-statusbar-connected-no-internet-after:before {
  content: "\e8f6"; }

.mdi-device-signal-cellular-connected-no-internet-0-bar:before {
  content: "\e759"; }

.mdi-device-signal-cellular-connected-no-internet-1-bar:before {
  content: "\e75a"; }

.mdi-device-signal-cellular-connected-no-internet-2-bar:before {
  content: "\e75b"; }

.mdi-device-signal-cellular-connected-no-internet-3-bar:before {
  content: "\e75c"; }

.mdi-device-signal-cellular-connected-no-internet-4-bar:before {
  content: "\e75d"; }

.mdi-device-signal-cellular-no-sim:before {
  content: "\e75e"; }

.mdi-device-signal-cellular-null:before {
  content: "\e75f"; }

.mdi-device-signal-cellular-off:before {
  content: "\e760"; }

.mdi-device-signal-wifi-0-bar:before {
  content: "\e761"; }

.mdi-device-signal-wifi-1-bar:before {
  content: "\e762"; }

.mdi-device-signal-wifi-2-bar:before {
  content: "\e763"; }

.mdi-device-signal-wifi-3-bar:before {
  content: "\e764"; }

.mdi-device-signal-wifi-4-bar:before {
  content: "\e765"; }

.mdi-device-signal-wifi-off:before {
  content: "\e766"; }

.mdi-device-signal-wifi-statusbar-1-bar:before {
  content: "\e767"; }

.mdi-device-signal-wifi-statusbar-2-bar:before {
  content: "\e768"; }

.mdi-device-signal-wifi-statusbar-3-bar:before {
  content: "\e769"; }

.mdi-device-signal-wifi-statusbar-4-bar:before {
  content: "\e76a"; }

.mdi-device-signal-wifi-statusbar-connected-no-internet-:before {
  content: "\e76b"; }

.mdi-device-signal-wifi-statusbar-connected-no-internet:before {
  content: "\e76f"; }

.mdi-device-signal-wifi-statusbar-connected-no-internet-2:before {
  content: "\e76c"; }

.mdi-device-signal-wifi-statusbar-connected-no-internet-3:before {
  content: "\e76d"; }

.mdi-device-signal-wifi-statusbar-connected-no-internet-4:before {
  content: "\e76e"; }

.mdi-signal-wifi-statusbar-not-connected-after:before {
  content: "\e8f7"; }

.mdi-device-signal-wifi-statusbar-not-connected:before {
  content: "\e770"; }

.mdi-device-signal-wifi-statusbar-null:before {
  content: "\e771"; }

.mdi-device-storage:before {
  content: "\e772"; }

.mdi-device-usb:before {
  content: "\e773"; }

.mdi-device-wifi-lock:before {
  content: "\e774"; }

.mdi-device-wifi-tethering:before {
  content: "\e775"; }

.mdi-hardware-cast-connected:before {
  content: "\e7b7"; }

.mdi-hardware-cast:before {
  content: "\e7b8"; }

.mdi-hardware-computer:before {
  content: "\e7b9"; }

.mdi-hardware-desktop-mac:before {
  content: "\e7ba"; }

.mdi-hardware-desktop-windows:before {
  content: "\e7bb"; }

.mdi-hardware-dock:before {
  content: "\e7bc"; }

.mdi-hardware-gamepad:before {
  content: "\e7bd"; }

.mdi-hardware-headset-mic:before {
  content: "\e7be"; }

.mdi-hardware-headset:before {
  content: "\e7bf"; }

.mdi-hardware-keyboard-alt:before {
  content: "\e7c0"; }

.mdi-hardware-keyboard-arrow-down:before {
  content: "\e7c1"; }

.mdi-hardware-keyboard-arrow-left:before {
  content: "\e7c2"; }

.mdi-hardware-keyboard-arrow-right:before {
  content: "\e7c3"; }

.mdi-hardware-keyboard-arrow-up:before {
  content: "\e7c4"; }

.mdi-hardware-keyboard-backspace:before {
  content: "\e7c5"; }

.mdi-hardware-keyboard-capslock:before {
  content: "\e7c6"; }

.mdi-hardware-keyboard-control:before {
  content: "\e7c7"; }

.mdi-hardware-keyboard-hide:before {
  content: "\e7c8"; }

.mdi-hardware-keyboard-return:before {
  content: "\e7c9"; }

.mdi-hardware-keyboard-tab:before {
  content: "\e7ca"; }

.mdi-hardware-keyboard-voice:before {
  content: "\e7cb"; }

.mdi-hardware-keyboard:before {
  content: "\e7cc"; }

.mdi-hardware-laptop-chromebook:before {
  content: "\e7cd"; }

.mdi-hardware-laptop-mac:before {
  content: "\e7ce"; }

.mdi-hardware-laptop-windows:before {
  content: "\e7cf"; }

.mdi-hardware-laptop:before {
  content: "\e7d0"; }

.mdi-hardware-memory:before {
  content: "\e7d1"; }

.mdi-hardware-mouse:before {
  content: "\e7d2"; }

.mdi-hardware-phone-android:before {
  content: "\e7d3"; }

.mdi-hardware-phone-iphone:before {
  content: "\e7d4"; }

.mdi-hardware-phonelink-off:before {
  content: "\e7d5"; }

.mdi-hardware-phonelink:before {
  content: "\e7d6"; }

.mdi-hardware-security:before {
  content: "\e7d7"; }

.mdi-hardware-sim-card:before {
  content: "\e7d8"; }

.mdi-hardware-smartphone:before {
  content: "\e7d9"; }

.mdi-hardware-speaker:before {
  content: "\e7da"; }

.mdi-hardware-tablet-android:before {
  content: "\e7db"; }

.mdi-hardware-tablet-mac:before {
  content: "\e7dc"; }

.mdi-hardware-tablet:before {
  content: "\e7dd"; }

.mdi-hardware-tv:before {
  content: "\e7de"; }

.mdi-hardware-watch:before {
  content: "\e7df"; }

.mdi-image-add-to-photos:before {
  content: "\e7e0"; }

.mdi-image-adjust:before {
  content: "\e7e1"; }

.mdi-image-assistant-photo:before {
  content: "\e7e2"; }

.mdi-image-audiotrack:before {
  content: "\e7e3"; }

.mdi-image-blur-circular:before {
  content: "\e7e4"; }

.mdi-image-blur-linear:before {
  content: "\e7e5"; }

.mdi-image-blur-off:before {
  content: "\e7e6"; }

.mdi-image-blur-on:before {
  content: "\e7e7"; }

.mdi-image-brightness-1:before {
  content: "\e7e8"; }

.mdi-image-brightness-2:before {
  content: "\e7e9"; }

.mdi-image-brightness-3:before {
  content: "\e7ea"; }

.mdi-image-brightness-4:before {
  content: "\e7eb"; }

.mdi-image-brightness-5:before {
  content: "\e7ec"; }

.mdi-image-brightness-6:before {
  content: "\e7ed"; }

.mdi-image-brightness-7:before {
  content: "\e7ee"; }

.mdi-image-brush:before {
  content: "\e7ef"; }

.mdi-image-camera-alt:before {
  content: "\e7f0"; }

.mdi-image-camera-front:before {
  content: "\e7f1"; }

.mdi-image-camera-rear:before {
  content: "\e7f2"; }

.mdi-image-camera-roll:before {
  content: "\e7f3"; }

.mdi-image-camera:before {
  content: "\e7f4"; }

.mdi-image-center-focus-strong:before {
  content: "\e7f5"; }

.mdi-image-center-focus-weak:before {
  content: "\e7f6"; }

.mdi-image-collections:before {
  content: "\e7f7"; }

.mdi-image-color-lens:before {
  content: "\e7f8"; }

.mdi-image-colorize:before {
  content: "\e7f9"; }

.mdi-image-compare:before {
  content: "\e7fa"; }

.mdi-image-control-point-duplicate:before {
  content: "\e7fb"; }

.mdi-image-control-point:before {
  content: "\e7fc"; }

.mdi-image-crop-3-2:before {
  content: "\e7fd"; }

.mdi-image-crop-5-4:before {
  content: "\e7fe"; }

.mdi-image-crop-7-5:before {
  content: "\e7ff"; }

.mdi-image-crop-16-9:before {
  content: "\e800"; }

.mdi-image-crop-din:before {
  content: "\e801"; }

.mdi-image-crop-free:before {
  content: "\e802"; }

.mdi-image-crop-landscape:before {
  content: "\e803"; }

.mdi-image-crop-original:before {
  content: "\e804"; }

.mdi-image-crop-portrait:before {
  content: "\e805"; }

.mdi-image-crop-square:before {
  content: "\e806"; }

.mdi-image-crop:before {
  content: "\e807"; }

.mdi-image-dehaze:before {
  content: "\e808"; }

.mdi-image-details:before {
  content: "\e809"; }

.mdi-image-edit:before {
  content: "\e80a"; }

.mdi-image-exposure-minus-1:before {
  content: "\e80b"; }

.mdi-image-exposure-minus-2:before {
  content: "\e80c"; }

.mdi-image-exposure-plus-1:before {
  content: "\e80d"; }

.mdi-image-exposure-plus-2:before {
  content: "\e80e"; }

.mdi-image-exposure-zero:before {
  content: "\e80f"; }

.mdi-image-exposure:before {
  content: "\e810"; }

.mdi-image-filter-1:before {
  content: "\e811"; }

.mdi-image-filter-2:before {
  content: "\e812"; }

.mdi-image-filter-3:before {
  content: "\e813"; }

.mdi-image-filter-4:before {
  content: "\e814"; }

.mdi-image-filter-5:before {
  content: "\e815"; }

.mdi-image-filter-6:before {
  content: "\e816"; }

.mdi-image-filter-7:before {
  content: "\e817"; }

.mdi-image-filter-8:before {
  content: "\e818"; }

.mdi-image-filter-9-plus:before {
  content: "\e819"; }

.mdi-image-filter-9:before {
  content: "\e81a"; }

.mdi-image-filter-b-and-w:before {
  content: "\e81b"; }

.mdi-image-filter-center-focus:before {
  content: "\e81c"; }

.mdi-image-filter-drama:before {
  content: "\e81d"; }

.mdi-image-filter-frames:before {
  content: "\e81e"; }

.mdi-image-filter-hdr:before {
  content: "\e81f"; }

.mdi-image-filter-none:before {
  content: "\e820"; }

.mdi-image-filter-tilt-shift:before {
  content: "\e821"; }

.mdi-image-filter-vintage:before {
  content: "\e822"; }

.mdi-image-filter:before {
  content: "\e823"; }

.mdi-image-flare:before {
  content: "\e824"; }

.mdi-image-flash-auto:before {
  content: "\e825"; }

.mdi-image-flash-off:before {
  content: "\e826"; }

.mdi-image-flash-on:before {
  content: "\e827"; }

.mdi-image-flip:before {
  content: "\e828"; }

.mdi-image-gradient:before {
  content: "\e829"; }

.mdi-image-grain:before {
  content: "\e82a"; }

.mdi-image-grid-off:before {
  content: "\e82b"; }

.mdi-image-grid-on:before {
  content: "\e82c"; }

.mdi-image-hdr-off:before {
  content: "\e82d"; }

.mdi-image-hdr-on:before {
  content: "\e82e"; }

.mdi-image-hdr-strong:before {
  content: "\e82f"; }

.mdi-image-hdr-weak:before {
  content: "\e830"; }

.mdi-image-healing:before {
  content: "\e831"; }

.mdi-image-image-aspect-ratio:before {
  content: "\e832"; }

.mdi-image-image:before {
  content: "\e833"; }

.mdi-image-iso:before {
  content: "\e834"; }

.mdi-image-landscape:before {
  content: "\e835"; }

.mdi-image-leak-add:before {
  content: "\e836"; }

.mdi-image-leak-remove:before {
  content: "\e837"; }

.mdi-image-lens:before {
  content: "\e838"; }

.mdi-image-looks-3:before {
  content: "\e839"; }

.mdi-image-looks-4:before {
  content: "\e83a"; }

.mdi-image-looks-5:before {
  content: "\e83b"; }

.mdi-image-looks-6:before {
  content: "\e83c"; }

.mdi-image-looks-one:before {
  content: "\e83d"; }

.mdi-image-looks-two:before {
  content: "\e83e"; }

.mdi-image-looks:before {
  content: "\e83f"; }

.mdi-image-loupe:before {
  content: "\e840"; }

.mdi-image-movie-creation:before {
  content: "\e841"; }

.mdi-image-nature-people:before {
  content: "\e842"; }

.mdi-image-nature:before {
  content: "\e843"; }

.mdi-image-navigate-before:before {
  content: "\e844"; }

.mdi-image-navigate-next:before {
  content: "\e845"; }

.mdi-image-palette:before {
  content: "\e846"; }

.mdi-image-panorama-fisheye:before {
  content: "\e847"; }

.mdi-image-panorama-horizontal:before {
  content: "\e848"; }

.mdi-image-panorama-vertical:before {
  content: "\e849"; }

.mdi-image-panorama-wide-angle:before {
  content: "\e84a"; }

.mdi-image-panorama:before {
  content: "\e84b"; }

.mdi-image-photo-album:before {
  content: "\e84c"; }

.mdi-image-photo-camera:before {
  content: "\e84d"; }

.mdi-image-photo-library:before {
  content: "\e84e"; }

.mdi-image-photo:before {
  content: "\e84f"; }

.mdi-image-portrait:before {
  content: "\e850"; }

.mdi-image-remove-red-eye:before {
  content: "\e851"; }

.mdi-image-rotate-left:before {
  content: "\e852"; }

.mdi-image-rotate-right:before {
  content: "\e853"; }

.mdi-image-slideshow:before {
  content: "\e854"; }

.mdi-image-straighten:before {
  content: "\e855"; }

.mdi-image-style:before {
  content: "\e856"; }

.mdi-image-switch-camera:before {
  content: "\e857"; }

.mdi-image-switch-video:before {
  content: "\e858"; }

.mdi-image-tag-faces:before {
  content: "\e859"; }

.mdi-image-texture:before {
  content: "\e85a"; }

.mdi-image-timelapse:before {
  content: "\e85b"; }

.mdi-image-timer-3:before {
  content: "\e85c"; }

.mdi-image-timer-10:before {
  content: "\e85d"; }

.mdi-image-timer-auto:before {
  content: "\e85e"; }

.mdi-image-timer-off:before {
  content: "\e85f"; }

.mdi-image-timer:before {
  content: "\e860"; }

.mdi-image-tonality:before {
  content: "\e861"; }

.mdi-image-transform:before {
  content: "\e862"; }

.mdi-image-tune:before {
  content: "\e863"; }

.mdi-image-wb-auto:before {
  content: "\e864"; }

.mdi-image-wb-cloudy:before {
  content: "\e865"; }

.mdi-image-wb-incandescent:before {
  content: "\e866"; }

.mdi-image-wb-irradescent:before {
  content: "\e867"; }

.mdi-image-wb-sunny:before {
  content: "\e868"; }

.mdi-maps-beenhere:before {
  content: "\e869"; }

.mdi-maps-directions-bike:before {
  content: "\e86a"; }

.mdi-maps-directions-bus:before {
  content: "\e86b"; }

.mdi-maps-directions-car:before {
  content: "\e86c"; }

.mdi-maps-directions-ferry:before {
  content: "\e86d"; }

.mdi-maps-directions-subway:before {
  content: "\e86e"; }

.mdi-maps-directions-train:before {
  content: "\e86f"; }

.mdi-maps-directions-transit:before {
  content: "\e870"; }

.mdi-maps-directions-walk:before {
  content: "\e871"; }

.mdi-maps-directions:before {
  content: "\e872"; }

.mdi-maps-flight:before {
  content: "\e873"; }

.mdi-maps-hotel:before {
  content: "\e874"; }

.mdi-maps-layers-clear:before {
  content: "\e875"; }

.mdi-maps-layers:before {
  content: "\e876"; }

.mdi-maps-local-airport:before {
  content: "\e877"; }

.mdi-maps-local-atm:before {
  content: "\e878"; }

.mdi-maps-local-attraction:before {
  content: "\e879"; }

.mdi-maps-local-bar:before {
  content: "\e87a"; }

.mdi-maps-local-cafe:before {
  content: "\e87b"; }

.mdi-maps-local-car-wash:before {
  content: "\e87c"; }

.mdi-maps-local-convenience-store:before {
  content: "\e87d"; }

.mdi-maps-local-drink:before {
  content: "\e87e"; }

.mdi-maps-local-florist:before {
  content: "\e87f"; }

.mdi-maps-local-gas-station:before {
  content: "\e880"; }

.mdi-maps-local-grocery-store:before {
  content: "\e881"; }

.mdi-maps-local-hospital:before {
  content: "\e882"; }

.mdi-maps-local-hotel:before {
  content: "\e883"; }

.mdi-maps-local-laundry-service:before {
  content: "\e884"; }

.mdi-maps-local-library:before {
  content: "\e885"; }

.mdi-maps-local-mall:before {
  content: "\e886"; }

.mdi-maps-local-movies:before {
  content: "\e887"; }

.mdi-maps-local-offer:before {
  content: "\e888"; }

.mdi-maps-local-parking:before {
  content: "\e889"; }

.mdi-maps-local-pharmacy:before {
  content: "\e88a"; }

.mdi-maps-local-phone:before {
  content: "\e88b"; }

.mdi-maps-local-pizza:before {
  content: "\e88c"; }

.mdi-maps-local-play:before {
  content: "\e88d"; }

.mdi-maps-local-post-office:before {
  content: "\e88e"; }

.mdi-maps-local-print-shop:before {
  content: "\e88f"; }

.mdi-maps-local-restaurant:before {
  content: "\e890"; }

.mdi-maps-local-see:before {
  content: "\e891"; }

.mdi-maps-local-shipping:before {
  content: "\e892"; }

.mdi-maps-local-taxi:before {
  content: "\e893"; }

.mdi-maps-location-history:before {
  content: "\e894"; }

.mdi-maps-map:before {
  content: "\e895"; }

.mdi-maps-my-location:before {
  content: "\e896"; }

.mdi-maps-navigation:before {
  content: "\e897"; }

.mdi-maps-pin-drop:before {
  content: "\e898"; }

.mdi-maps-place:before {
  content: "\e899"; }

.mdi-maps-rate-review:before {
  content: "\e89a"; }

.mdi-maps-restaurant-menu:before {
  content: "\e89b"; }

.mdi-maps-satellite:before {
  content: "\e89c"; }

.mdi-maps-store-mall-directory:before {
  content: "\e89d"; }

.mdi-maps-terrain:before {
  content: "\e89e"; }

.mdi-maps-traffic:before {
  content: "\e89f"; }

.mdi-navigation-apps:before {
  content: "\e8a0"; }

.mdi-navigation-arrow-back:before {
  content: "\e8a1"; }

.mdi-navigation-arrow-drop-down-circle:before {
  content: "\e8a2"; }

.mdi-navigation-arrow-drop-down:before {
  content: "\e8a3"; }

.mdi-navigation-arrow-drop-up:before {
  content: "\e8a4"; }

.mdi-navigation-arrow-forward:before {
  content: "\e8a5"; }

.mdi-navigation-cancel:before {
  content: "\e8a6"; }

.mdi-navigation-check:before {
  content: "\e8a7"; }

.mdi-navigation-chevron-left:before {
  content: "\e8a8"; }

.mdi-navigation-chevron-right:before {
  content: "\e8a9"; }

.mdi-navigation-close:before, .select2-container--default .select2-selection--multiple .select2-selection__choice__remove:before, .select2-container--default.select2-container--focus .select2-selection--multiple .select2-selection__choice__remove:before {
  content: "\e8aa"; }

.mdi-navigation-expand-less:before {
  content: "\e8ab"; }

.mdi-navigation-expand-more:before {
  content: "\e8ac"; }

.mdi-navigation-fullscreen-exit:before {
  content: "\e8ad"; }

.mdi-navigation-fullscreen:before {
  content: "\e8ae"; }

.mdi-navigation-menu:before {
  content: "\e8af"; }

.mdi-navigation-more-horiz:before {
  content: "\e8b0"; }

.mdi-navigation-more-vert:before {
  content: "\e8b1"; }

.mdi-navigation-refresh:before {
  content: "\e8b2"; }

.mdi-navigation-unfold-less:before {
  content: "\e8b3"; }

.mdi-navigation-unfold-more:before {
  content: "\e8b4"; }

.mdi-notification-adb:before {
  content: "\e8b5"; }

.mdi-notification-bluetooth-audio:before {
  content: "\e8b6"; }

.mdi-notification-disc-full:before {
  content: "\e8b7"; }

.mdi-notification-dnd-forwardslash:before {
  content: "\e8b8"; }

.mdi-notification-do-not-disturb:before {
  content: "\e8b9"; }

.mdi-notification-drive-eta:before {
  content: "\e8ba"; }

.mdi-notification-event-available:before {
  content: "\e8bb"; }

.mdi-notification-event-busy:before {
  content: "\e8bc"; }

.mdi-notification-event-note:before {
  content: "\e8bd"; }

.mdi-notification-folder-special:before {
  content: "\e8be"; }

.mdi-notification-mms:before {
  content: "\e8bf"; }

.mdi-notification-more:before {
  content: "\e8c0"; }

.mdi-notification-network-locked:before {
  content: "\e8c1"; }

.mdi-notification-phone-bluetooth-speaker:before {
  content: "\e8c2"; }

.mdi-notification-phone-forwarded:before {
  content: "\e8c3"; }

.mdi-notification-phone-in-talk:before {
  content: "\e8c4"; }

.mdi-notification-phone-locked:before {
  content: "\e8c5"; }

.mdi-notification-phone-missed:before {
  content: "\e8c6"; }

.mdi-notification-phone-paused:before {
  content: "\e8c7"; }

.mdi-notification-play-download:before {
  content: "\e8c8"; }

.mdi-notification-play-install:before {
  content: "\e8c9"; }

.mdi-notification-sd-card:before {
  content: "\e8ca"; }

.mdi-notification-sim-card-alert:before {
  content: "\e8cb"; }

.mdi-notification-sms-failed:before {
  content: "\e8cc"; }

.mdi-notification-sms:before {
  content: "\e8cd"; }

.mdi-notification-sync-disabled:before {
  content: "\e8ce"; }

.mdi-notification-sync-problem:before {
  content: "\e8cf"; }

.mdi-notification-sync:before {
  content: "\e8d0"; }

.mdi-notification-system-update:before {
  content: "\e8d1"; }

.mdi-notification-tap-and-play:before {
  content: "\e8d2"; }

.mdi-notification-time-to-leave:before {
  content: "\e8d3"; }

.mdi-notification-vibration:before {
  content: "\e8d4"; }

.mdi-notification-voice-chat:before {
  content: "\e8d5"; }

.mdi-notification-vpn-lock:before {
  content: "\e8d6"; }

.mdi-social-cake:before {
  content: "\e8d7"; }

.mdi-social-domain:before {
  content: "\e8d8"; }

.mdi-social-group-add:before {
  content: "\e8d9"; }

.mdi-social-group:before {
  content: "\e8da"; }

.mdi-social-location-city:before {
  content: "\e8db"; }

.mdi-social-mood:before {
  content: "\e8dc"; }

.mdi-social-notifications-none:before {
  content: "\e8dd"; }

.mdi-social-notifications-off:before {
  content: "\e8de"; }

.mdi-social-notifications-on:before {
  content: "\e8df"; }

.mdi-social-notifications-paused:before {
  content: "\e8e0"; }

.mdi-social-notifications:before {
  content: "\e8e1"; }

.mdi-social-pages:before {
  content: "\e8e2"; }

.mdi-social-party-mode:before {
  content: "\e8e3"; }

.mdi-social-people-outline:before {
  content: "\e8e4"; }

.mdi-social-people:before {
  content: "\e8e5"; }

.mdi-social-person-add:before {
  content: "\e8e6"; }

.mdi-social-person-outline:before {
  content: "\e8e7"; }

.mdi-social-person:before {
  content: "\e8e8"; }

.mdi-social-plus-one:before {
  content: "\e8e9"; }

.mdi-social-poll:before {
  content: "\e8ea"; }

.mdi-social-public:before {
  content: "\e8eb"; }

.mdi-social-school:before {
  content: "\e8ec"; }

.mdi-social-share:before {
  content: "\e8ed"; }

.mdi-social-whatshot:before {
  content: "\e8ee"; }

.mdi-toggle-check-box-outline-blank:before {
  content: "\e8ef"; }

.mdi-toggle-check-box:before {
  content: "\e8f0"; }

.mdi-toggle-radio-button-off:before {
  content: "\e8f1"; }

.mdi-toggle-radio-button-on:before {
  content: "\e8f2"; }

.mdi-toggle-star-half:before {
  content: "\e8f3"; }

.mdi-toggle-star-outline:before {
  content: "\e8f4"; }

.mdi-toggle-star:before {
  content: "\e8f5"; }

.container {
  margin: 0 auto;
  max-width: 1280px;
  width: 90%; }

@media only screen and (min-width: 601px) {
  .container {
    width: 85%; } }

@media only screen and (min-width: 993px) {
  .container {
    width: 70%; } }

.container .row {
  margin-left: -0.75rem;
  margin-right: -0.75rem; }

.section {
  padding-top: 1rem;
  padding-bottom: 1rem; }
  .section.no-pad {
    padding: 0; }
  .section.no-pad-bot {
    padding-bottom: 0; }
  .section.no-pad-top {
    padding-top: 0; }

.row {
  margin-left: auto;
  margin-right: auto;
  margin-bottom: 20px; }
  .row:after {
    content: "";
    display: table;
    clear: both; }
  .row .col {
    float: left;
    box-sizing: border-box;
    padding: 0 0.75rem; }
    .row .col.s1 {
      width: 8.3333333333%;
      margin-left: 0; }
    .row .col.s2 {
      width: 16.6666666667%;
      margin-left: 0; }
    .row .col.s3 {
      width: 25%;
      margin-left: 0; }
    .row .col.s4 {
      width: 33.3333333333%;
      margin-left: 0; }
    .row .col.s5 {
      width: 41.6666666667%;
      margin-left: 0; }
    .row .col.s6 {
      width: 50%;
      margin-left: 0; }
    .row .col.s7 {
      width: 58.3333333333%;
      margin-left: 0; }
    .row .col.s8 {
      width: 66.6666666667%;
      margin-left: 0; }
    .row .col.s9 {
      width: 75%;
      margin-left: 0; }
    .row .col.s10 {
      width: 83.3333333333%;
      margin-left: 0; }
    .row .col.s11 {
      width: 91.6666666667%;
      margin-left: 0; }
    .row .col.s12 {
      width: 100%;
      margin-left: 0; }
    .row .col.offset-s1 {
      margin-left: 8.3333333333%; }
    .row .col.offset-s2 {
      margin-left: 16.6666666667%; }
    .row .col.offset-s3 {
      margin-left: 25%; }
    .row .col.offset-s4 {
      margin-left: 33.3333333333%; }
    .row .col.offset-s5 {
      margin-left: 41.6666666667%; }
    .row .col.offset-s6 {
      margin-left: 50%; }
    .row .col.offset-s7 {
      margin-left: 58.3333333333%; }
    .row .col.offset-s8 {
      margin-left: 66.6666666667%; }
    .row .col.offset-s9 {
      margin-left: 75%; }
    .row .col.offset-s10 {
      margin-left: 83.3333333333%; }
    .row .col.offset-s11 {
      margin-left: 91.6666666667%; }
    .row .col.offset-s12 {
      margin-left: 100%; }
    @media only screen and (min-width: 601px) {
      .row .col.m1 {
        width: 8.3333333333%;
        margin-left: 0; }
      .row .col.m2 {
        width: 16.6666666667%;
        margin-left: 0; }
      .row .col.m3 {
        width: 25%;
        margin-left: 0; }
      .row .col.m4 {
        width: 33.3333333333%;
        margin-left: 0; }
      .row .col.m5 {
        width: 41.6666666667%;
        margin-left: 0; }
      .row .col.m6 {
        width: 50%;
        margin-left: 0; }
      .row .col.m7 {
        width: 58.3333333333%;
        margin-left: 0; }
      .row .col.m8 {
        width: 66.6666666667%;
        margin-left: 0; }
      .row .col.m9 {
        width: 75%;
        margin-left: 0; }
      .row .col.m10 {
        width: 83.3333333333%;
        margin-left: 0; }
      .row .col.m11 {
        width: 91.6666666667%;
        margin-left: 0; }
      .row .col.m12 {
        width: 100%;
        margin-left: 0; }
      .row .col.offset-m1 {
        margin-left: 8.3333333333%; }
      .row .col.offset-m2 {
        margin-left: 16.6666666667%; }
      .row .col.offset-m3 {
        margin-left: 25%; }
      .row .col.offset-m4 {
        margin-left: 33.3333333333%; }
      .row .col.offset-m5 {
        margin-left: 41.6666666667%; }
      .row .col.offset-m6 {
        margin-left: 50%; }
      .row .col.offset-m7 {
        margin-left: 58.3333333333%; }
      .row .col.offset-m8 {
        margin-left: 66.6666666667%; }
      .row .col.offset-m9 {
        margin-left: 75%; }
      .row .col.offset-m10 {
        margin-left: 83.3333333333%; }
      .row .col.offset-m11 {
        margin-left: 91.6666666667%; }
      .row .col.offset-m12 {
        margin-left: 100%; } }
    @media only screen and (min-width: 993px) {
      .row .col.l1 {
        width: 8.3333333333%;
        margin-left: 0; }
      .row .col.l2 {
        width: 16.6666666667%;
        margin-left: 0; }
      .row .col.l3 {
        width: 25%;
        margin-left: 0; }
      .row .col.l4 {
        width: 33.3333333333%;
        margin-left: 0; }
      .row .col.l5 {
        width: 41.6666666667%;
        margin-left: 0; }
      .row .col.l6 {
        width: 50%;
        margin-left: 0; }
      .row .col.l7 {
        width: 58.3333333333%;
        margin-left: 0; }
      .row .col.l8 {
        width: 66.6666666667%;
        margin-left: 0; }
      .row .col.l9 {
        width: 75%;
        margin-left: 0; }
      .row .col.l10 {
        width: 83.3333333333%;
        margin-left: 0; }
      .row .col.l11 {
        width: 91.6666666667%;
        margin-left: 0; }
      .row .col.l12 {
        width: 100%;
        margin-left: 0; }
      .row .col.offset-l1 {
        margin-left: 8.3333333333%; }
      .row .col.offset-l2 {
        margin-left: 16.6666666667%; }
      .row .col.offset-l3 {
        margin-left: 25%; }
      .row .col.offset-l4 {
        margin-left: 33.3333333333%; }
      .row .col.offset-l5 {
        margin-left: 41.6666666667%; }
      .row .col.offset-l6 {
        margin-left: 50%; }
      .row .col.offset-l7 {
        margin-left: 58.3333333333%; }
      .row .col.offset-l8 {
        margin-left: 66.6666666667%; }
      .row .col.offset-l9 {
        margin-left: 75%; }
      .row .col.offset-l10 {
        margin-left: 83.3333333333%; }
      .row .col.offset-l11 {
        margin-left: 91.6666666667%; }
      .row .col.offset-l12 {
        margin-left: 100%; } }

nav {
  color: #fff;
  background-color: #ee6e73;
  width: 100%;
  height: 56px;
  line-height: 56px; }
  nav a {
    color: #fff; }
  nav .nav-wrapper {
    position: relative;
    height: 100%; }
    nav .nav-wrapper i {
      display: block;
      font-size: 2rem; }
  @media only screen and (min-width: 993px) {
    nav a.button-collapse {
      display: none; } }
  nav .button-collapse {
    float: left;
    position: relative;
    z-index: 1;
    height: 56px; }
    nav .button-collapse i {
      font-size: 2.7rem;
      height: 56px;
      line-height: 56px; }
  nav .brand-logo {
    position: absolute;
    color: #fff;
    display: inline-block;
    font-size: 2.1rem;
    padding: 0;
    white-space: nowrap; }
    nav .brand-logo.center {
      left: 50%;
      -webkit-transform: translateX(-50%);
      transform: translateX(-50%); }
    @media only screen and (max-width: 992px) {
      nav .brand-logo {
        left: 50%;
        -webkit-transform: translateX(-50%);
        transform: translateX(-50%); } }
    nav .brand-logo.right {
      right: 0.5rem;
      padding: 0; }
  nav ul {
    margin: 0; }
    nav ul li {
      -webkit-transition: background-color 0.3s;
      transition: background-color 0.3s;
      float: left;
      padding: 0; }
      nav ul li:hover, nav ul li.active, nav ul .body-home .header .side-nav li.nav-home, .body-home .header .side-nav nav ul li.nav-home, nav ul .body-products .header .side-nav li.subnav-products, .body-products .header .side-nav nav ul li.subnav-products, nav ul .body-attributes .header .side-nav li.subnav-attributes, .body-attributes .header .side-nav nav ul li.subnav-attributes, nav ul .body-categories .header .side-nav li.subnav-categories, .body-categories .header .side-nav nav ul li.subnav-categories, nav ul .body-orders .header .side-nav li.subnav-orders, .body-orders .header .side-nav nav ul li.subnav-orders, nav ul .body-payments .header .side-nav li.subnav-payments, .body-payments .header .side-nav nav ul li.subnav-payments, nav ul .body-customers .header .side-nav li.subnav-customers, .body-customers .header .side-nav nav ul li.subnav-customers, nav ul .body-discounts .header .side-nav li.subnav-discounts, .body-discounts .header .side-nav nav ul li.subnav-discounts, nav ul .body-vouchers .header .side-nav li.subnav-vouchers, .body-vouchers .header .side-nav nav ul li.subnav-vouchers, nav ul .body-sales .header .side-nav li.subnav-sales, .body-sales .header .side-nav nav ul li.subnav-sales {
        background-color: rgba(0, 0, 0, 0.1); }
    nav ul a {
      font-size: 1rem;
      color: #fff;
      display: block;
      padding: 0 15px; }
    nav ul.left {
      float: left; }
  nav .input-field {
    margin: 0; }
    nav .input-field input {
      height: 100%;
      font-size: 1.2rem;
      border: none;
      padding-left: 2rem; }
      nav .input-field input:focus, nav .input-field input[type=text]:valid, nav .input-field input[type=password]:valid, nav .input-field input[type=email]:valid, nav .input-field input[type=url]:valid, nav .input-field input[type=date]:valid {
        border: none;
        box-shadow: none; }
    nav .input-field label {
      top: 0;
      left: 0; }
      nav .input-field label i {
        color: rgba(255, 255, 255, 0.7);
        -webkit-transition: color 0.3s;
        transition: color 0.3s; }
      nav .input-field label.active i, nav .input-field form label i, form nav .input-field label i {
        color: #fff; }
      nav .input-field label.active, nav .input-field form label, form nav .input-field label {
        -webkit-transform: translateY(0);
        transform: translateY(0); }

.navbar-fixed {
  position: relative;
  height: 56px;
  z-index: 998; }
  .navbar-fixed nav {
    position: fixed; }

@media only screen and (min-width: 601px) {
  nav, nav .nav-wrapper i, nav a.button-collapse, nav a.button-collapse i {
    height: 64px;
    line-height: 64px; }
  .navbar-fixed {
    height: 64px; } }

@font-face {
  font-family: "Roboto";
  src: url("../fonts/Roboto-Thin.woff2") format("woff2"), url("../fonts/Roboto-Thin.woff") format("woff"), url("../fonts/Roboto-Thin.ttf") format("truetype");
  font-weight: 200; }

@font-face {
  font-family: "Roboto";
  src: url("../fonts/Roboto-Light.woff2") format("woff2"), url("../fonts/Roboto-Light.woff") format("woff"), url("../fonts/Roboto-Light.ttf") format("truetype");
  font-weight: 300; }

@font-face {
  font-family: "Roboto";
  src: url("../fonts/Roboto-Regular.woff2") format("woff2"), url("../fonts/Roboto-Regular.woff") format("woff"), url("../fonts/Roboto-Regular.ttf") format("truetype");
  font-weight: 400; }

@font-face {
  font-family: "Roboto";
  src: url("../fonts/Roboto-Medium.woff2") format("woff2"), url("../fonts/Roboto-Medium.woff") format("woff"), url("../fonts/Roboto-Medium.ttf") format("truetype");
  font-weight: 500; }

@font-face {
  font-family: "Roboto";
  src: url("../fonts/Roboto-Bold.woff2") format("woff2"), url("../fonts/Roboto-Bold.woff") format("woff"), url("../fonts/Roboto-Bold.ttf") format("truetype");
  font-weight: 700; }

a {
  text-decoration: none; }

html {
  line-height: 1.5;
  font-family: "Roboto", sans-serif;
  font-weight: normal;
  color: rgba(0, 0, 0, 0.87); }
  @media only screen and (min-width: 0) {
    html {
      font-size: 14px; } }
  @media only screen and (min-width: 992px) {
    html {
      font-size: 14.5px; } }
  @media only screen and (min-width: 1200px) {
    html {
      font-size: 15px; } }

h1, h2, h3, h4, h5, h6 {
  font-weight: 400;
  line-height: 1.1; }

h1 a, h2 a, h3 a, h4 a, h5 a, h6 a {
  font-weight: inherit; }

h1 {
  font-size: 4.2rem;
  line-height: 110%;
  margin: 2.1rem 0 1.68rem 0; }

h2 {
  font-size: 3.56rem;
  line-height: 110%;
  margin: 1.78rem 0 1.424rem 0; }

h3 {
  font-size: 2.92rem;
  line-height: 110%;
  margin: 1.46rem 0 1.168rem 0; }

h4 {
  font-size: 2.28rem;
  line-height: 110%;
  margin: 1.14rem 0 0.912rem 0; }

h5 {
  font-size: 1.64rem;
  line-height: 110%;
  margin: 0.82rem 0 0.656rem 0; }

h6 {
  font-size: 1rem;
  line-height: 110%;
  margin: 0.5rem 0 0.4rem 0; }

em {
  font-style: italic; }

strong {
  font-weight: 500; }

small {
  font-size: 75%; }

.light, footer.page-footer .footer-copyright {
  font-weight: 300; }

.thin {
  font-weight: 200; }

.flow-text {
  font-weight: 300; }
  @media only screen and (min-width: 360px) {
    .flow-text {
      font-size: 1.2rem; } }
  @media only screen and (min-width: 390px) {
    .flow-text {
      font-size: 1.224rem; } }
  @media only screen and (min-width: 420px) {
    .flow-text {
      font-size: 1.248rem; } }
  @media only screen and (min-width: 450px) {
    .flow-text {
      font-size: 1.272rem; } }
  @media only screen and (min-width: 480px) {
    .flow-text {
      font-size: 1.296rem; } }
  @media only screen and (min-width: 510px) {
    .flow-text {
      font-size: 1.32rem; } }
  @media only screen and (min-width: 540px) {
    .flow-text {
      font-size: 1.344rem; } }
  @media only screen and (min-width: 570px) {
    .flow-text {
      font-size: 1.368rem; } }
  @media only screen and (min-width: 600px) {
    .flow-text {
      font-size: 1.392rem; } }
  @media only screen and (min-width: 630px) {
    .flow-text {
      font-size: 1.416rem; } }
  @media only screen and (min-width: 660px) {
    .flow-text {
      font-size: 1.44rem; } }
  @media only screen and (min-width: 690px) {
    .flow-text {
      font-size: 1.464rem; } }
  @media only screen and (min-width: 720px) {
    .flow-text {
      font-size: 1.488rem; } }
  @media only screen and (min-width: 750px) {
    .flow-text {
      font-size: 1.512rem; } }
  @media only screen and (min-width: 780px) {
    .flow-text {
      font-size: 1.536rem; } }
  @media only screen and (min-width: 810px) {
    .flow-text {
      font-size: 1.56rem; } }
  @media only screen and (min-width: 840px) {
    .flow-text {
      font-size: 1.584rem; } }
  @media only screen and (min-width: 870px) {
    .flow-text {
      font-size: 1.608rem; } }
  @media only screen and (min-width: 900px) {
    .flow-text {
      font-size: 1.632rem; } }
  @media only screen and (min-width: 930px) {
    .flow-text {
      font-size: 1.656rem; } }
  @media only screen and (min-width: 960px) {
    .flow-text {
      font-size: 1.68rem; } }
  @media only screen and (max-width: 360px) {
    .flow-text {
      font-size: 1.2rem; } }

.card-panel {
  -webkit-transition: box-shadow .25s;
  transition: box-shadow .25s;
  padding: 20px;
  margin: 0.5rem 0 1rem 0;
  border-radius: 2px;
  background-color: #fff; }

.card {
  position: relative;
  overflow: hidden;
  margin: 0.5rem 0 1rem 0;
  background-color: #fff;
  -webkit-transition: box-shadow .25s;
  transition: box-shadow .25s;
  border-radius: 2px; }
  .card .card-title {
    color: #fff;
    font-size: 24px;
    font-weight: 300; }
    .card .card-title.activator {
      cursor: pointer; }
  .card.small, .card.medium, .card.large {
    position: relative; }
    .card.small .card-image, .card.medium .card-image, .card.large .card-image {
      overflow: hidden; }
    .card.small .card-content, .card.medium .card-content, .card.large .card-content {
      overflow: hidden; }
    .card.small .card-action, .card.medium .card-action, .card.large .card-action {
      position: absolute;
      bottom: 0;
      left: 0;
      right: 0; }
  .card.small {
    height: 300px; }
    .card.small .card-image {
      height: 150px; }
    .card.small .card-content {
      height: 150px; }
  .card.medium {
    height: 400px; }
    .card.medium .card-image {
      height: 250px; }
    .card.medium .card-content {
      height: 150px; }
  .card.large {
    height: 500px; }
    .card.large .card-image {
      height: 330px; }
    .card.large .card-content {
      height: 170px; }
  .card .card-image {
    position: relative; }
    .card .card-image img {
      border-radius: 2px 2px 0 0;
      position: relative;
      left: 0;
      right: 0;
      top: 0;
      bottom: 0;
      width: 100%; }
    .card .card-image .card-title {
      position: absolute;
      bottom: 0;
      left: 0;
      padding: 20px; }
  .card .card-content {
    padding: 20px;
    border-radius: 0 0 2px 2px; }
    .card .card-content p {
      margin: 0;
      color: inherit; }
    .card .card-content .card-title {
      line-height: 48px; }
  .card .card-action {
    border-top: 1px solid rgba(160, 160, 160, 0.2);
    padding: 20px; }
    .card .card-action a {
      color: #ffab40;
      margin-right: 20px;
      -webkit-transition: color 0.3s ease;
      transition: color 0.3s ease;
      text-transform: uppercase; }
      .card .card-action a:hover {
        color: #ffd8a6; }
  .card .card-reveal {
    padding: 20px;
    position: absolute;
    background-color: #fff;
    width: 100%;
    overflow-y: auto;
    top: 100%;
    height: 100%;
    z-index: 1;
    display: none; }
    .card .card-reveal .card-title {
      cursor: pointer;
      display: block; }

#toast-container {
  display: block;
  position: fixed;
  z-index: 1001; }
  @media only screen and (max-width: 600px) {
    #toast-container {
      min-width: 100%;
      bottom: 0%; } }
  @media only screen and (min-width: 601px) and (max-width: 992px) {
    #toast-container {
      min-width: 30%;
      left: 5%;
      bottom: 7%; } }
  @media only screen and (min-width: 993px) {
    #toast-container {
      min-width: 8%;
      top: 10%;
      right: 7%; } }

.toast {
  border-radius: 2px;
  top: 0;
  width: auto;
  clear: both;
  margin-top: 10px;
  position: relative;
  max-width: 100%;
  height: 48px;
  line-height: 48px;
  background-color: #323232;
  padding: 0 25px;
  font-size: 1.1rem;
  font-weight: 300;
  color: #fff;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-align: center;
  -ms-flex-align: center;
  -webkit-box-align: center;
          align-items: center;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between; }
  .toast .btn, .toast .btn-large, .toast .btn-flat {
    margin: 0;
    margin-left: 3rem; }
  .toast.rounded {
    border-radius: 24px; }
  @media only screen and (max-width: 600px) {
    .toast {
      width: 100%;
      border-radius: 0; } }
  @media only screen and (min-width: 601px) and (max-width: 992px) {
    .toast {
      float: left; } }
  @media only screen and (min-width: 993px) {
    .toast {
      float: right; } }

.tabs {
  position: relative;
  height: 48px;
  background-color: #fff;
  margin: 0 auto;
  width: 100%;
  white-space: nowrap; }
  .tabs .tab {
    display: block;
    float: left;
    text-align: center;
    line-height: 48px;
    height: 48px;
    padding: 0 20px;
    margin: 0;
    text-transform: uppercase;
    letter-spacing: .8px;
    width: 15%; }
    .tabs .tab a {
      color: #ee6e73;
      display: block;
      width: 100%;
      height: 100%;
      -webkit-transition: color 0.28s ease;
      transition: color 0.28s ease; }
      .tabs .tab a:hover {
        color: #f9c9cb; }
    .tabs .tab.disabled a {
      color: #f9c9cb;
      cursor: default; }
  .tabs .indicator {
    position: absolute;
    bottom: 0;
    height: 2px;
    background-color: #f6b2b5;
    will-change: left, right; }

.tabs .tab {
  padding: 0; }

.material-tooltip {
  padding: 10px 8px;
  font-size: 1rem;
  z-index: 2000;
  background-color: transparent;
  border-radius: 2px;
  color: #fff;
  min-height: 36px;
  line-height: 1rem;
  opacity: 0;
  display: none;
  position: absolute;
  text-align: center;
  overflow: hidden;
  left: 0;
  top: 0;
  will-change: top, left; }

.backdrop {
  position: absolute;
  opacity: 0;
  display: none;
  height: 7px;
  width: 14px;
  border-radius: 0 0 14px 14px;
  background-color: #323232;
  z-index: -1;
  -webkit-transform-origin: 50% 10%;
  transform-origin: 50% 10%;
  will-change: transform, opacity; }

.btn, .btn-large, .btn-flat {
  border: none;
  border-radius: 2px;
  display: inline-block;
  height: 36px;
  line-height: 36px;
  outline: 0;
  padding: 0 2rem;
  text-transform: uppercase;
  vertical-align: middle;
  -webkit-tap-highlight-color: transparent; }

.btn.disabled, .disabled.btn-large, .btn-floating.disabled, .btn-large.disabled, .btn:disabled, .btn-large:disabled, .btn-large:disabled, .btn-floating:disabled {
  background-color: #DFDFDF !important;
  box-shadow: none;
  color: #9F9F9F !important;
  cursor: default; }
  .btn.disabled *, .disabled.btn-large *, .btn-floating.disabled *, .btn-large.disabled *, .btn:disabled *, .btn-large:disabled *, .btn-large:disabled *, .btn-floating:disabled * {
    pointer-events: none; }
  .btn.disabled:hover, .disabled.btn-large:hover, .btn-floating.disabled:hover, .btn-large.disabled:hover, .btn:disabled:hover, .btn-large:disabled:hover, .btn-large:disabled:hover, .btn-floating:disabled:hover {
    background-color: #DFDFDF;
    color: #9F9F9F; }

.btn i, .btn-large i, .btn-floating i, .btn-large i, .btn-flat i {
  font-size: 1.3rem;
  line-height: inherit; }

.btn, .btn-large {
  text-decoration: none;
  color: #fff;
  background-color: #26a69a;
  text-align: center;
  letter-spacing: .5px;
  -webkit-transition: 0.2s ease-out;
  transition: 0.2s ease-out;
  cursor: pointer; }
  .btn:hover, .btn-large:hover {
    background-color: #2bbbad; }

.btn-floating {
  display: inline-block;
  color: #fff;
  position: relative;
  overflow: hidden;
  z-index: 1;
  width: 37px;
  height: 37px;
  line-height: 37px;
  padding: 0;
  background-color: #26a69a;
  border-radius: 50%;
  -webkit-transition: .3s;
  transition: .3s;
  cursor: pointer;
  vertical-align: middle; }
  .btn-floating i {
    width: inherit;
    display: inline-block;
    text-align: center;
    color: #fff;
    font-size: 1.6rem;
    line-height: 37px; }
  .btn-floating:before {
    border-radius: 0; }
  .btn-floating.btn-large {
    width: 55.5px;
    height: 55.5px; }
    .btn-floating.btn-large i {
      line-height: 55.5px; }

button.btn-floating {
  border: none; }

.fixed-action-btn {
  position: fixed;
  right: 23px;
  bottom: 23px;
  padding-top: 15px;
  margin-bottom: 0;
  z-index: 998; }
  .fixed-action-btn ul {
    left: 0;
    right: 0;
    text-align: center;
    position: absolute;
    bottom: 64px;
    margin: 0; }
    .fixed-action-btn ul li {
      margin-bottom: 15px; }
    .fixed-action-btn ul a.btn-floating {
      opacity: 0; }

.btn-flat {
  box-shadow: none;
  background-color: transparent;
  color: #343434;
  cursor: pointer; }
  .btn-flat.disabled {
    color: #b3b3b3;
    cursor: default; }

.btn-large {
  height: 54px;
  line-height: 56px; }
  .btn-large i {
    font-size: 1.6rem; }

.btn-block {
  display: block; }

.dropdown-content {
  background-color: #fff;
  margin: 0;
  display: none;
  min-width: 100px;
  max-height: 650px;
  overflow-y: auto;
  opacity: 0;
  position: absolute;
  z-index: 999;
  will-change: width, height; }
  .dropdown-content li {
    clear: both;
    color: rgba(0, 0, 0, 0.87);
    cursor: pointer;
    line-height: 1.5rem;
    width: 100%;
    text-align: left;
    text-transform: none; }
    .dropdown-content li:hover, .dropdown-content li.active, .dropdown-content .body-home .header .side-nav li.nav-home, .body-home .header .side-nav .dropdown-content li.nav-home, .dropdown-content .body-products .header .side-nav li.subnav-products, .body-products .header .side-nav .dropdown-content li.subnav-products, .dropdown-content .body-attributes .header .side-nav li.subnav-attributes, .body-attributes .header .side-nav .dropdown-content li.subnav-attributes, .dropdown-content .body-categories .header .side-nav li.subnav-categories, .body-categories .header .side-nav .dropdown-content li.subnav-categories, .dropdown-content .body-orders .header .side-nav li.subnav-orders, .body-orders .header .side-nav .dropdown-content li.subnav-orders, .dropdown-content .body-payments .header .side-nav li.subnav-payments, .body-payments .header .side-nav .dropdown-content li.subnav-payments, .dropdown-content .body-customers .header .side-nav li.subnav-customers, .body-customers .header .side-nav .dropdown-content li.subnav-customers, .dropdown-content .body-discounts .header .side-nav li.subnav-discounts, .body-discounts .header .side-nav .dropdown-content li.subnav-discounts, .dropdown-content .body-vouchers .header .side-nav li.subnav-vouchers, .body-vouchers .header .side-nav .dropdown-content li.subnav-vouchers, .dropdown-content .body-sales .header .side-nav li.subnav-sales, .body-sales .header .side-nav .dropdown-content li.subnav-sales {
      background-color: #eee; }
    .dropdown-content li > a, .dropdown-content li > span {
      font-size: 1.2rem;
      color: #26a69a;
      display: block;
      padding: 1rem 1rem; }
    .dropdown-content li > a > i {
      height: inherit;
      line-height: inherit; }

/*!
 * Waves v0.6.0
 * http://fian.my.id/Waves
 *
 * Copyright 2014 Alfiana E. Sibuea and other contributors
 * Released under the MIT license
 * https://github.com/fians/Waves/blob/master/LICENSE
 */
.waves-effect {
  position: relative;
  cursor: pointer;
  display: inline-block;
  overflow: hidden;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -webkit-tap-highlight-color: transparent;
  vertical-align: middle;
  z-index: 1;
  will-change: opacity, transform;
  -webkit-transition: all 0.3s ease-out;
  transition: all 0.3s ease-out; }
  .waves-effect .waves-ripple {
    position: absolute;
    border-radius: 50%;
    width: 20px;
    height: 20px;
    margin-top: -10px;
    margin-left: -10px;
    opacity: 0;
    background: rgba(0, 0, 0, 0.2);
    -webkit-transition: all 0.7s ease-out;
    transition: all 0.7s ease-out;
    -webkit-transition-property: -webkit-transform, opacity;
    -webkit-transition-property: opacity, -webkit-transform;
    transition-property: opacity, -webkit-transform;
    transition-property: transform, opacity;
    transition-property: transform, opacity, -webkit-transform;
    -webkit-transform: scale(0);
    transform: scale(0);
    pointer-events: none; }
  .waves-effect.waves-light .waves-ripple {
    background-color: rgba(255, 255, 255, 0.45); }
  .waves-effect.waves-red .waves-ripple {
    background-color: rgba(244, 67, 54, 0.7); }
  .waves-effect.waves-yellow .waves-ripple {
    background-color: rgba(255, 235, 59, 0.7); }
  .waves-effect.waves-orange .waves-ripple {
    background-color: rgba(255, 152, 0, 0.7); }
  .waves-effect.waves-purple .waves-ripple {
    background-color: rgba(156, 39, 176, 0.7); }
  .waves-effect.waves-green .waves-ripple {
    background-color: rgba(76, 175, 80, 0.7); }
  .waves-effect.waves-teal .waves-ripple {
    background-color: rgba(0, 150, 136, 0.7); }

.waves-notransition {
  -webkit-transition: none !important;
  transition: none !important; }

.waves-circle {
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
  -webkit-mask-image: -webkit-radial-gradient(circle, white 100%, black 100%); }

.waves-input-wrapper {
  border-radius: 0.2em;
  vertical-align: bottom; }
  .waves-input-wrapper .waves-button-input {
    position: relative;
    top: 0;
    left: 0;
    z-index: 1; }

.waves-circle {
  text-align: center;
  width: 2.5em;
  height: 2.5em;
  line-height: 2.5em;
  border-radius: 50%;
  -webkit-mask-image: none; }

.waves-block {
  display: block; }

/* Firefox Bug: link not triggered */
a.waves-effect .waves-ripple {
  z-index: -1; }

.modal {
  display: none;
  position: fixed;
  left: 0;
  right: 0;
  background-color: #fafafa;
  padding: 0;
  max-height: 70%;
  width: 55%;
  margin: auto;
  overflow-y: auto;
  border-radius: 2px;
  will-change: top, opacity; }
  @media only screen and (max-width: 992px) {
    .modal {
      width: 80%; } }
  .modal h1, .modal h2, .modal h3, .modal h4 {
    margin-top: 0; }
  .modal .modal-content {
    padding: 24px; }
  .modal .modal-close {
    cursor: pointer; }
  .modal .modal-footer {
    border-radius: 0 0 2px 2px;
    background-color: #fafafa;
    padding: 4px 6px;
    height: 56px;
    width: 100%; }
    .modal .modal-footer .btn, .modal .modal-footer .btn-large, .modal .modal-footer .btn-flat {
      float: right;
      margin: 6px 0; }

.lean-overlay {
  position: fixed;
  z-index: 999;
  top: -100px;
  left: 0;
  bottom: 0;
  right: 0;
  height: 125%;
  width: 100%;
  background: #000;
  display: none;
  will-change: opacity; }

.modal.modal-fixed-footer {
  padding: 0;
  height: 70%; }
  .modal.modal-fixed-footer .modal-content {
    position: absolute;
    height: calc(100% - 56px);
    max-height: 100%;
    width: 100%;
    overflow-y: auto; }
  .modal.modal-fixed-footer .modal-footer {
    border-top: 1px solid rgba(0, 0, 0, 0.1);
    position: absolute;
    bottom: 0; }

.modal.bottom-sheet {
  top: auto;
  bottom: -100%;
  margin: 0;
  width: 100%;
  max-height: 45%;
  border-radius: 0;
  will-change: bottom, opacity; }

.collapsible {
  border-top: 1px solid #ddd;
  border-right: 1px solid #ddd;
  border-left: 1px solid #ddd;
  margin: 0.5rem 0 1rem 0; }

.collapsible-header {
  display: block;
  cursor: pointer;
  height: 3rem;
  line-height: 3rem;
  padding: 0 1rem;
  background-color: #fff;
  border-bottom: 1px solid #ddd; }
  .collapsible-header i {
    width: 2rem;
    font-size: 1.6rem;
    line-height: 3rem;
    display: block;
    float: left;
    text-align: center;
    margin-right: 1rem; }

.collapsible-body {
  display: none;
  border-bottom: 1px solid #ddd;
  box-sizing: border-box; }
  .collapsible-body p {
    margin: 0;
    padding: 2rem; }

.side-nav .collapsible {
  border: none;
  box-shadow: none; }
  .side-nav .collapsible li {
    padding: 0; }

.side-nav .collapsible-header {
  background-color: transparent;
  border: none;
  line-height: inherit;
  height: inherit;
  margin: 0 1rem; }
  .side-nav .collapsible-header i {
    line-height: inherit; }

.side-nav .collapsible-body {
  border: 0;
  background-color: #fff; }
  .side-nav .collapsible-body li a {
    margin: 0 1rem 0 2rem; }

.collapsible.popout {
  border: none;
  box-shadow: none; }
  .collapsible.popout > li {
    box-shadow: 0 2px 5px 0 rgba(0, 0, 0, 0.16), 0 2px 10px 0 rgba(0, 0, 0, 0.12);
    margin: 0 24px;
    -webkit-transition: margin 0.35s cubic-bezier(0.25, 0.46, 0.45, 0.94);
    transition: margin 0.35s cubic-bezier(0.25, 0.46, 0.45, 0.94); }
  .collapsible.popout > li.active, .body-home .header .side-nav .collapsible.popout > li.nav-home, .body-products .header .side-nav .collapsible.popout > li.subnav-products, .body-attributes .header .side-nav .collapsible.popout > li.subnav-attributes, .body-categories .header .side-nav .collapsible.popout > li.subnav-categories, .body-orders .header .side-nav .collapsible.popout > li.subnav-orders, .body-payments .header .side-nav .collapsible.popout > li.subnav-payments, .body-customers .header .side-nav .collapsible.popout > li.subnav-customers, .body-discounts .header .side-nav .collapsible.popout > li.subnav-discounts, .body-vouchers .header .side-nav .collapsible.popout > li.subnav-vouchers, .body-sales .header .side-nav .collapsible.popout > li.subnav-sales {
    box-shadow: 0 5px 11px 0 rgba(0, 0, 0, 0.18), 0 4px 15px 0 rgba(0, 0, 0, 0.15);
    margin: 16px 0; }

.materialboxed {
  cursor: zoom-in;
  position: relative;
  -webkit-transition: opacity 0.4s;
  transition: opacity 0.4s; }
  .materialboxed:hover {
    will-change: left, top, width, height; }
    .materialboxed:hover:not(.active):not(.body-home .header .side-nav li.nav-home):not(.body-products .header .side-nav li.subnav-products):not(.body-attributes .header .side-nav li.subnav-attributes):not(.body-categories .header .side-nav li.subnav-categories):not(.body-orders .header .side-nav li.subnav-orders):not(.body-payments .header .side-nav li.subnav-payments):not(.body-customers .header .side-nav li.subnav-customers):not(.body-discounts .header .side-nav li.subnav-discounts):not(.body-vouchers .header .side-nav li.subnav-vouchers):not(.body-sales .header .side-nav li.subnav-sales):not(form label) {
      opacity: .8; }

.materialboxed.active, .body-home .header .side-nav li.materialboxed.nav-home, .body-products .header .side-nav li.materialboxed.subnav-products, .body-attributes .header .side-nav li.materialboxed.subnav-attributes, .body-categories .header .side-nav li.materialboxed.subnav-categories, .body-orders .header .side-nav li.materialboxed.subnav-orders, .body-payments .header .side-nav li.materialboxed.subnav-payments, .body-customers .header .side-nav li.materialboxed.subnav-customers, .body-discounts .header .side-nav li.materialboxed.subnav-discounts, .body-vouchers .header .side-nav li.materialboxed.subnav-vouchers, .body-sales .header .side-nav li.materialboxed.subnav-sales, form label.materialboxed {
  cursor: zoom-out; }

#materialbox-overlay {
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-color: #292929;
  z-index: 999;
  will-change: opacity; }

.materialbox-caption {
  position: fixed;
  display: none;
  color: #fff;
  line-height: 50px;
  bottom: 0;
  width: 100%;
  text-align: center;
  padding: 0% 15%;
  height: 50px;
  z-index: 1000;
  -webkit-font-smoothing: antialiased; }

/* Remove Focus Boxes */
select:focus {
  outline: 1px solid #c9f3ef; }

button:focus {
  outline: none;
  background-color: #2ab7a9; }

label {
  font-size: 0.8rem;
  color: #9e9e9e; }

/***************************
   Text Inputs + Textarea
****************************/
::-webkit-input-placeholder {
  color: #d1d1d1; }

:-moz-placeholder {
  /* Firefox 18- */
  color: #d1d1d1; }

::-moz-placeholder {
  /* Firefox 19+ */
  color: #d1d1d1; }

:-ms-input-placeholder {
  color: #d1d1d1; }

input[type=text],
input[type=password],
input[type=email],
input[type=url],
input[type=time],
input[type=date],
input[type=datetime-local],
input[type=tel],
input[type=number],
input[type=search],
textarea.materialize-textarea {
  background-color: transparent;
  border: none;
  border-bottom: 1px solid #9e9e9e;
  border-radius: 0;
  outline: none;
  height: 3rem;
  width: 100%;
  font-size: 1rem;
  margin: 0 0 15px 0;
  padding: 0;
  box-shadow: none;
  box-sizing: content-box;
  -webkit-transition: all .3s;
  transition: all .3s; }
  input[type=text]:disabled, input[type=text][readonly="readonly"],
  input[type=password]:disabled,
  input[type=password][readonly="readonly"],
  input[type=email]:disabled,
  input[type=email][readonly="readonly"],
  input[type=url]:disabled,
  input[type=url][readonly="readonly"],
  input[type=time]:disabled,
  input[type=time][readonly="readonly"],
  input[type=date]:disabled,
  input[type=date][readonly="readonly"],
  input[type=datetime-local]:disabled,
  input[type=datetime-local][readonly="readonly"],
  input[type=tel]:disabled,
  input[type=tel][readonly="readonly"],
  input[type=number]:disabled,
  input[type=number][readonly="readonly"],
  input[type=search]:disabled,
  input[type=search][readonly="readonly"],
  textarea.materialize-textarea:disabled,
  textarea.materialize-textarea[readonly="readonly"] {
    color: rgba(0, 0, 0, 0.26);
    border-bottom: 1px dotted rgba(0, 0, 0, 0.26); }
  input[type=text]:disabled + label, input[type=text][readonly="readonly"] + label,
  input[type=password]:disabled + label,
  input[type=password][readonly="readonly"] + label,
  input[type=email]:disabled + label,
  input[type=email][readonly="readonly"] + label,
  input[type=url]:disabled + label,
  input[type=url][readonly="readonly"] + label,
  input[type=time]:disabled + label,
  input[type=time][readonly="readonly"] + label,
  input[type=date]:disabled + label,
  input[type=date][readonly="readonly"] + label,
  input[type=datetime-local]:disabled + label,
  input[type=datetime-local][readonly="readonly"] + label,
  input[type=tel]:disabled + label,
  input[type=tel][readonly="readonly"] + label,
  input[type=number]:disabled + label,
  input[type=number][readonly="readonly"] + label,
  input[type=search]:disabled + label,
  input[type=search][readonly="readonly"] + label,
  textarea.materialize-textarea:disabled + label,
  textarea.materialize-textarea[readonly="readonly"] + label {
    color: rgba(0, 0, 0, 0.26); }
  input[type=text]:focus:not([readonly]),
  input[type=password]:focus:not([readonly]),
  input[type=email]:focus:not([readonly]),
  input[type=url]:focus:not([readonly]),
  input[type=time]:focus:not([readonly]),
  input[type=date]:focus:not([readonly]),
  input[type=datetime-local]:focus:not([readonly]),
  input[type=tel]:focus:not([readonly]),
  input[type=number]:focus:not([readonly]),
  input[type=search]:focus:not([readonly]),
  textarea.materialize-textarea:focus:not([readonly]) {
    border-bottom: 1px solid #26a69a;
    box-shadow: 0 1px 0 0 #26a69a; }
  input[type=text]:focus:not([readonly]) + label,
  input[type=password]:focus:not([readonly]) + label,
  input[type=email]:focus:not([readonly]) + label,
  input[type=url]:focus:not([readonly]) + label,
  input[type=time]:focus:not([readonly]) + label,
  input[type=date]:focus:not([readonly]) + label,
  input[type=datetime-local]:focus:not([readonly]) + label,
  input[type=tel]:focus:not([readonly]) + label,
  input[type=number]:focus:not([readonly]) + label,
  input[type=search]:focus:not([readonly]) + label,
  textarea.materialize-textarea:focus:not([readonly]) + label {
    color: #26a69a; }
  input[type=text].valid, input[type=text]:focus.valid,
  input[type=password].valid,
  input[type=password]:focus.valid,
  input[type=email].valid,
  input[type=email]:focus.valid,
  input[type=url].valid,
  input[type=url]:focus.valid,
  input[type=time].valid,
  input[type=time]:focus.valid,
  input[type=date].valid,
  input[type=date]:focus.valid,
  input[type=datetime-local].valid,
  input[type=datetime-local]:focus.valid,
  input[type=tel].valid,
  input[type=tel]:focus.valid,
  input[type=number].valid,
  input[type=number]:focus.valid,
  input[type=search].valid,
  input[type=search]:focus.valid,
  textarea.materialize-textarea.valid,
  textarea.materialize-textarea:focus.valid {
    border-bottom: 1px solid #4CAF50;
    box-shadow: 0 1px 0 0 #4CAF50; }
  input[type=text].valid + label:after,
  input[type=text]:focus.valid + label:after,
  input[type=password].valid + label:after,
  input[type=password]:focus.valid + label:after,
  input[type=email].valid + label:after,
  input[type=email]:focus.valid + label:after,
  input[type=url].valid + label:after,
  input[type=url]:focus.valid + label:after,
  input[type=time].valid + label:after,
  input[type=time]:focus.valid + label:after,
  input[type=date].valid + label:after,
  input[type=date]:focus.valid + label:after,
  input[type=datetime-local].valid + label:after,
  input[type=datetime-local]:focus.valid + label:after,
  input[type=tel].valid + label:after,
  input[type=tel]:focus.valid + label:after,
  input[type=number].valid + label:after,
  input[type=number]:focus.valid + label:after,
  input[type=search].valid + label:after,
  input[type=search]:focus.valid + label:after,
  textarea.materialize-textarea.valid + label:after,
  textarea.materialize-textarea:focus.valid + label:after {
    content: attr(data-success);
    color: #4CAF50;
    opacity: 1; }
  input[type=text].invalid, form .select-wrapper.invalid input[type=text], input[type=text]:focus.invalid, form .select-wrapper.invalid input[type=text]:focus,
  input[type=password].invalid,
  form .select-wrapper.invalid input[type=password],
  input[type=password]:focus.invalid,
  form .select-wrapper.invalid input[type=password]:focus,
  input[type=email].invalid,
  form .select-wrapper.invalid input[type=email],
  input[type=email]:focus.invalid,
  form .select-wrapper.invalid input[type=email]:focus,
  input[type=url].invalid,
  form .select-wrapper.invalid input[type=url],
  input[type=url]:focus.invalid,
  form .select-wrapper.invalid input[type=url]:focus,
  input[type=time].invalid,
  form .select-wrapper.invalid input[type=time],
  input[type=time]:focus.invalid,
  form .select-wrapper.invalid input[type=time]:focus,
  input[type=date].invalid,
  form .select-wrapper.invalid input[type=date],
  input[type=date]:focus.invalid,
  form .select-wrapper.invalid input[type=date]:focus,
  input[type=datetime-local].invalid,
  form .select-wrapper.invalid input[type=datetime-local],
  input[type=datetime-local]:focus.invalid,
  form .select-wrapper.invalid input[type=datetime-local]:focus,
  input[type=tel].invalid,
  form .select-wrapper.invalid input[type=tel],
  input[type=tel]:focus.invalid,
  form .select-wrapper.invalid input[type=tel]:focus,
  input[type=number].invalid,
  form .select-wrapper.invalid input[type=number],
  input[type=number]:focus.invalid,
  form .select-wrapper.invalid input[type=number]:focus,
  input[type=search].invalid,
  form .select-wrapper.invalid input[type=search],
  input[type=search]:focus.invalid,
  form .select-wrapper.invalid input[type=search]:focus,
  textarea.materialize-textarea.invalid,
  textarea.materialize-textarea:focus.invalid {
    border-bottom: 1px solid #F44336;
    box-shadow: 0 1px 0 0 #F44336; }
  input[type=text].invalid + label:after, form .select-wrapper.invalid input[type=text] + label:after,
  input[type=text]:focus.invalid + label:after, form .select-wrapper.invalid input[type=text]:focus + label:after,
  input[type=password].invalid + label:after, form .select-wrapper.invalid input[type=password] + label:after,
  input[type=password]:focus.invalid + label:after, form .select-wrapper.invalid input[type=password]:focus + label:after,
  input[type=email].invalid + label:after, form .select-wrapper.invalid input[type=email] + label:after,
  input[type=email]:focus.invalid + label:after, form .select-wrapper.invalid input[type=email]:focus + label:after,
  input[type=url].invalid + label:after, form .select-wrapper.invalid input[type=url] + label:after,
  input[type=url]:focus.invalid + label:after, form .select-wrapper.invalid input[type=url]:focus + label:after,
  input[type=time].invalid + label:after, form .select-wrapper.invalid input[type=time] + label:after,
  input[type=time]:focus.invalid + label:after, form .select-wrapper.invalid input[type=time]:focus + label:after,
  input[type=date].invalid + label:after, form .select-wrapper.invalid input[type=date] + label:after,
  input[type=date]:focus.invalid + label:after, form .select-wrapper.invalid input[type=date]:focus + label:after,
  input[type=datetime-local].invalid + label:after, form .select-wrapper.invalid input[type=datetime-local] + label:after,
  input[type=datetime-local]:focus.invalid + label:after, form .select-wrapper.invalid input[type=datetime-local]:focus + label:after,
  input[type=tel].invalid + label:after, form .select-wrapper.invalid input[type=tel] + label:after,
  input[type=tel]:focus.invalid + label:after, form .select-wrapper.invalid input[type=tel]:focus + label:after,
  input[type=number].invalid + label:after, form .select-wrapper.invalid input[type=number] + label:after,
  input[type=number]:focus.invalid + label:after, form .select-wrapper.invalid input[type=number]:focus + label:after,
  input[type=search].invalid + label:after, form .select-wrapper.invalid input[type=search] + label:after,
  input[type=search]:focus.invalid + label:after, form .select-wrapper.invalid input[type=search]:focus + label:after,
  textarea.materialize-textarea.invalid + label:after,
  textarea.materialize-textarea:focus.invalid + label:after {
    content: attr(data-error);
    color: #F44336;
    opacity: 1; }
  input[type=text] + label:after,
  input[type=password] + label:after,
  input[type=email] + label:after,
  input[type=url] + label:after,
  input[type=time] + label:after,
  input[type=date] + label:after,
  input[type=datetime-local] + label:after,
  input[type=tel] + label:after,
  input[type=number] + label:after,
  input[type=search] + label:after,
  textarea.materialize-textarea + label:after {
    display: block;
    content: "";
    position: absolute;
    top: 65px;
    opacity: 0;
    -webkit-transition: .2s opacity ease-out, .2s color ease-out;
    transition: .2s opacity ease-out, .2s color ease-out; }

.input-field {
  position: relative;
  margin-top: 1rem; }
  .input-field label {
    color: #9e9e9e;
    position: absolute;
    top: 0.8rem;
    left: 0.75rem;
    font-size: 1rem;
    cursor: text;
    -webkit-transition: 0.2s ease-out;
    transition: 0.2s ease-out; }
  .input-field label.active, .input-field form label, form .input-field label {
    font-size: 0.8rem;
    -webkit-transform: translateY(-140%);
    transform: translateY(-140%); }
  .input-field .prefix {
    position: absolute;
    width: 3rem;
    font-size: 2rem;
    -webkit-transition: color 0.2s;
    transition: color 0.2s; }
    .input-field .prefix.active, .input-field .body-home .header .side-nav li.prefix.nav-home, .body-home .header .side-nav .input-field li.prefix.nav-home, .input-field .body-products .header .side-nav li.prefix.subnav-products, .body-products .header .side-nav .input-field li.prefix.subnav-products, .input-field .body-attributes .header .side-nav li.prefix.subnav-attributes, .body-attributes .header .side-nav .input-field li.prefix.subnav-attributes, .input-field .body-categories .header .side-nav li.prefix.subnav-categories, .body-categories .header .side-nav .input-field li.prefix.subnav-categories, .input-field .body-orders .header .side-nav li.prefix.subnav-orders, .body-orders .header .side-nav .input-field li.prefix.subnav-orders, .input-field .body-payments .header .side-nav li.prefix.subnav-payments, .body-payments .header .side-nav .input-field li.prefix.subnav-payments, .input-field .body-customers .header .side-nav li.prefix.subnav-customers, .body-customers .header .side-nav .input-field li.prefix.subnav-customers, .input-field .body-discounts .header .side-nav li.prefix.subnav-discounts, .body-discounts .header .side-nav .input-field li.prefix.subnav-discounts, .input-field .body-vouchers .header .side-nav li.prefix.subnav-vouchers, .body-vouchers .header .side-nav .input-field li.prefix.subnav-vouchers, .input-field .body-sales .header .side-nav li.prefix.subnav-sales, .body-sales .header .side-nav .input-field li.prefix.subnav-sales, .input-field form label.prefix, form .input-field label.prefix {
      color: #26a69a; }
  .input-field .prefix ~ input,
  .input-field .prefix ~ textarea {
    margin-left: 3rem;
    width: 92%;
    width: calc(100% - 3rem); }
  .input-field .prefix ~ textarea {
    padding-top: .8rem; }
  .input-field .prefix ~ label {
    margin-left: 3rem; }
  @media only screen and (max-width: 992px) {
    .input-field .prefix ~ input {
      width: 86%;
      width: calc(100% - 3rem); } }
  @media only screen and (max-width: 600px) {
    .input-field .prefix ~ input {
      width: 80%;
      width: calc(100% - 3rem); } }

.input-field input[type=search] {
  display: block;
  line-height: inherit;
  padding-left: 4rem;
  width: calc(100% - 4rem); }
  .input-field input[type=search]:focus {
    background-color: #fff;
    border: 0;
    box-shadow: none;
    color: #444; }
    .input-field input[type=search]:focus + label i,
    .input-field input[type=search]:focus ~ .mdi-navigation-close,
    .input-field .select2-container--default .select2-selection--multiple input[type=search]:focus ~ .select2-selection__choice__remove, .select2-container--default .select2-selection--multiple
    .input-field input[type=search]:focus ~ .select2-selection__choice__remove {
      color: #444; }
  .input-field input[type=search] + label {
    left: 1rem; }
  .input-field input[type=search] ~ .mdi-navigation-close, .input-field .select2-container--default .select2-selection--multiple input[type=search] ~ .select2-selection__choice__remove, .select2-container--default .select2-selection--multiple .input-field input[type=search] ~ .select2-selection__choice__remove {
    position: absolute;
    top: 0;
    right: 1rem;
    color: transparent;
    cursor: pointer;
    font-size: 2rem;
    -webkit-transition: .3s color;
    transition: .3s color; }

textarea {
  width: 100%;
  height: 3rem;
  background-color: transparent; }
  textarea.materialize-textarea {
    overflow-y: hidden;
    /* prevents scroll bar flash */
    padding: 1.6rem 0;
    /* prevents text jump on Enter keypress */
    resize: none;
    min-height: 3rem; }

.hiddendiv {
  display: none;
  white-space: pre-wrap;
  word-wrap: break-word;
  overflow-wrap: break-word;
  /* future version of deprecated 'word-wrap' */
  padding-top: 1.2rem;
  /* prevents text jump on Enter keypress */ }

/***************
  Radio Buttons
***************/
/* Remove default Radio Buttons */
[type="radio"]:not(:checked),
[type="radio"]:checked {
  position: absolute;
  left: -9999px;
  visibility: hidden; }

[type="radio"]:not(:checked) + label,
[type="radio"]:checked + label {
  position: relative;
  padding-left: 35px;
  cursor: pointer;
  display: inline-block;
  height: 25px;
  line-height: 25px;
  font-size: 1rem;
  -webkit-transition: 0.28s ease;
  transition: 0.28s ease;
  -webkit-user-select: none;
  /* webkit (safari, chrome) browsers */
  -moz-user-select: none;
  /* mozilla browsers */
  -khtml-user-select: none;
  /* webkit (konqueror) browsers */
  -ms-user-select: none;
  /* IE10+ */ }

[type="radio"] + label:before,
[type="radio"] + label:after {
  content: '';
  position: absolute;
  left: 0;
  top: 0;
  margin: 4px;
  width: 16px;
  height: 16px;
  z-index: 0;
  -webkit-transition: 0.28s ease;
  transition: 0.28s ease; }

/* Unchecked styles */
[type="radio"]:not(:checked) + label:before {
  border-radius: 50%;
  border: 2px solid #5a5a5a; }

[type="radio"]:not(:checked) + label:after {
  border-radius: 50%;
  border: 2px solid #5a5a5a;
  z-index: -1;
  -webkit-transform: scale(0);
  transform: scale(0); }

/* Checked styles */
[type="radio"]:checked + label:before {
  border-radius: 50%;
  border: 2px solid transparent; }

[type="radio"]:checked + label:after {
  border-radius: 50%;
  border: 2px solid #26a69a;
  background-color: #26a69a;
  z-index: 0;
  -webkit-transform: scale(1.02);
  transform: scale(1.02); }

/* Radio With gap */
[type="radio"].with-gap:checked + label:before, form input[type="radio"][type=radio]:checked + label:before {
  border-radius: 50%;
  border: 2px solid #26a69a; }

[type="radio"].with-gap:checked + label:after, form input[type="radio"][type=radio]:checked + label:after {
  border-radius: 50%;
  border: 2px solid #26a69a;
  background-color: #26a69a;
  z-index: 0;
  -webkit-transform: scale(0.5);
  transform: scale(0.5); }

/* Disabled Radio With gap */
[type="radio"].with-gap:disabled:checked + label:before, form input[type="radio"][type=radio]:disabled:checked + label:before {
  border: 2px solid rgba(0, 0, 0, 0.26); }

[type="radio"].with-gap:disabled:checked + label:after, form input[type="radio"][type=radio]:disabled:checked + label:after {
  border: none;
  background-color: rgba(0, 0, 0, 0.26); }

/* Disabled style */
[type="radio"]:disabled:not(:checked) + label:before,
[type="radio"]:disabled:checked + label:before {
  background-color: transparent;
  border-color: rgba(0, 0, 0, 0.26); }

[type="radio"]:disabled + label {
  color: rgba(0, 0, 0, 0.26); }

[type="radio"]:disabled:not(:checked) + label:before {
  border-color: rgba(0, 0, 0, 0.26); }

[type="radio"]:disabled:checked + label:after {
  background-color: rgba(0, 0, 0, 0.26);
  border-color: #BDBDBD; }

/***************
   Checkboxes
***************/
/* CUSTOM CSS CHECKBOXES */
form p {
  margin-bottom: 10px;
  text-align: left; }

form p:last-child {
  margin-bottom: 0; }

/* Remove default checkbox */
[type="checkbox"]:not(:checked),
[type="checkbox"]:checked {
  position: absolute;
  left: -9999px;
  visibility: hidden; }

[type="checkbox"] {
  /* checkbox aspect */ }
  [type="checkbox"] + label {
    position: relative;
    padding-left: 35px;
    cursor: pointer;
    display: inline-block;
    height: 25px;
    line-height: 25px;
    font-size: 1rem;
    -webkit-user-select: none;
    /* webkit (safari, chrome) browsers */
    -moz-user-select: none;
    /* mozilla browsers */
    -khtml-user-select: none;
    /* webkit (konqueror) browsers */
    -ms-user-select: none;
    /* IE10+ */ }
  [type="checkbox"] + label:before {
    content: '';
    position: absolute;
    top: 0;
    left: 0;
    width: 18px;
    height: 18px;
    z-index: 0;
    border: 2px solid #5a5a5a;
    border-radius: 1px;
    margin-top: 2px;
    -webkit-transition: 0.2s;
    transition: 0.2s; }
  [type="checkbox"]:not(:checked):disabled + label:before {
    border: none;
    background-color: rgba(0, 0, 0, 0.26); }

[type="checkbox"]:checked + label:before {
  top: -4px;
  left: -3px;
  width: 12px;
  height: 22px;
  border-top: 2px solid transparent;
  border-left: 2px solid transparent;
  border-right: 2px solid #26a69a;
  border-bottom: 2px solid #26a69a;
  -webkit-transform: rotate(40deg);
  transform: rotate(40deg);
  -webkit-backface-visibility: hidden;
  -webkit-transform-origin: 100% 100%;
  transform-origin: 100% 100%; }

[type="checkbox"]:checked:disabled + label:before {
  border-right: 2px solid rgba(0, 0, 0, 0.26);
  border-bottom: 2px solid rgba(0, 0, 0, 0.26); }

/* Indeterminate checkbox */
[type="checkbox"]:indeterminate + label:before {
  left: -10px;
  top: -11px;
  width: 10px;
  height: 22px;
  border-top: none;
  border-left: none;
  border-right: 2px solid #26a69a;
  border-bottom: none;
  -webkit-transform: rotate(90deg);
  transform: rotate(90deg);
  -webkit-backface-visibility: hidden;
  -webkit-transform-origin: 100% 100%;
  transform-origin: 100% 100%; }

[type="checkbox"]:indeterminate:disabled + label:before {
  border-right: 2px solid rgba(0, 0, 0, 0.26);
  background-color: transparent; }

[type="checkbox"].filled-in + label:after {
  border-radius: 2px; }

[type="checkbox"].filled-in + label:before,
[type="checkbox"].filled-in + label:after {
  content: '';
  left: 0;
  position: absolute;
  /* .1s delay is for check animation */
  -webkit-transition: border .25s, background-color .25s, width .20s .1s, height .20s .1s, top .20s .1s, left .20s .1s;
  transition: border .25s, background-color .25s, width .20s .1s, height .20s .1s, top .20s .1s, left .20s .1s;
  z-index: 1; }

[type="checkbox"].filled-in:not(:checked) + label:before {
  width: 0;
  height: 0;
  border: 3px solid transparent;
  left: 6px;
  top: 10px;
  -webkit-transform: rotateZ(37deg);
  transform: rotateZ(37deg);
  -webkit-transform-origin: 20% 40%;
  transform-origin: 100% 100%; }

[type="checkbox"].filled-in:not(:checked) + label:after {
  height: 20px;
  width: 20px;
  background-color: transparent;
  border: 2px solid #5a5a5a;
  top: 0px;
  z-index: 0; }

[type="checkbox"].filled-in:checked + label:before {
  top: 0;
  left: 1px;
  width: 8px;
  height: 13px;
  border-top: 2px solid transparent;
  border-left: 2px solid transparent;
  border-right: 2px solid #fff;
  border-bottom: 2px solid #fff;
  -webkit-transform: rotateZ(37deg);
  transform: rotateZ(37deg);
  -webkit-transform-origin: 100% 100%;
  transform-origin: 100% 100%; }

[type="checkbox"].filled-in:checked + label:after {
  top: 0px;
  width: 20px;
  height: 20px;
  border: 2px solid #26a69a;
  background-color: #26a69a;
  z-index: 0; }

[type="checkbox"].filled-in:disabled:not(:checked) + label:before {
  background-color: transparent;
  border: 2px solid transparent; }

[type="checkbox"].filled-in:disabled:not(:checked) + label:after {
  border-color: transparent;
  background-color: #BDBDBD; }

[type="checkbox"].filled-in:disabled:checked + label:before {
  background-color: transparent; }

[type="checkbox"].filled-in:disabled:checked + label:after {
  background-color: #BDBDBD;
  border-color: #BDBDBD; }

/***************
     Switch
***************/
.switch,
.switch * {
  -webkit-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -ms-user-select: none; }

.switch label {
  cursor: pointer; }

.switch label input[type=checkbox] {
  opacity: 0;
  width: 0;
  height: 0; }

.switch label input[type=checkbox]:checked + .lever {
  background-color: #84c7c1; }

.switch label input[type=checkbox]:checked + .lever:after {
  background-color: #26a69a; }

.switch label .lever {
  content: "";
  display: inline-block;
  position: relative;
  width: 40px;
  height: 15px;
  background-color: #818181;
  border-radius: 15px;
  margin-right: 10px;
  -webkit-transition: background 0.3s ease;
  transition: background 0.3s ease;
  vertical-align: middle;
  margin: 0 16px; }

.switch label .lever:after {
  content: "";
  position: absolute;
  display: inline-block;
  width: 21px;
  height: 21px;
  background-color: #F1F1F1;
  border-radius: 21px;
  box-shadow: 0 1px 3px 1px rgba(0, 0, 0, 0.4);
  left: -5px;
  top: -3px;
  -webkit-transition: left 0.3s ease, background .3s ease, box-shadow 0.1s ease;
  transition: left 0.3s ease, background .3s ease, box-shadow 0.1s ease; }

input[type=checkbox]:checked:not(:disabled) ~ .lever:active:after {
  box-shadow: 0 1px 3px 1px rgba(0, 0, 0, 0.4), 0 0 0 15px rgba(38, 166, 154, 0.1); }

input[type=checkbox]:not(:disabled) ~ .lever:active:after {
  box-shadow: 0 1px 3px 1px rgba(0, 0, 0, 0.4), 0 0 0 15px rgba(0, 0, 0, 0.08); }

.switch label input[type=checkbox]:checked + .lever:after {
  left: 24px; }

.switch input[type=checkbox][disabled] + .lever {
  cursor: default; }

.switch label input[type=checkbox][disabled] + .lever:after,
.switch label input[type=checkbox][disabled]:checked + .lever:after {
  background-color: #BDBDBD; }

/***************
  Select Field
***************/
.select-label {
  position: absolute; }

.select-wrapper {
  position: relative; }
  .select-wrapper input.select-dropdown {
    position: relative;
    cursor: pointer;
    background-color: transparent;
    border: none;
    border-bottom: 1px solid #9e9e9e;
    outline: none;
    height: 3rem;
    line-height: 3rem;
    width: 100%;
    font-size: 1rem;
    margin: 0 0 15px 0;
    padding: 0;
    display: block; }
  .select-wrapper span.caret {
    color: initial;
    position: absolute;
    right: 0;
    top: 16px;
    font-size: 10px; }
    .select-wrapper span.caret.disabled {
      color: rgba(0, 0, 0, 0.26); }
  .select-wrapper + label {
    position: absolute;
    top: -14px;
    font-size: 0.8rem; }

select {
  display: none; }

select.browser-default {
  display: block; }

select:disabled {
  color: rgba(0, 0, 0, 0.3); }

.select-wrapper input.select-dropdown:disabled {
  color: rgba(0, 0, 0, 0.3);
  cursor: default;
  -webkit-user-select: none;
  /* webkit (safari, chrome) browsers */
  -moz-user-select: none;
  /* mozilla browsers */
  -ms-user-select: none;
  /* IE10+ */
  border-bottom: 1px solid rgba(0, 0, 0, 0.3); }

.select-wrapper i {
  color: rgba(0, 0, 0, 0.3); }

.select-dropdown li.disabled {
  color: rgba(0, 0, 0, 0.3);
  background-color: transparent; }

/*********************
      File Input
**********************/
.file-field {
  position: relative; }
  .file-field .file-path-wrapper {
    overflow: hidden;
    padding-left: 10px; }
  .file-field input.file-path {
    width: 100%; }
  .file-field .btn, .file-field .btn-large {
    float: left;
    height: 3rem;
    line-height: 3rem; }
  .file-field span {
    cursor: pointer; }
  .file-field input[type=file] {
    position: absolute;
    top: 0;
    right: 0;
    left: 0;
    bottom: 0;
    width: 100%;
    margin: 0;
    padding: 0;
    font-size: 20px;
    cursor: pointer;
    opacity: 0;
    filter: alpha(opacity=0); }

/***************
      Range
***************/
.range-field {
  position: relative; }

input[type=range], input[type=range] + .thumb {
  cursor: pointer; }

input[type=range] {
  position: relative;
  background-color: transparent;
  border: none;
  outline: none;
  width: 100%;
  margin: 15px 0px;
  padding: 0; }

input[type=range] + .thumb {
  position: absolute;
  border: none;
  height: 0;
  width: 0;
  border-radius: 50%;
  background-color: #26a69a;
  top: 10px;
  margin-left: -6px;
  -webkit-transform-origin: 50% 50%;
  transform-origin: 50% 50%;
  -webkit-transform: rotate(-45deg);
  transform: rotate(-45deg); }
  input[type=range] + .thumb .value {
    display: block;
    width: 30px;
    text-align: center;
    color: #26a69a;
    font-size: 0;
    -webkit-transform: rotate(45deg);
    transform: rotate(45deg); }
  input[type=range] + .thumb.active, .body-home .header .side-nav input[type=range] + li.thumb.nav-home, .body-products .header .side-nav input[type=range] + li.thumb.subnav-products, .body-attributes .header .side-nav input[type=range] + li.thumb.subnav-attributes, .body-categories .header .side-nav input[type=range] + li.thumb.subnav-categories, .body-orders .header .side-nav input[type=range] + li.thumb.subnav-orders, .body-payments .header .side-nav input[type=range] + li.thumb.subnav-payments, .body-customers .header .side-nav input[type=range] + li.thumb.subnav-customers, .body-discounts .header .side-nav input[type=range] + li.thumb.subnav-discounts, .body-vouchers .header .side-nav input[type=range] + li.thumb.subnav-vouchers, .body-sales .header .side-nav input[type=range] + li.thumb.subnav-sales, form input[type=range] + label.thumb {
    border-radius: 50% 50% 50% 0; }
    input[type=range] + .thumb.active .value, .body-home .header .side-nav input[type=range] + li.thumb.nav-home .value, .body-products .header .side-nav input[type=range] + li.thumb.subnav-products .value, .body-attributes .header .side-nav input[type=range] + li.thumb.subnav-attributes .value, .body-categories .header .side-nav input[type=range] + li.thumb.subnav-categories .value, .body-orders .header .side-nav input[type=range] + li.thumb.subnav-orders .value, .body-payments .header .side-nav input[type=range] + li.thumb.subnav-payments .value, .body-customers .header .side-nav input[type=range] + li.thumb.subnav-customers .value, .body-discounts .header .side-nav input[type=range] + li.thumb.subnav-discounts .value, .body-vouchers .header .side-nav input[type=range] + li.thumb.subnav-vouchers .value, .body-sales .header .side-nav input[type=range] + li.thumb.subnav-sales .value, form input[type=range] + label.thumb .value {
      color: #fff;
      margin-left: -1px;
      margin-top: 8px;
      font-size: 10px; }

input[type=range]:focus {
  outline: none; }

input[type=range] {
  -webkit-appearance: none; }

input[type=range]::-webkit-slider-runnable-track {
  height: 3px;
  background: #c2c0c2;
  border: none; }

input[type=range]::-webkit-slider-thumb {
  -webkit-appearance: none;
  border: none;
  height: 14px;
  width: 14px;
  border-radius: 50%;
  background-color: #26a69a;
  -webkit-transform-origin: 50% 50%;
          transform-origin: 50% 50%;
  margin: -5px 0 0 0;
  -webkit-transition: 0.3s;
  transition: 0.3s; }

input[type=range]:focus::-webkit-slider-runnable-track {
  background: #ccc; }

input[type=range] {
  /* fix for FF unable to apply focus style bug  */
  border: 1px solid white;
  /*required for proper track sizing in FF*/ }

input[type=range]::-moz-range-track {
  height: 3px;
  background: #ddd;
  border: none; }

input[type=range]::-moz-range-thumb {
  border: none;
  height: 14px;
  width: 14px;
  border-radius: 50%;
  background: #26a69a;
  margin-top: -5px; }

/*hide the outline behind the border*/
input[type=range]:-moz-focusring {
  outline: 1px solid white;
  outline-offset: -1px; }

input[type=range]:focus::-moz-range-track {
  background: #ccc; }

input[type=range]::-ms-track {
  height: 3px;
  /*remove bg colour from the track, we'll use ms-fill-lower and ms-fill-upper instead */
  background: transparent;
  /*leave room for the larger thumb to overflow with a transparent border */
  border-color: transparent;
  border-width: 6px 0;
  /*remove default tick marks*/
  color: transparent; }

input[type=range]::-ms-fill-lower {
  background: #777; }

input[type=range]::-ms-fill-upper {
  background: #ddd; }

input[type=range]::-ms-thumb {
  border: none;
  height: 14px;
  width: 14px;
  border-radius: 50%;
  background: #26a69a; }

input[type=range]:focus::-ms-fill-lower {
  background: #888; }

input[type=range]:focus::-ms-fill-upper {
  background: #ccc; }

/***************************
   Text Inputs + Textarea
****************************/
select {
  background-color: rgba(255, 255, 255, 0.9);
  width: 100%;
  padding: 5px;
  border: 1px solid #f2f2f2;
  border-radius: 2px;
  height: 3rem; }

/***************
    Nav List
***************/
.table-of-contents.fixed {
  position: fixed; }

.table-of-contents li {
  padding: 2px 0; }

.table-of-contents a {
  display: inline-block;
  font-weight: 300;
  color: #757575;
  padding-left: 20px;
  height: 1.5rem;
  line-height: 1.5rem;
  letter-spacing: .4;
  display: inline-block; }
  .table-of-contents a:hover {
    color: #a8a8a8;
    padding-left: 19px;
    border-left: 1px solid #ea4a4f; }
  .table-of-contents a.active {
    font-weight: 500;
    padding-left: 18px;
    border-left: 2px solid #ea4a4f; }

.side-nav {
  position: fixed;
  width: 240px;
  left: -105%;
  top: 0;
  margin: 0;
  height: 100%;
  height: calc(100% + 60px);
  height: -moz-calc(100%);
  padding-bottom: 60px;
  background-color: #fff;
  z-index: 999;
  overflow-y: auto;
  will-change: left; }
  .side-nav.right-aligned {
    will-change: right;
    right: -105%;
    left: auto; }
  .side-nav .collapsible {
    margin: 0; }
  .side-nav li {
    float: none;
    padding: 0 15px; }
    .side-nav li:hover, .side-nav li.active, .body-home .header .side-nav li.nav-home, .body-products .header .side-nav li.subnav-products, .body-attributes .header .side-nav li.subnav-attributes, .body-categories .header .side-nav li.subnav-categories, .body-orders .header .side-nav li.subnav-orders, .body-payments .header .side-nav li.subnav-payments, .body-customers .header .side-nav li.subnav-customers, .body-discounts .header .side-nav li.subnav-discounts, .body-vouchers .header .side-nav li.subnav-vouchers, .body-sales .header .side-nav li.subnav-sales {
      background-color: #ddd; }
  .side-nav a {
    color: #444;
    display: block;
    font-size: 1rem;
    height: 64px;
    line-height: 64px;
    padding: 0 15px; }

.drag-target {
  height: 100%;
  width: 10px;
  position: fixed;
  top: 0;
  z-index: 998; }

.side-nav.fixed a {
  display: block;
  padding: 0 15px;
  color: #444; }

.side-nav.fixed {
  left: 0;
  position: fixed; }
  .side-nav.fixed.right-aligned {
    right: 0;
    left: auto; }

@media only screen and (max-width: 992px) {
  .side-nav.fixed {
    left: -105%; }
    .side-nav.fixed.right-aligned {
      right: -105%;
      left: auto; } }

.side-nav .collapsible-body li.active, .body-home .header .side-nav .collapsible-body li.nav-home, .body-products .header .side-nav .collapsible-body li.subnav-products, .body-attributes .header .side-nav .collapsible-body li.subnav-attributes, .body-categories .header .side-nav .collapsible-body li.subnav-categories, .body-orders .header .side-nav .collapsible-body li.subnav-orders, .body-payments .header .side-nav .collapsible-body li.subnav-payments, .body-customers .header .side-nav .collapsible-body li.subnav-customers, .body-discounts .header .side-nav .collapsible-body li.subnav-discounts, .body-vouchers .header .side-nav .collapsible-body li.subnav-vouchers, .body-sales .header .side-nav .collapsible-body li.subnav-sales,
.side-nav.fixed .collapsible-body li.active, .body-home .header .side-nav.fixed .collapsible-body li.nav-home, .body-products .header .side-nav.fixed .collapsible-body li.subnav-products, .body-attributes .header .side-nav.fixed .collapsible-body li.subnav-attributes, .body-categories .header .side-nav.fixed .collapsible-body li.subnav-categories, .body-orders .header .side-nav.fixed .collapsible-body li.subnav-orders, .body-payments .header .side-nav.fixed .collapsible-body li.subnav-payments, .body-customers .header .side-nav.fixed .collapsible-body li.subnav-customers, .body-discounts .header .side-nav.fixed .collapsible-body li.subnav-discounts, .body-vouchers .header .side-nav.fixed .collapsible-body li.subnav-vouchers, .body-sales .header .side-nav.fixed .collapsible-body li.subnav-sales {
  background-color: #ee6e73; }
  .side-nav .collapsible-body li.active a, .body-home .header .side-nav .collapsible-body li.nav-home a, .body-products .header .side-nav .collapsible-body li.subnav-products a, .body-attributes .header .side-nav .collapsible-body li.subnav-attributes a, .body-categories .header .side-nav .collapsible-body li.subnav-categories a, .body-orders .header .side-nav .collapsible-body li.subnav-orders a, .body-payments .header .side-nav .collapsible-body li.subnav-payments a, .body-customers .header .side-nav .collapsible-body li.subnav-customers a, .body-discounts .header .side-nav .collapsible-body li.subnav-discounts a, .body-vouchers .header .side-nav .collapsible-body li.subnav-vouchers a, .body-sales .header .side-nav .collapsible-body li.subnav-sales a,
  .side-nav.fixed .collapsible-body li.active a, .body-home .header .side-nav.fixed .collapsible-body li.nav-home a, .body-products .header .side-nav.fixed .collapsible-body li.subnav-products a, .body-attributes .header .side-nav.fixed .collapsible-body li.subnav-attributes a, .body-categories .header .side-nav.fixed .collapsible-body li.subnav-categories a, .body-orders .header .side-nav.fixed .collapsible-body li.subnav-orders a, .body-payments .header .side-nav.fixed .collapsible-body li.subnav-payments a, .body-customers .header .side-nav.fixed .collapsible-body li.subnav-customers a, .body-discounts .header .side-nav.fixed .collapsible-body li.subnav-discounts a, .body-vouchers .header .side-nav.fixed .collapsible-body li.subnav-vouchers a, .body-sales .header .side-nav.fixed .collapsible-body li.subnav-sales a {
    color: #fff; }

#sidenav-overlay {
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  height: 120vh;
  background-color: rgba(0, 0, 0, 0.5);
  z-index: 997;
  will-change: opacity; }

/*
    @license
    Copyright (c) 2014 The Polymer Project Authors. All rights reserved.
    This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
    The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
    The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
    Code distributed by Google as part of the polymer project is also
    subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
 */
/**************************/
/* STYLES FOR THE SPINNER */
/**************************/
/*
 * Constants:
 *      STROKEWIDTH = 3px
 *      ARCSIZE     = 270 degrees (amount of circle the arc takes up)
 *      ARCTIME     = 1333ms (time it takes to expand and contract arc)
 *      ARCSTARTROT = 216 degrees (how much the start location of the arc
 *                                should rotate each time, 216 gives us a
 *                                5 pointed star shape (it's 360/5 * 3).
 *                                For a 7 pointed star, we might do
 *                                360/7 * 3 = 154.286)
 *      CONTAINERWIDTH = 28px
 *      SHRINK_TIME = 400ms
 */
.preloader-wrapper {
  display: inline-block;
  position: relative;
  width: 48px;
  height: 48px; }
  .preloader-wrapper.small {
    width: 36px;
    height: 36px; }
  .preloader-wrapper.big {
    width: 64px;
    height: 64px; }
  .preloader-wrapper.active, .body-home .header .side-nav li.preloader-wrapper.nav-home, .body-products .header .side-nav li.preloader-wrapper.subnav-products, .body-attributes .header .side-nav li.preloader-wrapper.subnav-attributes, .body-categories .header .side-nav li.preloader-wrapper.subnav-categories, .body-orders .header .side-nav li.preloader-wrapper.subnav-orders, .body-payments .header .side-nav li.preloader-wrapper.subnav-payments, .body-customers .header .side-nav li.preloader-wrapper.subnav-customers, .body-discounts .header .side-nav li.preloader-wrapper.subnav-discounts, .body-vouchers .header .side-nav li.preloader-wrapper.subnav-vouchers, .body-sales .header .side-nav li.preloader-wrapper.subnav-sales, form label.preloader-wrapper {
    /* duration: 360 * ARCTIME / (ARCSTARTROT + (360-ARCSIZE)) */
    -webkit-animation: container-rotate 1568ms linear infinite;
    animation: container-rotate 1568ms linear infinite; }

@-webkit-keyframes container-rotate {
  to {
    -webkit-transform: rotate(360deg); } }

@keyframes container-rotate {
  to {
    -webkit-transform: rotate(360deg);
            transform: rotate(360deg); } }

.spinner-layer {
  position: absolute;
  width: 100%;
  height: 100%;
  opacity: 0; }

.spinner-blue,
.spinner-blue-only {
  border-color: #4285f4; }

.spinner-red,
.spinner-red-only {
  border-color: #db4437; }

.spinner-yellow,
.spinner-yellow-only {
  border-color: #f4b400; }

.spinner-green,
.spinner-green-only {
  border-color: #0f9d58; }

/**
 * IMPORTANT NOTE ABOUT CSS ANIMATION PROPERTIES (keanulee):
 *
 * iOS Safari (tested on iOS 8.1) does not handle animation-delay very well - it doesn't
 * guarantee that the animation will start _exactly_ after that value. So we avoid using
 * animation-delay and instead set custom keyframes for each color (as redundant as it
 * seems).
 *
 * We write out each animation in full (instead of separating animation-name,
 * animation-duration, etc.) because under the polyfill, Safari does not recognize those
 * specific properties properly, treats them as -webkit-animation, and overrides the
 * other animation rules. See https://github.com/Polymer/platform/issues/53.
 */
.active .spinner-layer.spinner-blue, .body-home .header .side-nav li.nav-home .spinner-layer.spinner-blue, .body-products .header .side-nav li.subnav-products .spinner-layer.spinner-blue, .body-attributes .header .side-nav li.subnav-attributes .spinner-layer.spinner-blue, .body-categories .header .side-nav li.subnav-categories .spinner-layer.spinner-blue, .body-orders .header .side-nav li.subnav-orders .spinner-layer.spinner-blue, .body-payments .header .side-nav li.subnav-payments .spinner-layer.spinner-blue, .body-customers .header .side-nav li.subnav-customers .spinner-layer.spinner-blue, .body-discounts .header .side-nav li.subnav-discounts .spinner-layer.spinner-blue, .body-vouchers .header .side-nav li.subnav-vouchers .spinner-layer.spinner-blue, .body-sales .header .side-nav li.subnav-sales .spinner-layer.spinner-blue, form label .spinner-layer.spinner-blue {
  /* durations: 4 * ARCTIME */
  -webkit-animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both, blue-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both;
  animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both, blue-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both; }

.active .spinner-layer.spinner-red, .body-home .header .side-nav li.nav-home .spinner-layer.spinner-red, .body-products .header .side-nav li.subnav-products .spinner-layer.spinner-red, .body-attributes .header .side-nav li.subnav-attributes .spinner-layer.spinner-red, .body-categories .header .side-nav li.subnav-categories .spinner-layer.spinner-red, .body-orders .header .side-nav li.subnav-orders .spinner-layer.spinner-red, .body-payments .header .side-nav li.subnav-payments .spinner-layer.spinner-red, .body-customers .header .side-nav li.subnav-customers .spinner-layer.spinner-red, .body-discounts .header .side-nav li.subnav-discounts .spinner-layer.spinner-red, .body-vouchers .header .side-nav li.subnav-vouchers .spinner-layer.spinner-red, .body-sales .header .side-nav li.subnav-sales .spinner-layer.spinner-red, form label .spinner-layer.spinner-red {
  /* durations: 4 * ARCTIME */
  -webkit-animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both, red-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both;
  animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both, red-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both; }

.active .spinner-layer.spinner-yellow, .body-home .header .side-nav li.nav-home .spinner-layer.spinner-yellow, .body-products .header .side-nav li.subnav-products .spinner-layer.spinner-yellow, .body-attributes .header .side-nav li.subnav-attributes .spinner-layer.spinner-yellow, .body-categories .header .side-nav li.subnav-categories .spinner-layer.spinner-yellow, .body-orders .header .side-nav li.subnav-orders .spinner-layer.spinner-yellow, .body-payments .header .side-nav li.subnav-payments .spinner-layer.spinner-yellow, .body-customers .header .side-nav li.subnav-customers .spinner-layer.spinner-yellow, .body-discounts .header .side-nav li.subnav-discounts .spinner-layer.spinner-yellow, .body-vouchers .header .side-nav li.subnav-vouchers .spinner-layer.spinner-yellow, .body-sales .header .side-nav li.subnav-sales .spinner-layer.spinner-yellow, form label .spinner-layer.spinner-yellow {
  /* durations: 4 * ARCTIME */
  -webkit-animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both, yellow-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both;
  animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both, yellow-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both; }

.active .spinner-layer.spinner-green, .body-home .header .side-nav li.nav-home .spinner-layer.spinner-green, .body-products .header .side-nav li.subnav-products .spinner-layer.spinner-green, .body-attributes .header .side-nav li.subnav-attributes .spinner-layer.spinner-green, .body-categories .header .side-nav li.subnav-categories .spinner-layer.spinner-green, .body-orders .header .side-nav li.subnav-orders .spinner-layer.spinner-green, .body-payments .header .side-nav li.subnav-payments .spinner-layer.spinner-green, .body-customers .header .side-nav li.subnav-customers .spinner-layer.spinner-green, .body-discounts .header .side-nav li.subnav-discounts .spinner-layer.spinner-green, .body-vouchers .header .side-nav li.subnav-vouchers .spinner-layer.spinner-green, .body-sales .header .side-nav li.subnav-sales .spinner-layer.spinner-green, form label .spinner-layer.spinner-green {
  /* durations: 4 * ARCTIME */
  -webkit-animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both, green-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both;
  animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both, green-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both; }

.active .spinner-layer.spinner-blue-only, .body-home .header .side-nav li.nav-home .spinner-layer.spinner-blue-only, .body-products .header .side-nav li.subnav-products .spinner-layer.spinner-blue-only, .body-attributes .header .side-nav li.subnav-attributes .spinner-layer.spinner-blue-only, .body-categories .header .side-nav li.subnav-categories .spinner-layer.spinner-blue-only, .body-orders .header .side-nav li.subnav-orders .spinner-layer.spinner-blue-only, .body-payments .header .side-nav li.subnav-payments .spinner-layer.spinner-blue-only, .body-customers .header .side-nav li.subnav-customers .spinner-layer.spinner-blue-only, .body-discounts .header .side-nav li.subnav-discounts .spinner-layer.spinner-blue-only, .body-vouchers .header .side-nav li.subnav-vouchers .spinner-layer.spinner-blue-only, .body-sales .header .side-nav li.subnav-sales .spinner-layer.spinner-blue-only, form label .spinner-layer.spinner-blue-only,
.active .spinner-layer.spinner-red-only, .body-home .header .side-nav li.nav-home .spinner-layer.spinner-red-only, .body-products .header .side-nav li.subnav-products .spinner-layer.spinner-red-only, .body-attributes .header .side-nav li.subnav-attributes .spinner-layer.spinner-red-only, .body-categories .header .side-nav li.subnav-categories .spinner-layer.spinner-red-only, .body-orders .header .side-nav li.subnav-orders .spinner-layer.spinner-red-only, .body-payments .header .side-nav li.subnav-payments .spinner-layer.spinner-red-only, .body-customers .header .side-nav li.subnav-customers .spinner-layer.spinner-red-only, .body-discounts .header .side-nav li.subnav-discounts .spinner-layer.spinner-red-only, .body-vouchers .header .side-nav li.subnav-vouchers .spinner-layer.spinner-red-only, .body-sales .header .side-nav li.subnav-sales .spinner-layer.spinner-red-only, form label .spinner-layer.spinner-red-only,
.active .spinner-layer.spinner-yellow-only, .body-home .header .side-nav li.nav-home .spinner-layer.spinner-yellow-only, .body-products .header .side-nav li.subnav-products .spinner-layer.spinner-yellow-only, .body-attributes .header .side-nav li.subnav-attributes .spinner-layer.spinner-yellow-only, .body-categories .header .side-nav li.subnav-categories .spinner-layer.spinner-yellow-only, .body-orders .header .side-nav li.subnav-orders .spinner-layer.spinner-yellow-only, .body-payments .header .side-nav li.subnav-payments .spinner-layer.spinner-yellow-only, .body-customers .header .side-nav li.subnav-customers .spinner-layer.spinner-yellow-only, .body-discounts .header .side-nav li.subnav-discounts .spinner-layer.spinner-yellow-only, .body-vouchers .header .side-nav li.subnav-vouchers .spinner-layer.spinner-yellow-only, .body-sales .header .side-nav li.subnav-sales .spinner-layer.spinner-yellow-only, form label .spinner-layer.spinner-yellow-only,
.active .spinner-layer.spinner-green-only, .body-home .header .side-nav li.nav-home .spinner-layer.spinner-green-only, .body-products .header .side-nav li.subnav-products .spinner-layer.spinner-green-only, .body-attributes .header .side-nav li.subnav-attributes .spinner-layer.spinner-green-only, .body-categories .header .side-nav li.subnav-categories .spinner-layer.spinner-green-only, .body-orders .header .side-nav li.subnav-orders .spinner-layer.spinner-green-only, .body-payments .header .side-nav li.subnav-payments .spinner-layer.spinner-green-only, .body-customers .header .side-nav li.subnav-customers .spinner-layer.spinner-green-only, .body-discounts .header .side-nav li.subnav-discounts .spinner-layer.spinner-green-only, .body-vouchers .header .side-nav li.subnav-vouchers .spinner-layer.spinner-green-only, .body-sales .header .side-nav li.subnav-sales .spinner-layer.spinner-green-only, form label .spinner-layer.spinner-green-only {
  /* durations: 4 * ARCTIME */
  opacity: 1;
  -webkit-animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both;
  animation: fill-unfill-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both; }

@-webkit-keyframes fill-unfill-rotate {
  12.5% {
    -webkit-transform: rotate(135deg); }
  /* 0.5 * ARCSIZE */
  25% {
    -webkit-transform: rotate(270deg); }
  /* 1   * ARCSIZE */
  37.5% {
    -webkit-transform: rotate(405deg); }
  /* 1.5 * ARCSIZE */
  50% {
    -webkit-transform: rotate(540deg); }
  /* 2   * ARCSIZE */
  62.5% {
    -webkit-transform: rotate(675deg); }
  /* 2.5 * ARCSIZE */
  75% {
    -webkit-transform: rotate(810deg); }
  /* 3   * ARCSIZE */
  87.5% {
    -webkit-transform: rotate(945deg); }
  /* 3.5 * ARCSIZE */
  to {
    -webkit-transform: rotate(1080deg); }
  /* 4   * ARCSIZE */ }

@keyframes fill-unfill-rotate {
  12.5% {
    -webkit-transform: rotate(135deg);
            transform: rotate(135deg); }
  /* 0.5 * ARCSIZE */
  25% {
    -webkit-transform: rotate(270deg);
            transform: rotate(270deg); }
  /* 1   * ARCSIZE */
  37.5% {
    -webkit-transform: rotate(405deg);
            transform: rotate(405deg); }
  /* 1.5 * ARCSIZE */
  50% {
    -webkit-transform: rotate(540deg);
            transform: rotate(540deg); }
  /* 2   * ARCSIZE */
  62.5% {
    -webkit-transform: rotate(675deg);
            transform: rotate(675deg); }
  /* 2.5 * ARCSIZE */
  75% {
    -webkit-transform: rotate(810deg);
            transform: rotate(810deg); }
  /* 3   * ARCSIZE */
  87.5% {
    -webkit-transform: rotate(945deg);
            transform: rotate(945deg); }
  /* 3.5 * ARCSIZE */
  to {
    -webkit-transform: rotate(1080deg);
            transform: rotate(1080deg); }
  /* 4   * ARCSIZE */ }

@-webkit-keyframes blue-fade-in-out {
  from {
    opacity: 1; }
  25% {
    opacity: 1; }
  26% {
    opacity: 0; }
  89% {
    opacity: 0; }
  90% {
    opacity: 1; }
  100% {
    opacity: 1; } }

@keyframes blue-fade-in-out {
  from {
    opacity: 1; }
  25% {
    opacity: 1; }
  26% {
    opacity: 0; }
  89% {
    opacity: 0; }
  90% {
    opacity: 1; }
  100% {
    opacity: 1; } }

@-webkit-keyframes red-fade-in-out {
  from {
    opacity: 0; }
  15% {
    opacity: 0; }
  25% {
    opacity: 1; }
  50% {
    opacity: 1; }
  51% {
    opacity: 0; } }

@keyframes red-fade-in-out {
  from {
    opacity: 0; }
  15% {
    opacity: 0; }
  25% {
    opacity: 1; }
  50% {
    opacity: 1; }
  51% {
    opacity: 0; } }

@-webkit-keyframes yellow-fade-in-out {
  from {
    opacity: 0; }
  40% {
    opacity: 0; }
  50% {
    opacity: 1; }
  75% {
    opacity: 1; }
  76% {
    opacity: 0; } }

@keyframes yellow-fade-in-out {
  from {
    opacity: 0; }
  40% {
    opacity: 0; }
  50% {
    opacity: 1; }
  75% {
    opacity: 1; }
  76% {
    opacity: 0; } }

@-webkit-keyframes green-fade-in-out {
  from {
    opacity: 0; }
  65% {
    opacity: 0; }
  75% {
    opacity: 1; }
  90% {
    opacity: 1; }
  100% {
    opacity: 0; } }

@keyframes green-fade-in-out {
  from {
    opacity: 0; }
  65% {
    opacity: 0; }
  75% {
    opacity: 1; }
  90% {
    opacity: 1; }
  100% {
    opacity: 0; } }

/**
 * Patch the gap that appear between the two adjacent div.circle-clipper while the
 * spinner is rotating (appears on Chrome 38, Safari 7.1, and IE 11).
 */
.gap-patch {
  position: absolute;
  top: 0;
  left: 45%;
  width: 10%;
  height: 100%;
  overflow: hidden;
  border-color: inherit; }

.gap-patch .circle {
  width: 1000%;
  left: -450%; }

.circle-clipper {
  display: inline-block;
  position: relative;
  width: 50%;
  height: 100%;
  overflow: hidden;
  border-color: inherit; }
  .circle-clipper .circle {
    width: 200%;
    height: 100%;
    border-width: 3px;
    /* STROKEWIDTH */
    border-style: solid;
    border-color: inherit;
    border-bottom-color: transparent !important;
    border-radius: 50%;
    -webkit-animation: none;
    animation: none;
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0; }
  .circle-clipper.left .circle {
    left: 0;
    border-right-color: transparent !important;
    -webkit-transform: rotate(129deg);
    transform: rotate(129deg); }
  .circle-clipper.right .circle {
    left: -100%;
    border-left-color: transparent !important;
    -webkit-transform: rotate(-129deg);
    transform: rotate(-129deg); }

.active .circle-clipper.left .circle, .body-home .header .side-nav li.nav-home .circle-clipper.left .circle, .body-products .header .side-nav li.subnav-products .circle-clipper.left .circle, .body-attributes .header .side-nav li.subnav-attributes .circle-clipper.left .circle, .body-categories .header .side-nav li.subnav-categories .circle-clipper.left .circle, .body-orders .header .side-nav li.subnav-orders .circle-clipper.left .circle, .body-payments .header .side-nav li.subnav-payments .circle-clipper.left .circle, .body-customers .header .side-nav li.subnav-customers .circle-clipper.left .circle, .body-discounts .header .side-nav li.subnav-discounts .circle-clipper.left .circle, .body-vouchers .header .side-nav li.subnav-vouchers .circle-clipper.left .circle, .body-sales .header .side-nav li.subnav-sales .circle-clipper.left .circle, form label .circle-clipper.left .circle {
  /* duration: ARCTIME */
  -webkit-animation: left-spin 1333ms cubic-bezier(0.4, 0, 0.2, 1) infinite both;
  animation: left-spin 1333ms cubic-bezier(0.4, 0, 0.2, 1) infinite both; }

.active .circle-clipper.right .circle, .body-home .header .side-nav li.nav-home .circle-clipper.right .circle, .body-products .header .side-nav li.subnav-products .circle-clipper.right .circle, .body-attributes .header .side-nav li.subnav-attributes .circle-clipper.right .circle, .body-categories .header .side-nav li.subnav-categories .circle-clipper.right .circle, .body-orders .header .side-nav li.subnav-orders .circle-clipper.right .circle, .body-payments .header .side-nav li.subnav-payments .circle-clipper.right .circle, .body-customers .header .side-nav li.subnav-customers .circle-clipper.right .circle, .body-discounts .header .side-nav li.subnav-discounts .circle-clipper.right .circle, .body-vouchers .header .side-nav li.subnav-vouchers .circle-clipper.right .circle, .body-sales .header .side-nav li.subnav-sales .circle-clipper.right .circle, form label .circle-clipper.right .circle {
  /* duration: ARCTIME */
  -webkit-animation: right-spin 1333ms cubic-bezier(0.4, 0, 0.2, 1) infinite both;
  animation: right-spin 1333ms cubic-bezier(0.4, 0, 0.2, 1) infinite both; }

@-webkit-keyframes left-spin {
  from {
    -webkit-transform: rotate(130deg); }
  50% {
    -webkit-transform: rotate(-5deg); }
  to {
    -webkit-transform: rotate(130deg); } }

@keyframes left-spin {
  from {
    -webkit-transform: rotate(130deg);
            transform: rotate(130deg); }
  50% {
    -webkit-transform: rotate(-5deg);
            transform: rotate(-5deg); }
  to {
    -webkit-transform: rotate(130deg);
            transform: rotate(130deg); } }

@-webkit-keyframes right-spin {
  from {
    -webkit-transform: rotate(-130deg); }
  50% {
    -webkit-transform: rotate(5deg); }
  to {
    -webkit-transform: rotate(-130deg); } }

@keyframes right-spin {
  from {
    -webkit-transform: rotate(-130deg);
            transform: rotate(-130deg); }
  50% {
    -webkit-transform: rotate(5deg);
            transform: rotate(5deg); }
  to {
    -webkit-transform: rotate(-130deg);
            transform: rotate(-130deg); } }

#spinnerContainer.cooldown {
  /* duration: SHRINK_TIME */
  -webkit-animation: container-rotate 1568ms linear infinite, fade-out 400ms cubic-bezier(0.4, 0, 0.2, 1);
  animation: container-rotate 1568ms linear infinite, fade-out 400ms cubic-bezier(0.4, 0, 0.2, 1); }

@-webkit-keyframes fade-out {
  from {
    opacity: 1; }
  to {
    opacity: 0; } }

@keyframes fade-out {
  from {
    opacity: 1; }
  to {
    opacity: 0; } }

.slider {
  position: relative;
  height: 400px;
  width: 100%; }
  .slider.fullscreen {
    height: 100%;
    width: 100%;
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0; }
    .slider.fullscreen ul.slides {
      height: 100%; }
    .slider.fullscreen ul.indicators {
      z-index: 2;
      bottom: 30px; }
  .slider .slides {
    background-color: #9e9e9e;
    margin: 0;
    height: 400px; }
    .slider .slides li {
      opacity: 0;
      position: absolute;
      top: 0;
      left: 0;
      z-index: 1;
      width: 100%;
      height: inherit;
      overflow: hidden; }
      .slider .slides li img {
        height: 100%;
        width: 100%;
        background-size: cover;
        background-position: center; }
      .slider .slides li .caption {
        color: #fff;
        position: absolute;
        top: 15%;
        left: 15%;
        width: 70%;
        opacity: 0; }
        .slider .slides li .caption p {
          color: #e0e0e0; }
      .slider .slides li.active, .slider .slides .body-home .header .side-nav li.nav-home, .body-home .header .side-nav .slider .slides li.nav-home, .slider .slides .body-products .header .side-nav li.subnav-products, .body-products .header .side-nav .slider .slides li.subnav-products, .slider .slides .body-attributes .header .side-nav li.subnav-attributes, .body-attributes .header .side-nav .slider .slides li.subnav-attributes, .slider .slides .body-categories .header .side-nav li.subnav-categories, .body-categories .header .side-nav .slider .slides li.subnav-categories, .slider .slides .body-orders .header .side-nav li.subnav-orders, .body-orders .header .side-nav .slider .slides li.subnav-orders, .slider .slides .body-payments .header .side-nav li.subnav-payments, .body-payments .header .side-nav .slider .slides li.subnav-payments, .slider .slides .body-customers .header .side-nav li.subnav-customers, .body-customers .header .side-nav .slider .slides li.subnav-customers, .slider .slides .body-discounts .header .side-nav li.subnav-discounts, .body-discounts .header .side-nav .slider .slides li.subnav-discounts, .slider .slides .body-vouchers .header .side-nav li.subnav-vouchers, .body-vouchers .header .side-nav .slider .slides li.subnav-vouchers, .slider .slides .body-sales .header .side-nav li.subnav-sales, .body-sales .header .side-nav .slider .slides li.subnav-sales {
        z-index: 2; }
  .slider .indicators {
    position: absolute;
    text-align: center;
    left: 0;
    right: 0;
    bottom: 0;
    margin: 0; }
    .slider .indicators .indicator-item {
      display: inline-block;
      position: relative;
      cursor: pointer;
      height: 16px;
      width: 16px;
      margin: 0 12px;
      background-color: #e0e0e0;
      -webkit-transition: background-color 0.3s;
      transition: background-color 0.3s;
      border-radius: 50%; }
      .slider .indicators .indicator-item.active, .slider .indicators .body-home .header .side-nav li.indicator-item.nav-home, .body-home .header .side-nav .slider .indicators li.indicator-item.nav-home, .slider .indicators .body-products .header .side-nav li.indicator-item.subnav-products, .body-products .header .side-nav .slider .indicators li.indicator-item.subnav-products, .slider .indicators .body-attributes .header .side-nav li.indicator-item.subnav-attributes, .body-attributes .header .side-nav .slider .indicators li.indicator-item.subnav-attributes, .slider .indicators .body-categories .header .side-nav li.indicator-item.subnav-categories, .body-categories .header .side-nav .slider .indicators li.indicator-item.subnav-categories, .slider .indicators .body-orders .header .side-nav li.indicator-item.subnav-orders, .body-orders .header .side-nav .slider .indicators li.indicator-item.subnav-orders, .slider .indicators .body-payments .header .side-nav li.indicator-item.subnav-payments, .body-payments .header .side-nav .slider .indicators li.indicator-item.subnav-payments, .slider .indicators .body-customers .header .side-nav li.indicator-item.subnav-customers, .body-customers .header .side-nav .slider .indicators li.indicator-item.subnav-customers, .slider .indicators .body-discounts .header .side-nav li.indicator-item.subnav-discounts, .body-discounts .header .side-nav .slider .indicators li.indicator-item.subnav-discounts, .slider .indicators .body-vouchers .header .side-nav li.indicator-item.subnav-vouchers, .body-vouchers .header .side-nav .slider .indicators li.indicator-item.subnav-vouchers, .slider .indicators .body-sales .header .side-nav li.indicator-item.subnav-sales, .body-sales .header .side-nav .slider .indicators li.indicator-item.subnav-sales, .slider .indicators form label.indicator-item, form .slider .indicators label.indicator-item {
        background-color: #4CAF50; }

/* ==========================================================================
   $BASE-PICKER
   ========================================================================== */
/**
 * Note: the root picker element should *NOT* be styled more than what's here.
 */
.picker {
  font-size: 16px;
  text-align: left;
  line-height: 1.2;
  color: #000000;
  position: absolute;
  z-index: 10000;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

/**
 * The picker input element.
 */
.picker__input {
  cursor: default; }

/**
 * When the picker is opened, the input element is "activated".
 */
.picker__input.picker__input--active {
  border-color: #0089ec; }

/**
 * The holder is the only "scrollable" top-level container element.
 */
.picker__holder {
  width: 100%;
  overflow-y: auto;
  -webkit-overflow-scrolling: touch; }

/*!
 * Default mobile-first, responsive styling for pickadate.js
 * Demo: http://amsul.github.io/pickadate.js
 */
/**
 * Note: the root picker element should *NOT* be styled more than what's here.
 */
/**
 * Make the holder and frame fullscreen.
 */
.picker__holder,
.picker__frame {
  bottom: 0;
  left: 0;
  right: 0;
  top: 100%; }

/**
 * The holder should overlay the entire screen.
 */
.picker__holder {
  position: fixed;
  -webkit-transition: background 0.15s ease-out, top 0s 0.15s;
  transition: background 0.15s ease-out, top 0s 0.15s;
  -webkit-backface-visibility: hidden; }

/**
 * The frame that bounds the box contents of the picker.
 */
.picker__frame {
  position: absolute;
  margin: 0 auto;
  min-width: 256px;
  width: 300px;
  max-height: 350px;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
  filter: alpha(opacity=0);
  -moz-opacity: 0;
  opacity: 0;
  -webkit-transition: all 0.15s ease-out;
  transition: all 0.15s ease-out; }

@media (min-height: 28.875em) {
  .picker__frame {
    overflow: visible;
    top: auto;
    bottom: -100%;
    max-height: 80%; } }

@media (min-height: 40.125em) {
  .picker__frame {
    margin-bottom: 7.5%; } }

/**
 * The wrapper sets the stage to vertically align the box contents.
 */
.picker__wrap {
  display: table;
  width: 100%;
  height: 100%; }

@media (min-height: 28.875em) {
  .picker__wrap {
    display: block; } }

/**
 * The box contains all the picker contents.
 */
.picker__box {
  background: #ffffff;
  display: table-cell;
  vertical-align: middle; }

@media (min-height: 28.875em) {
  .picker__box {
    display: block;
    border: 1px solid #777777;
    border-top-color: #898989;
    border-bottom-width: 0;
    border-radius: 5px 5px 0 0;
    box-shadow: 0 12px 36px 16px rgba(0, 0, 0, 0.24); } }

/**
 * When the picker opens...
 */
.picker--opened .picker__holder {
  top: 0;
  background: transparent;
  -ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorstr=#1E000000,endColorstr=#1E000000)";
  zoom: 1;
  background: rgba(0, 0, 0, 0.32);
  -webkit-transition: background 0.15s ease-out;
  transition: background 0.15s ease-out; }

.picker--opened .picker__frame {
  top: 0;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
  filter: alpha(opacity=100);
  -moz-opacity: 1;
  opacity: 1; }

@media (min-height: 35.875em) {
  .picker--opened .picker__frame {
    top: 10%;
    bottom: 20%auto; } }

/**
 * For `large` screens, transform into an inline picker.
 */
/* ==========================================================================
   CUSTOM MATERIALIZE STYLES
   ========================================================================== */
.picker__input.picker__input--active {
  border-color: #E3F2FD; }

.picker__frame {
  margin: 0 auto;
  max-width: 325px; }

@media (min-height: 38.875em) {
  .picker--opened .picker__frame {
    top: 10%;
    bottom: auto; } }

/* ==========================================================================
   $BASE-DATE-PICKER
   ========================================================================== */
/**
 * The picker box.
 */
.picker__box {
  padding: 0 1em; }

/**
 * The header containing the month and year stuff.
 */
.picker__header {
  text-align: center;
  position: relative;
  margin-top: .75em; }

/**
 * The month and year labels.
 */
.picker__month,
.picker__year {
  display: inline-block;
  margin-left: .25em;
  margin-right: .25em; }

/**
 * The month and year selectors.
 */
.picker__select--month,
.picker__select--year {
  height: 2em;
  padding: 0;
  margin-left: .25em;
  margin-right: .25em; }

.picker__select--month.browser-default {
  display: inline;
  background-color: #FFFFFF;
  width: 40%; }

.picker__select--year.browser-default {
  display: inline;
  background-color: #FFFFFF;
  width: 25%; }

.picker__select--month:focus,
.picker__select--year:focus {
  border-color: rgba(0, 0, 0, 0.05); }

/**
 * The month navigation buttons.
 */
.picker__nav--prev,
.picker__nav--next {
  position: absolute;
  padding: .5em 1.25em;
  width: 1em;
  height: 1em;
  box-sizing: content-box;
  top: -0.25em; }

.picker__nav--prev {
  left: -1em;
  padding-right: 1.25em; }

.picker__nav--next {
  right: -1em;
  padding-left: 1.25em; }

.picker__nav--disabled,
.picker__nav--disabled:hover,
.picker__nav--disabled:before,
.picker__nav--disabled:before:hover {
  cursor: default;
  background: none;
  border-right-color: #f5f5f5;
  border-left-color: #f5f5f5; }

/**
 * The calendar table of dates
 */
.picker__table {
  text-align: center;
  border-collapse: collapse;
  border-spacing: 0;
  table-layout: fixed;
  font-size: 1rem;
  width: 100%;
  margin-top: .75em;
  margin-bottom: .5em; }

.picker__table th, .picker__table td {
  text-align: center; }

.picker__table td {
  margin: 0;
  padding: 0; }

/**
 * The weekday labels
 */
.picker__weekday {
  width: 14.285714286%;
  font-size: .75em;
  padding-bottom: .25em;
  color: #999999;
  font-weight: 500;
  /* Increase the spacing a tad */ }

@media (min-height: 33.875em) {
  .picker__weekday {
    padding-bottom: .5em; } }

/**
 * The days on the calendar
 */
.picker__day--today {
  position: relative;
  color: #595959;
  letter-spacing: -.3;
  padding: .75rem 0;
  font-weight: 400;
  border: 1px solid transparent; }

.picker__day--disabled:before {
  border-top-color: #aaaaaa; }

.picker__day--infocus:hover {
  cursor: pointer;
  color: #000;
  font-weight: 500; }

.picker__day--outfocus {
  display: none;
  padding: .75rem 0;
  color: #fff; }

.picker__day--outfocus:hover {
  cursor: pointer;
  color: #dddddd;
  font-weight: 500; }

.picker__day--highlighted:hover,
.picker--focused .picker__day--highlighted {
  cursor: pointer; }

.picker__day--selected,
.picker__day--selected:hover,
.picker--focused .picker__day--selected {
  border-radius: 50%;
  -webkit-transform: scale(0.75);
  transform: scale(0.75);
  background: #0089ec;
  color: #ffffff; }

.picker__day--disabled,
.picker__day--disabled:hover,
.picker--focused .picker__day--disabled {
  background: #f5f5f5;
  border-color: #f5f5f5;
  color: #dddddd;
  cursor: default; }

.picker__day--highlighted.picker__day--disabled,
.picker__day--highlighted.picker__day--disabled:hover {
  background: #bbbbbb; }

/**
 * The footer containing the "today", "clear", and "close" buttons.
 */
.picker__footer {
  text-align: center;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center;
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between; }

.picker__button--today,
.picker__button--clear,
.picker__button--close {
  border: 1px solid #ffffff;
  background: #ffffff;
  font-size: .8em;
  padding: .66em 0;
  font-weight: bold;
  width: 33%;
  display: inline-block;
  vertical-align: bottom; }

.picker__button--today:hover,
.picker__button--clear:hover,
.picker__button--close:hover {
  cursor: pointer;
  color: #000000;
  background: #b1dcfb;
  border-bottom-color: #b1dcfb; }

.picker__button--today:focus,
.picker__button--clear:focus,
.picker__button--close:focus {
  background: #b1dcfb;
  border-color: rgba(0, 0, 0, 0.05);
  outline: none; }

.picker__button--today:before,
.picker__button--clear:before,
.picker__button--close:before {
  position: relative;
  display: inline-block;
  height: 0; }

.picker__button--today:before,
.picker__button--clear:before {
  content: " ";
  margin-right: .45em; }

.picker__button--today:before {
  top: -0.05em;
  width: 0;
  border-top: 0.66em solid #0059bc;
  border-left: .66em solid transparent; }

.picker__button--clear:before {
  top: -0.25em;
  width: .66em;
  border-top: 3px solid #ee2200; }

.picker__button--close:before {
  content: "\D7";
  top: -0.1em;
  vertical-align: top;
  font-size: 1.1em;
  margin-right: .35em;
  color: #777777; }

.picker__button--today[disabled],
.picker__button--today[disabled]:hover {
  background: #f5f5f5;
  border-color: #f5f5f5;
  color: #dddddd;
  cursor: default; }

.picker__button--today[disabled]:before {
  border-top-color: #aaaaaa; }

/* ==========================================================================
   CUSTOM MATERIALIZE STYLES
   ========================================================================== */
.picker__box {
  border-radius: 2px;
  overflow: hidden; }

.picker__date-display {
  text-align: center;
  background-color: #26a69a;
  color: #fff;
  padding-bottom: 15px;
  font-weight: 300; }

.picker__nav--prev:hover,
.picker__nav--next:hover {
  cursor: pointer;
  color: #000000;
  background: #a1ded8; }

.picker__weekday-display {
  background-color: #1f897f;
  padding: 10px;
  font-weight: 200;
  letter-spacing: .5;
  font-size: 1rem;
  margin-bottom: 15px; }

.picker__month-display {
  text-transform: uppercase;
  font-size: 2rem; }

.picker__day-display {
  font-size: 4.5rem;
  font-weight: 400; }

.picker__year-display {
  font-size: 1.8rem;
  color: rgba(255, 255, 255, 0.4); }

.picker__box {
  padding: 0; }

.picker__calendar-container {
  padding: 0 1rem; }
  .picker__calendar-container thead {
    border: none; }

.picker__table {
  margin-top: 0;
  margin-bottom: .5em; }

.picker__day--infocus {
  color: #595959;
  letter-spacing: -.3;
  padding: .75rem 0;
  font-weight: 400;
  border: 1px solid transparent; }

.picker__day.picker__day--today {
  color: #26a69a; }

.picker__day.picker__day--today.picker__day--selected {
  color: #fff; }

.picker__weekday {
  font-size: .9rem; }

.picker__day--selected,
.picker__day--selected:hover,
.picker--focused .picker__day--selected {
  border-radius: 50%;
  -webkit-transform: scale(0.9);
  transform: scale(0.9);
  background-color: #26a69a;
  color: #ffffff; }
  .picker__day--selected.picker__day--outfocus,
  .picker__day--selected:hover.picker__day--outfocus,
  .picker--focused .picker__day--selected.picker__day--outfocus {
    background-color: #a1ded8; }

.picker__footer {
  text-align: right;
  padding: 5px 10px; }

.picker__close, .picker__today {
  font-size: 1.1rem;
  padding: 0 1rem;
  color: #26a69a; }

.picker__nav--prev:before,
.picker__nav--next:before {
  content: " ";
  border-top: .5em solid transparent;
  border-bottom: .5em solid transparent;
  border-right: 0.75em solid #676767;
  width: 0;
  height: 0;
  display: block;
  margin: 0 auto; }

.picker__nav--next:before {
  border-right: 0;
  border-left: 0.75em solid #676767; }

button.picker__today:focus, button.picker__clear:focus, button.picker__close:focus {
  background-color: #a1ded8; }

/* ==========================================================================
   $BASE-TIME-PICKER
   ========================================================================== */
/**
 * The list of times.
 */
.picker__list {
  list-style: none;
  padding: 0.75em 0 4.2em;
  margin: 0; }

/**
 * The times on the clock.
 */
.picker__list-item {
  border-bottom: 1px solid #dddddd;
  border-top: 1px solid #dddddd;
  margin-bottom: -1px;
  position: relative;
  background: #ffffff;
  padding: .75em 1.25em; }

@media (min-height: 46.75em) {
  .picker__list-item {
    padding: .5em 1em; } }

/* Hovered time */
.picker__list-item:hover {
  cursor: pointer;
  color: #000000;
  background: #b1dcfb;
  border-color: #0089ec;
  z-index: 10; }

/* Highlighted and hovered/focused time */
.picker__list-item--highlighted {
  border-color: #0089ec;
  z-index: 10; }

.picker__list-item--highlighted:hover,
.picker--focused .picker__list-item--highlighted {
  cursor: pointer;
  color: #000000;
  background: #b1dcfb; }

/* Selected and hovered/focused time */
.picker__list-item--selected,
.picker__list-item--selected:hover,
.picker--focused .picker__list-item--selected {
  background: #0089ec;
  color: #ffffff;
  z-index: 10; }

/* Disabled time */
.picker__list-item--disabled,
.picker__list-item--disabled:hover,
.picker--focused .picker__list-item--disabled {
  background: #f5f5f5;
  border-color: #f5f5f5;
  color: #dddddd;
  cursor: default;
  border-color: #dddddd;
  z-index: auto; }

/**
 * The clear button
 */
.picker--time .picker__button--clear {
  display: block;
  width: 80%;
  margin: 1em auto 0;
  padding: 1em 1.25em;
  background: none;
  border: 0;
  font-weight: 500;
  font-size: .67em;
  text-align: center;
  text-transform: uppercase;
  color: #666; }

.picker--time .picker__button--clear:hover,
.picker--time .picker__button--clear:focus {
  color: #000000;
  background: #b1dcfb;
  background: #ee2200;
  border-color: #ee2200;
  cursor: pointer;
  color: #ffffff;
  outline: none; }

.picker--time .picker__button--clear:before {
  top: -0.25em;
  color: #666;
  font-size: 1.25em;
  font-weight: bold; }

.picker--time .picker__button--clear:hover:before,
.picker--time .picker__button--clear:focus:before {
  color: #ffffff; }

/* ==========================================================================
   $DEFAULT-TIME-PICKER
   ========================================================================== */
/**
 * The frame the bounds the time picker.
 */
.picker--time .picker__frame {
  min-width: 256px;
  max-width: 320px; }

/**
 * The picker box.
 */
.picker--time .picker__box {
  font-size: 1em;
  background: #f2f2f2;
  padding: 0; }

@media (min-height: 40.125em) {
  .picker--time .picker__box {
    margin-bottom: 5em; } }

.select2-container {
  box-sizing: border-box;
  display: inline-block;
  margin: 0;
  position: relative;
  vertical-align: middle; }
  .select2-container .select2-selection--single {
    box-sizing: border-box;
    cursor: pointer;
    display: block;
    height: 28px;
    -moz-user-select: none;
     -ms-user-select: none;
         user-select: none;
    -webkit-user-select: none; }
    .select2-container .select2-selection--single .select2-selection__rendered {
      display: block;
      padding-left: 8px;
      padding-right: 20px;
      overflow: hidden;
      text-overflow: ellipsis;
      white-space: nowrap; }
    .select2-container .select2-selection--single .select2-selection__clear {
      position: relative; }
  .select2-container[dir="rtl"] .select2-selection--single .select2-selection__rendered {
    padding-right: 8px;
    padding-left: 20px; }
  .select2-container .select2-selection--multiple {
    box-sizing: border-box;
    cursor: pointer;
    display: block;
    min-height: 32px;
    -moz-user-select: none;
     -ms-user-select: none;
         user-select: none;
    -webkit-user-select: none; }
    .select2-container .select2-selection--multiple .select2-selection__rendered {
      display: inline-block;
      overflow: hidden;
      padding-left: 8px;
      text-overflow: ellipsis;
      white-space: nowrap; }
  .select2-container .select2-search--inline {
    float: left; }
    .select2-container .select2-search--inline .select2-search__field {
      box-sizing: border-box;
      border: none;
      font-size: 100%;
      margin-top: 5px;
      padding: 0; }
      .select2-container .select2-search--inline .select2-search__field::-webkit-search-cancel-button {
        -webkit-appearance: none; }

.select2-dropdown {
  background-color: white;
  border: 1px solid #aaa;
  border-radius: 4px;
  box-sizing: border-box;
  display: block;
  position: absolute;
  left: -100000px;
  width: 100%;
  z-index: 1051; }

.select2-results {
  display: block; }

.select2-results__options {
  list-style: none;
  margin: 0;
  padding: 0; }

.select2-results__option {
  padding: 6px;
  -moz-user-select: none;
   -ms-user-select: none;
       user-select: none;
  -webkit-user-select: none; }
  .select2-results__option[aria-selected] {
    cursor: pointer; }

.select2-container--open .select2-dropdown {
  left: 0; }

.select2-container--open .select2-dropdown--above {
  border-bottom: none;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0; }

.select2-container--open .select2-dropdown--below {
  border-top: none;
  border-top-left-radius: 0;
  border-top-right-radius: 0; }

.select2-search--dropdown {
  display: block;
  padding: 4px; }
  .select2-search--dropdown .select2-search__field {
    padding: 4px;
    width: 100%;
    box-sizing: border-box; }
    .select2-search--dropdown .select2-search__field::-webkit-search-cancel-button {
      -webkit-appearance: none; }
  .select2-search--dropdown.select2-search--hide {
    display: none; }

.select2-close-mask {
  border: 0;
  margin: 0;
  padding: 0;
  display: block;
  position: fixed;
  left: 0;
  top: 0;
  min-height: 100%;
  min-width: 100%;
  height: auto;
  width: auto;
  opacity: 0;
  z-index: 99;
  background-color: #fff;
  filter: alpha(opacity=0); }

.select2-hidden-accessible {
  border: 0 !important;
  clip: rect(0 0 0 0) !important;
  height: 1px !important;
  margin: -1px !important;
  overflow: hidden !important;
  padding: 0 !important;
  position: absolute !important;
  width: 1px !important; }

.select2-container--default .select2-selection--single {
  background-color: #fff;
  border: 1px solid #aaa;
  border-radius: 4px; }
  .select2-container--default .select2-selection--single .select2-selection__rendered {
    color: #444;
    line-height: 28px; }
  .select2-container--default .select2-selection--single .select2-selection__clear {
    cursor: pointer;
    float: right;
    font-weight: bold; }
  .select2-container--default .select2-selection--single .select2-selection__placeholder {
    color: #999; }
  .select2-container--default .select2-selection--single .select2-selection__arrow {
    height: 26px;
    position: absolute;
    top: 1px;
    right: 1px;
    width: 20px; }
    .select2-container--default .select2-selection--single .select2-selection__arrow b {
      border-color: #888 transparent transparent transparent;
      border-style: solid;
      border-width: 5px 4px 0 4px;
      height: 0;
      left: 50%;
      margin-left: -4px;
      margin-top: -2px;
      position: absolute;
      top: 50%;
      width: 0; }

.select2-container--default[dir="rtl"] .select2-selection--single .select2-selection__clear {
  float: left; }

.select2-container--default[dir="rtl"] .select2-selection--single .select2-selection__arrow {
  left: 1px;
  right: auto; }

.select2-container--default.select2-container--disabled .select2-selection--single {
  background-color: #eee;
  cursor: default; }
  .select2-container--default.select2-container--disabled .select2-selection--single .select2-selection__clear {
    display: none; }

.select2-container--default.select2-container--open .select2-selection--single .select2-selection__arrow b {
  border-color: transparent transparent #888 transparent;
  border-width: 0 4px 5px 4px; }

.select2-container--default .select2-selection--multiple {
  background-color: white;
  border: 1px solid #aaa;
  border-radius: 4px;
  cursor: text; }
  .select2-container--default .select2-selection--multiple .select2-selection__rendered {
    box-sizing: border-box;
    list-style: none;
    margin: 0;
    padding: 0 5px;
    width: 100%; }
    .select2-container--default .select2-selection--multiple .select2-selection__rendered li {
      list-style: none; }
  .select2-container--default .select2-selection--multiple .select2-selection__placeholder {
    color: #999;
    margin-top: 5px;
    float: left; }
  .select2-container--default .select2-selection--multiple .select2-selection__clear {
    cursor: pointer;
    float: right;
    font-weight: bold;
    margin-top: 5px;
    margin-right: 10px; }
  .select2-container--default .select2-selection--multiple .select2-selection__choice {
    background-color: #e4e4e4;
    border: 1px solid #aaa;
    border-radius: 4px;
    cursor: default;
    float: left;
    margin-right: 5px;
    margin-top: 5px;
    padding: 0 5px; }
  .select2-container--default .select2-selection--multiple .select2-selection__choice__remove {
    color: #999;
    cursor: pointer;
    display: inline-block;
    font-weight: bold;
    margin-right: 2px; }
    .select2-container--default .select2-selection--multiple .select2-selection__choice__remove:hover {
      color: #333; }

.select2-container--default[dir="rtl"] .select2-selection--multiple .select2-selection__choice, .select2-container--default[dir="rtl"] .select2-selection--multiple .select2-selection__placeholder, .select2-container--default[dir="rtl"] .select2-selection--multiple .select2-search--inline {
  float: right; }

.select2-container--default[dir="rtl"] .select2-selection--multiple .select2-selection__choice {
  margin-left: 5px;
  margin-right: auto; }

.select2-container--default[dir="rtl"] .select2-selection--multiple .select2-selection__choice__remove {
  margin-left: 2px;
  margin-right: auto; }

.select2-container--default.select2-container--focus .select2-selection--multiple {
  border: solid black 1px;
  outline: 0; }

.select2-container--default.select2-container--disabled .select2-selection--multiple {
  background-color: #eee;
  cursor: default; }

.select2-container--default.select2-container--disabled .select2-selection__choice__remove {
  display: none; }

.select2-container--default.select2-container--open.select2-container--above .select2-selection--single, .select2-container--default.select2-container--open.select2-container--above .select2-selection--multiple {
  border-top-left-radius: 0;
  border-top-right-radius: 0; }

.select2-container--default.select2-container--open.select2-container--below .select2-selection--single, .select2-container--default.select2-container--open.select2-container--below .select2-selection--multiple {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0; }

.select2-container--default .select2-search--dropdown .select2-search__field {
  border: 1px solid #aaa; }

.select2-container--default .select2-search--inline .select2-search__field {
  background: transparent;
  border: none;
  outline: 0;
  box-shadow: none;
  -webkit-appearance: textfield; }

.select2-container--default .select2-results > .select2-results__options {
  max-height: 200px;
  overflow-y: auto; }

.select2-container--default .select2-results__option[role=group] {
  padding: 0; }

.select2-container--default .select2-results__option[aria-disabled=true] {
  color: #999; }

.select2-container--default .select2-results__option[aria-selected=true] {
  background-color: #ddd; }

.select2-container--default .select2-results__option .select2-results__option {
  padding-left: 1em; }
  .select2-container--default .select2-results__option .select2-results__option .select2-results__group {
    padding-left: 0; }
  .select2-container--default .select2-results__option .select2-results__option .select2-results__option {
    margin-left: -1em;
    padding-left: 2em; }
    .select2-container--default .select2-results__option .select2-results__option .select2-results__option .select2-results__option {
      margin-left: -2em;
      padding-left: 3em; }
      .select2-container--default .select2-results__option .select2-results__option .select2-results__option .select2-results__option .select2-results__option {
        margin-left: -3em;
        padding-left: 4em; }
        .select2-container--default .select2-results__option .select2-results__option .select2-results__option .select2-results__option .select2-results__option .select2-results__option {
          margin-left: -4em;
          padding-left: 5em; }
          .select2-container--default .select2-results__option .select2-results__option .select2-results__option .select2-results__option .select2-results__option .select2-results__option .select2-results__option {
            margin-left: -5em;
            padding-left: 6em; }

.select2-container--default .select2-results__option--highlighted[aria-selected] {
  background-color: #5897fb;
  color: white; }

.select2-container--default .select2-results__group {
  cursor: default;
  display: block;
  padding: 6px; }

.select2-container--classic .select2-selection--single {
  background-color: #f7f7f7;
  border: 1px solid #aaa;
  border-radius: 4px;
  outline: 0;
  background-image: -webkit-linear-gradient(top, white 50%, #eeeeee 100%);
  background-image: linear-gradient(to bottom, white 50%, #eeeeee 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFFFFFFF', endColorstr='#FFEEEEEE', GradientType=0); }
  .select2-container--classic .select2-selection--single:focus {
    border: 1px solid #5897fb; }
  .select2-container--classic .select2-selection--single .select2-selection__rendered {
    color: #444;
    line-height: 28px; }
  .select2-container--classic .select2-selection--single .select2-selection__clear {
    cursor: pointer;
    float: right;
    font-weight: bold;
    margin-right: 10px; }
  .select2-container--classic .select2-selection--single .select2-selection__placeholder {
    color: #999; }
  .select2-container--classic .select2-selection--single .select2-selection__arrow {
    background-color: #ddd;
    border: none;
    border-left: 1px solid #aaa;
    border-top-right-radius: 4px;
    border-bottom-right-radius: 4px;
    height: 26px;
    position: absolute;
    top: 1px;
    right: 1px;
    width: 20px;
    background-image: -webkit-linear-gradient(top, #eeeeee 50%, #cccccc 100%);
    background-image: linear-gradient(to bottom, #eeeeee 50%, #cccccc 100%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFEEEEEE', endColorstr='#FFCCCCCC', GradientType=0); }
    .select2-container--classic .select2-selection--single .select2-selection__arrow b {
      border-color: #888 transparent transparent transparent;
      border-style: solid;
      border-width: 5px 4px 0 4px;
      height: 0;
      left: 50%;
      margin-left: -4px;
      margin-top: -2px;
      position: absolute;
      top: 50%;
      width: 0; }

.select2-container--classic[dir="rtl"] .select2-selection--single .select2-selection__clear {
  float: left; }

.select2-container--classic[dir="rtl"] .select2-selection--single .select2-selection__arrow {
  border: none;
  border-right: 1px solid #aaa;
  border-radius: 0;
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
  left: 1px;
  right: auto; }

.select2-container--classic.select2-container--open .select2-selection--single {
  border: 1px solid #5897fb; }
  .select2-container--classic.select2-container--open .select2-selection--single .select2-selection__arrow {
    background: transparent;
    border: none; }
    .select2-container--classic.select2-container--open .select2-selection--single .select2-selection__arrow b {
      border-color: transparent transparent #888 transparent;
      border-width: 0 4px 5px 4px; }

.select2-container--classic.select2-container--open.select2-container--above .select2-selection--single {
  border-top: none;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
  background-image: -webkit-linear-gradient(top, white 0%, #eeeeee 50%);
  background-image: linear-gradient(to bottom, white 0%, #eeeeee 50%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFFFFFFF', endColorstr='#FFEEEEEE', GradientType=0); }

.select2-container--classic.select2-container--open.select2-container--below .select2-selection--single {
  border-bottom: none;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  background-image: -webkit-linear-gradient(top, #eeeeee 50%, white 100%);
  background-image: linear-gradient(to bottom, #eeeeee 50%, white 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#FFEEEEEE', endColorstr='#FFFFFFFF', GradientType=0); }

.select2-container--classic .select2-selection--multiple {
  background-color: white;
  border: 1px solid #aaa;
  border-radius: 4px;
  cursor: text;
  outline: 0; }
  .select2-container--classic .select2-selection--multiple:focus {
    border: 1px solid #5897fb; }
  .select2-container--classic .select2-selection--multiple .select2-selection__rendered {
    list-style: none;
    margin: 0;
    padding: 0 5px; }
  .select2-container--classic .select2-selection--multiple .select2-selection__clear {
    display: none; }
  .select2-container--classic .select2-selection--multiple .select2-selection__choice {
    background-color: #e4e4e4;
    border: 1px solid #aaa;
    border-radius: 4px;
    cursor: default;
    float: left;
    margin-right: 5px;
    margin-top: 5px;
    padding: 0 5px; }
  .select2-container--classic .select2-selection--multiple .select2-selection__choice__remove {
    color: #888;
    cursor: pointer;
    display: inline-block;
    font-weight: bold;
    margin-right: 2px; }
    .select2-container--classic .select2-selection--multiple .select2-selection__choice__remove:hover {
      color: #555; }

.select2-container--classic[dir="rtl"] .select2-selection--multiple .select2-selection__choice {
  float: right; }

.select2-container--classic[dir="rtl"] .select2-selection--multiple .select2-selection__choice {
  margin-left: 5px;
  margin-right: auto; }

.select2-container--classic[dir="rtl"] .select2-selection--multiple .select2-selection__choice__remove {
  margin-left: 2px;
  margin-right: auto; }

.select2-container--classic.select2-container--open .select2-selection--multiple {
  border: 1px solid #5897fb; }

.select2-container--classic.select2-container--open.select2-container--above .select2-selection--multiple {
  border-top: none;
  border-top-left-radius: 0;
  border-top-right-radius: 0; }

.select2-container--classic.select2-container--open.select2-container--below .select2-selection--multiple {
  border-bottom: none;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0; }

.select2-container--classic .select2-search--dropdown .select2-search__field {
  border: 1px solid #aaa;
  outline: 0; }

.select2-container--classic .select2-search--inline .select2-search__field {
  outline: 0;
  box-shadow: none; }

.select2-container--classic .select2-dropdown {
  background-color: #fff;
  border: 1px solid transparent; }

.select2-container--classic .select2-dropdown--above {
  border-bottom: none; }

.select2-container--classic .select2-dropdown--below {
  border-top: none; }

.select2-container--classic .select2-results > .select2-results__options {
  max-height: 200px;
  overflow-y: auto; }

.select2-container--classic .select2-results__option[role=group] {
  padding: 0; }

.select2-container--classic .select2-results__option[aria-disabled=true] {
  color: grey; }

.select2-container--classic .select2-results__option--highlighted[aria-selected] {
  background-color: #3875d7;
  color: white; }

.select2-container--classic .select2-results__group {
  cursor: default;
  display: block;
  padding: 6px; }

.select2-container--classic.select2-container--open .select2-dropdown {
  border-color: #5897fb; }

/*
 * The MIT License
 * Copyright (c) 2012 Matias Meno <m@tias.me>
 */
@-webkit-keyframes passing-through {
  0% {
    opacity: 0;
    -webkit-transform: translateY(40px);
    transform: translateY(40px); }
  30%, 70% {
    opacity: 1;
    -webkit-transform: translateY(0px);
    transform: translateY(0px); }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-40px);
    transform: translateY(-40px); } }

@keyframes passing-through {
  0% {
    opacity: 0;
    -webkit-transform: translateY(40px);
    transform: translateY(40px); }
  30%, 70% {
    opacity: 1;
    -webkit-transform: translateY(0px);
    transform: translateY(0px); }
  100% {
    opacity: 0;
    -webkit-transform: translateY(-40px);
    transform: translateY(-40px); } }

@-webkit-keyframes slide-in {
  0% {
    opacity: 0;
    -webkit-transform: translateY(40px);
    transform: translateY(40px); }
  30% {
    opacity: 1;
    -webkit-transform: translateY(0px);
    transform: translateY(0px); } }

@keyframes slide-in {
  0% {
    opacity: 0;
    -webkit-transform: translateY(40px);
    transform: translateY(40px); }
  30% {
    opacity: 1;
    -webkit-transform: translateY(0px);
    transform: translateY(0px); } }

@-webkit-keyframes pulse {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1); }
  10% {
    -webkit-transform: scale(1.1);
    transform: scale(1.1); }
  20% {
    -webkit-transform: scale(1);
    transform: scale(1); } }

@keyframes pulse {
  0% {
    -webkit-transform: scale(1);
    transform: scale(1); }
  10% {
    -webkit-transform: scale(1.1);
    transform: scale(1.1); }
  20% {
    -webkit-transform: scale(1);
    transform: scale(1); } }

.dropzone, .dropzone * {
  box-sizing: border-box; }

.dropzone {
  min-height: 150px;
  border: 2px solid rgba(0, 0, 0, 0.3);
  background: white;
  padding: 20px 20px; }

.dropzone.dz-clickable {
  cursor: pointer; }

.dropzone.dz-clickable * {
  cursor: default; }

.dropzone.dz-clickable .dz-message, .dropzone.dz-clickable .dz-message * {
  cursor: pointer; }

.dropzone.dz-started .dz-message {
  display: none; }

.dropzone.dz-drag-hover {
  border-style: solid; }

.dropzone.dz-drag-hover .dz-message {
  opacity: 0.5; }

.dropzone .dz-message {
  text-align: center;
  margin: 2em 0; }

.dropzone .dz-preview {
  position: relative;
  display: inline-block;
  vertical-align: top;
  margin: 16px;
  min-height: 100px; }

.dropzone .dz-preview:hover {
  z-index: 1000; }

.dropzone .dz-preview:hover .dz-details {
  opacity: 1; }

.dropzone .dz-preview.dz-file-preview .dz-image {
  border-radius: 20px;
  background: #999;
  background: -webkit-linear-gradient(top, #eee, #ddd);
  background: linear-gradient(to bottom, #eee, #ddd); }

.dropzone .dz-preview.dz-file-preview .dz-details {
  opacity: 1; }

.dropzone .dz-preview.dz-image-preview {
  background: white; }

.dropzone .dz-preview.dz-image-preview .dz-details {
  -webkit-transition: opacity 0.2s linear;
  transition: opacity 0.2s linear; }

.dropzone .dz-preview .dz-remove {
  font-size: 14px;
  text-align: center;
  display: block;
  cursor: pointer;
  border: none; }

.dropzone .dz-preview .dz-remove:hover {
  text-decoration: underline; }

.dropzone .dz-preview:hover .dz-details {
  opacity: 1; }

.dropzone .dz-preview .dz-details {
  z-index: 20;
  position: absolute;
  top: 0;
  left: 0;
  opacity: 0;
  font-size: 13px;
  min-width: 100%;
  max-width: 100%;
  padding: 2em 1em;
  text-align: center;
  color: rgba(0, 0, 0, 0.9);
  line-height: 150%; }

.dropzone .dz-preview .dz-details .dz-size {
  margin-bottom: 1em;
  font-size: 16px; }

.dropzone .dz-preview .dz-details .dz-filename {
  white-space: nowrap; }

.dropzone .dz-preview .dz-details .dz-filename:hover span {
  border: 1px solid rgba(200, 200, 200, 0.8);
  background-color: rgba(255, 255, 255, 0.8); }

.dropzone .dz-preview .dz-details .dz-filename:not(:hover) {
  overflow: hidden;
  text-overflow: ellipsis; }

.dropzone .dz-preview .dz-details .dz-filename:not(:hover) span {
  border: 1px solid transparent; }

.dropzone .dz-preview .dz-details .dz-filename span, .dropzone .dz-preview .dz-details .dz-size span {
  background-color: rgba(255, 255, 255, 0.4);
  padding: 0 0.4em;
  border-radius: 3px; }

.dropzone .dz-preview:hover .dz-image img {
  -webkit-transform: scale(1.05, 1.05);
  transform: scale(1.05, 1.05);
  -webkit-filter: blur(8px);
  filter: blur(8px); }

.dropzone .dz-preview .dz-image {
  border-radius: 20px;
  overflow: hidden;
  width: 120px;
  height: 120px;
  position: relative;
  display: block;
  z-index: 10; }

.dropzone .dz-preview .dz-image img {
  display: block; }

.dropzone .dz-preview.dz-success .dz-success-mark {
  -webkit-animation: passing-through 3s cubic-bezier(0.77, 0, 0.175, 1);
  animation: passing-through 3s cubic-bezier(0.77, 0, 0.175, 1); }

.dropzone .dz-preview.dz-error .dz-error-mark {
  opacity: 1;
  -webkit-animation: slide-in 3s cubic-bezier(0.77, 0, 0.175, 1);
  animation: slide-in 3s cubic-bezier(0.77, 0, 0.175, 1); }

.dropzone .dz-preview .dz-success-mark, .dropzone .dz-preview .dz-error-mark {
  pointer-events: none;
  opacity: 0;
  z-index: 500;
  position: absolute;
  display: block;
  top: 50%;
  left: 50%;
  margin-left: -27px;
  margin-top: -27px; }

.dropzone .dz-preview .dz-success-mark svg, .dropzone .dz-preview .dz-error-mark svg {
  display: block;
  width: 54px;
  height: 54px; }

.dropzone .dz-preview.dz-processing .dz-progress {
  opacity: 1;
  -webkit-transition: all 0.2s linear;
  transition: all 0.2s linear; }

.dropzone .dz-preview.dz-complete .dz-progress {
  opacity: 0;
  -webkit-transition: opacity 0.4s ease-in;
  transition: opacity 0.4s ease-in; }

.dropzone .dz-preview:not(.dz-processing) .dz-progress {
  -webkit-animation: pulse 6s ease infinite;
  animation: pulse 6s ease infinite; }

.dropzone .dz-preview .dz-progress {
  opacity: 1;
  z-index: 1000;
  pointer-events: none;
  position: absolute;
  height: 16px;
  left: 50%;
  top: 50%;
  margin-top: -8px;
  width: 80px;
  margin-left: -40px;
  background: rgba(255, 255, 255, 0.9);
  -webkit-transform: scale(1);
  border-radius: 8px;
  overflow: hidden; }

.dropzone .dz-preview .dz-progress .dz-upload {
  background: #333;
  background: -webkit-linear-gradient(top, #666, #444);
  background: linear-gradient(to bottom, #666, #444);
  position: absolute;
  top: 0;
  left: 0;
  bottom: 0;
  width: 0;
  -webkit-transition: width 300ms ease-in-out;
  transition: width 300ms ease-in-out; }

.dropzone .dz-preview.dz-error .dz-error-message {
  display: block; }

.dropzone .dz-preview.dz-error:hover .dz-error-message {
  opacity: 1;
  pointer-events: auto; }

.dropzone .dz-preview .dz-error-message {
  pointer-events: none;
  z-index: 1000;
  position: absolute;
  display: block;
  display: none;
  opacity: 0;
  -webkit-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
  border-radius: 8px;
  font-size: 13px;
  top: 130px;
  left: -10px;
  width: 140px;
  background: #be2626;
  background: -webkit-linear-gradient(top, #be2626, #a92222);
  background: linear-gradient(to bottom, #be2626, #a92222);
  padding: 0.5em 1.2em;
  color: white; }

.dropzone .dz-preview .dz-error-message:after {
  content: '';
  position: absolute;
  top: -6px;
  left: 64px;
  width: 0;
  height: 0;
  border-left: 6px solid transparent;
  border-right: 6px solid transparent;
  border-bottom: 6px solid #be2626; }

@media (min-width: 1201px) {
  .header {
    margin-left: 240px; } }

.header .top-nav {
  box-shadow: none;
  height: 60px;
  margin-bottom: 1.5rem; }
  .header .top-nav .container {
    height: 100%; }
  .header .top-nav .header-button {
    float: left;
    margin-right: 1.5rem; }
    @media (min-width: 993px) {
      .header .top-nav .header-button {
        display: none; } }
    .header .top-nav .header-button i {
      font-size: 2.7rem;
      height: 60px;
      line-height: 60px; }
  .header .top-nav .dropdown-button {
    float: right;
    line-height: 30px;
    position: relative;
    top: 15px; }
    .header .top-nav .dropdown-button i {
      height: 30px;
      line-height: 30px; }
  .header .top-nav .dropdown-content {
    left: auto !important;
    right: 0;
    white-space: nowrap; }

.header .side-nav {
  padding-top: 60px; }
  .header .side-nav li {
    display: block;
    padding: 0; }
    .header .side-nav li:after {
      content: "";
      display: block; }
    .header .side-nav li li:after {
      content: none; }
    .body-products .header .side-nav li.subnav-products a {
      background-color: #ee6e73; }
    .body-attributes .header .side-nav li.subnav-attributes a {
      background-color: #ee6e73; }
    .body-categories .header .side-nav li.subnav-categories a {
      background-color: #ee6e73; }
    .body-orders .header .side-nav li.subnav-orders a {
      background-color: #ee6e73; }
    .body-payments .header .side-nav li.subnav-payments a {
      background-color: #ee6e73; }
    .body-customers .header .side-nav li.subnav-customers a {
      background-color: #ee6e73; }
    .body-discounts .header .side-nav li.subnav-discounts a {
      background-color: #ee6e73; }
    .body-vouchers .header .side-nav li.subnav-vouchers a {
      background-color: #ee6e73; }
    .body-sales .header .side-nav li.subnav-sales a {
      background-color: #ee6e73; }
    .header .side-nav li.brand-logo {
      top: 0;
      width: 100%; }
      .header .side-nav li.brand-logo:hover {
        background: none; }
      .header .side-nav li.brand-logo:after {
        content: none; }
      .header .side-nav li.brand-logo a {
        display: block;
        height: 60px;
        padding: 0;
        text-align: center; }
        .header .side-nav li.brand-logo a img {
          height: 100%;
          padding: 15px 0; }
    .header .side-nav li.side-nav-user a {
      font-size: 14px;
      line-height: 64px;
      margin: 0; }
      .header .side-nav li.side-nav-user a i {
        vertical-align: inherit;
        width: auto;
        margin: 0 5px; }
        .header .side-nav li.side-nav-user a i:last-child {
          margin-right: 0; }
    .header .side-nav li.side-nav-user ul ul li a {
      line-height: 52px; }
    .header .side-nav li ul ul li a {
      background: #fafafa;
      height: 52px;
      line-height: 52px;
      padding-left: 30px;
      -webkit-transition: background-color 0.2s;
      transition: background-color 0.2s; }
      .header .side-nav li ul ul li a:hover, .header .side-nav li ul ul li a:focus {
        background-color: #ddd; }
    .header .side-nav li .collapsible-header {
      margin: 0; }
    .header .side-nav li .collapsible-body a {
      margin: 0; }
    .header .side-nav li i {
      display: inline-block;
      float: none; }
  .header .side-nav > li:hover {
    background: none; }

@media (min-width: 1201px) {
  .main {
    margin-left: 240px; } }

@media (min-width: 1201px) {
  .container {
    width: 85%; } }

.modal-content .row {
  margin-left: -.75rem;
  margin-right: -.75rem; }

.page-title {
  display: block;
  font-size: 1.64rem;
  line-height: 60px; }
  @media (max-width: 992px) {
    .page-title {
      float: right;
      width: calc(100% - 38px - 1.5rem);
      overflow: hidden;
      text-overflow: ellipsis;
      white-space: nowrap; } }

table .row .col {
  float: none;
  padding: 0.75rem; }
  table .row .col .responsive-img {
    display: block; }

.input-with-suffix input {
  float: left;
  width: calc(100% - 40px); }

.input-text-suffix {
  float: right;
  line-height: 45px;
  text-align: right;
  width: 40px; }

#modal-product-class {
  max-width: 300px; }

.pagination li.disabled span {
  color: #999; }

.btn-data-table {
  background: none;
  border: none;
  font-weight: bold;
  padding: 0;
  text-transform: uppercase; }
  .btn-data-table:hover, .btn-data-table:focus {
    background: none; }

.fixed-action-btn {
  padding: 0; }

.btn-fab {
  -webkit-transition: box-shadow 0.2s, -webkit-transform 0.2s;
  transition: box-shadow 0.2s, -webkit-transform 0.2s;
  transition: transform 0.2s, box-shadow 0.2s;
  transition: transform 0.2s, box-shadow 0.2s, -webkit-transform 0.2s; }
  .btn-fab i:before {
    -webkit-transition: font-size 0.2s;
    transition: font-size 0.2s; }

.btn-fab.btn-fab-hidden {
  -webkit-transform: scaleX(0) scaleY(0);
          transform: scaleX(0) scaleY(0); }
  .btn-fab.btn-fab-hidden i:before {
    font-size: 0; }

.card {
  overflow: initial; }
  .card img {
    display: block; }
    @media (max-width: 600px) {
      .card img {
        width: 100%; } }

.no-margin {
  margin: 0; }

@media (min-width: 1200px) {
  .switch-two-columns {
    float: left !important; }
    .switch-two-columns:first-child {
      float: right !important; } }

.text-lg {
  font-size: 120%; }

#order-details .order-summary td {
  padding: 5px 5px; }

#order-details #order-notes {
  box-shadow: none; }

.breadcrumbs {
  display: block;
  float: left;
  font-size: 1.64rem;
  line-height: 60px;
  white-space: nowrap; }
  @media (max-width: 992px) {
    .breadcrumbs {
      width: calc(100% - 38px - 1.5rem);
      overflow: hidden;
      text-overflow: ellipsis; } }
  .breadcrumbs li {
    display: none;
    float: none;
    line-height: 30px; }
    @media (min-width: 993px) {
      .breadcrumbs li {
        display: inline; } }
    .breadcrumbs li:last-child {
      display: inline; }
    .breadcrumbs li:hover {
      background: none; }
    .breadcrumbs li a {
      color: #f8c1c3;
      display: inline-block;
      font-size: 1.64rem;
      padding: 0;
      -webkit-transition: color 0.2s;
      transition: color 0.2s; }
      .breadcrumbs li a:hover {
        color: white; }
      .breadcrumbs li a:after {
        content: "\e8a9";
        color: #f8c1c3;
        display: inline-block;
        font-family: "Material-Design-Icons", sans-serif;
        margin-left: 5px;
        vertical-align: bottom; }
    .breadcrumbs li [class^=mdi-] {
      display: inline; }
  .breadcrumbs--with-menu {
    width: calc(100% - 38px - 1.5rem); }
    @media (max-width: 992px) {
      .breadcrumbs--with-menu {
        width: calc(100% - 76px - 3rem); } }
  @media (min-width: 1200px) {
    .breadcrumbs--ellipsed-item {
      display: inline-block;
      overflow: hidden;
      text-overflow: ellipsis;
      white-space: nowrap;
      max-width: 14em;
      vertical-align: middle; } }

.card .card-content .card-title {
  display: block;
  line-height: 28px;
  margin-bottom: 10px; }

.card .card-content--no-data {
  padding-top: 6px; }

@media only screen and (max-width: 992px) {
  .data-table-container {
    overflow: scroll; } }

.card .data-table-container:first-child th, .card-title + .data-table-container th {
  border-top: none; }

.data-table-header {
  padding: 21px 24px; }
  .data-table-header--no-data {
    padding: 20px 20px 0; }

.data-table-title {
  font-weight: 300;
  margin: 0; }
  .data-table-title .data-table-status {
    float: right;
    margin-top: -4px; }

.data-table-status--danger {
  color: white;
  background: #F44336;
  border-radius: 2px;
  padding: .25em 5px;
  font-size: .8em; }

.data-table-status--success {
  color: white;
  background: #81C784;
  border-radius: 2px;
  padding: .25em 5px;
  font-size: .8em; }

.data-table-status--default {
  color: white;
  background: #9e9e9e;
  border-radius: 2px;
  padding: .25em 5px;
  font-size: .8em; }

.data-table input[type=checkbox].filled-in + label {
  margin-top: 5px;
  padding: 0; }
  .data-table input[type=checkbox].filled-in + label:after {
    display: inline-block;
    position: static; }

.data-table th, .data-table td {
  height: 48px;
  overflow: hidden;
  padding: 0 28px;
  text-overflow: ellipsis;
  vertical-align: middle;
  white-space: nowrap; }
  .data-table th:first-child, .data-table td:first-child {
    padding-left: 24px; }
  .data-table th:last-child, .data-table td:last-child {
    padding-right: 24px; }
  .data-table th.no-padded, .data-table td.no-padded {
    padding: 0; }

.data-table th {
  border-top: 1px solid #d0d0d0;
  color: #757575;
  font-weight: normal;
  font-size: 85%;
  height: 56px; }

.data-table tfoot {
  font-weight: bold; }

.data-table .bulk-checkbox {
  padding: 0 24px;
  width: 1px; }
  .data-table .bulk-checkbox + th, .data-table .bulk-checkbox + td {
    padding-left: 0; }

.data-table .wide {
  width: 99%; }

.data-table.hoverable {
  box-shadow: none; }

.data-table .dropdown-button {
  padding: 15px 28px; }

.data-table .dropdown-content {
  left: auto !important;
  right: 0;
  top: 0;
  white-space: nowrap; }

.dropzone {
  border: none;
  height: 79vh;
  padding: 0;
  position: relative; }
  .dropzone.dz-clickable * {
    cursor: initial; }
  .dropzone li.dropzone-ghost {
    display: none;
    opacity: .75; }
  .dropzone.dz-drag-hover {
    border: none; }
    .dropzone.dz-drag-hover:after {
      bottom: 0;
      content: "";
      left: 0;
      position: absolute;
      right: 0;
      top: 0; }
    .dropzone.dz-drag-hover li.dropzone-ghost {
      display: block; }
  .dropzone .dz-preview .dz-progress {
    border: 0;
    border-radius: 0;
    bottom: 163px;
    height: 4px;
    top: auto;
    left: 0;
    width: 100%;
    margin: 0;
    opacity: 1 !important;
    -webkit-transition: height 0.2s !important;
    transition: height 0.2s !important; }
    .dropzone .dz-preview .dz-progress .dz-upload {
      background: #2196F3; }
  .dropzone .dz-preview.dz-complete .dz-progress {
    height: 0; }

form .select-wrapper {
  margin-top: -3px; }

form label {
  display: block; }
  form label.optional:before {
    content: "(optional)";
    float: right;
    margin-left: 3px; }

form .price-wrapper {
  overflow: hidden; }

form p.help-block {
  margin: -7px 0 15px;
  font-size: 0.8rem;
  clear: both; }

form#form-product #id_name, form#form-product #id_price, form#form-variant #id_sku, form#form-variant #id_price_override, form#form-stock #id_quantity, form#form-attributes #id_display, form#form-category #id_name, form#form-sales #id_name, form#form-vouchers #id_code {
  font-size: 2.2rem; }

form#form-attributes table .input-field, form#form-attributes table p {
  margin: 0;
  padding: 0; }

form#form-attributes table label {
  font-size: 0;
  vertical-align: bottom; }

form .sizedimage-mod {
  margin-bottom: 0.75rem; }
  form .sizedimage-mod ~ label {
    display: none; }

form .file-field label {
  display: none; }

form .btn--inline {
  display: inline-block;
  margin-top: 1.4rem; }

.list {
  border: none;
  overflow: visible; }
  .list .list-item.avatar {
    border: none;
    padding-left: 59px;
    padding-right: 0;
    padding-bottom: 3px;
    min-height: 0; }
    @media (max-width: 600px) {
      .list .list-item.avatar {
        margin-right: -0.75rem; } }
    .list .list-item.avatar .circle {
      left: 0; }
    .list .list-item.avatar-delete {
      background: white;
      font-size: 18px; }
      @media (min-width: 993px) {
        .list .list-item.avatar-delete {
          padding-left: 50px;
          display: none; } }
    @media (min-width: 993px) {
      .list .list-item.avatar:hover .product-list-item-delete {
        display: block; } }
  .list .list-item--two-lines {
    border: none;
    padding: 0; }
  .list-item {
    position: relative; }
    .list-item-name {
      display: block;
      overflow: hidden;
      padding-right: 20px;
      text-overflow: ellipsis;
      white-space: nowrap; }
      .list-item-name--single {
        margin-bottom: 10px; }
    .list-item-price, .list-item-desc, .list-item-name--single {
      border-bottom: 1px solid #e0e0e0;
      padding-bottom: 12px; }
    .list-item-desc {
      color: #9e9e9e;
      margin: 0 0 12px;
      overflow: hidden;
      text-overflow: ellipsis;
      white-space: nowrap; }
    .list-item-prefix {
      color: initial; }
    .list-item-author {
      color: #9e9e9e; }
    .list-item-icon {
      opacity: .6;
      position: absolute;
      right: 0;
      top: 0; }
    .list-item--spaced {
      margin-bottom: 5px; }
  .list--attributes .list--attributes-item {
    padding-left: 0; }
  .card .list {
    margin-bottom: 0; }
    .card .list-item:last-child .list-item-name {
      border-bottom: none;
      padding-bottom: 0; }

.product-gallery .product-gallery-item {
  margin: 0 0.75rem 1.5rem !important;
  padding: 0;
  display: block;
  position: relative;
  width: calc(50% - 2.25rem) !important; }
  @media (min-width: 601px) {
    .product-gallery .product-gallery-item {
      width: calc(33.3% - 1.5rem) !important; } }
  @media (min-width: 993px) {
    .product-gallery .product-gallery-item {
      width: calc(20% - 1.5rem) !important; } }
  .product-gallery .product-gallery-item-reorder {
    position: absolute; }
  .product-gallery .product-gallery-item-image img {
    cursor: move; }
  .product-gallery .product-gallery-item-image--ghost {
    background: #fafafa;
    padding: 64px 0 63px;
    text-align: center; }
  .product-gallery .product-gallery-item-title, .product-gallery .product-gallery-item-desc {
    display: block;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap; }
    .product-gallery .product-gallery-item-title--noclip, .product-gallery .product-gallery-item-desc--noclip {
      padding: 104px 0 103px;
      text-align: center;
      white-space: normal; }
  .product-gallery .product-gallery-item-text {
    background: rgba(0, 0, 0, 0.5);
    bottom: 0;
    color: white;
    height: 48px;
    line-height: 48px;
    left: 0;
    overflow: hidden;
    padding: 0 calc(0.75rem + 48px) 0 0.75rem;
    position: absolute;
    right: 0;
    text-align: left;
    text-overflow: ellipsis;
    white-space: nowrap; }

.product-gallery .sortable-ghost {
  opacity: .4; }

.point-stage div.ppoi-point {
  background-color: #f3989b;
  background-color: rgba(243, 152, 155, 0.5);
  border-radius: 50%;
  box-shadow: 0 0 5px 0 rgba(0, 0, 0, 0.5);
  height: 50px;
  width: 50px; }

.select2-container {
  margin-bottom: 15px; }
  .select2-container--default .select2-selection--multiple, .select2-container--default.select2-container--focus .select2-selection--multiple {
    background: transparent;
    border: none;
    border-bottom: 1px solid #9e9e9e;
    border-radius: 0;
    line-height: calc(3rem - 1px); }
    .select2-container--default .select2-selection--multiple .select2-selection__rendered, .select2-container--default.select2-container--focus .select2-selection--multiple .select2-selection__rendered {
      padding: 0;
      vertical-align: middle; }
    .select2-container--default .select2-selection--multiple .select2-selection__choice, .select2-container--default.select2-container--focus .select2-selection--multiple .select2-selection__choice {
      background-color: #BBDEFB;
      border-color: #90CAF9;
      border-radius: 2px;
      line-height: 1.5;
      margin-top: 10px; }
      .select2-container--default .select2-selection--multiple .select2-selection__choice__remove, .select2-container--default.select2-container--focus .select2-selection--multiple .select2-selection__choice__remove {
        font-size: 0; }
        .select2-container--default .select2-selection--multiple .select2-selection__choice__remove:before, .select2-container--default.select2-container--focus .select2-selection--multiple .select2-selection__choice__remove:before {
          display: inline-block;
          font-family: "Material-Design-Icons";
          font-size: 12px; }
  .select2-container--default .select2-search--inline .select2-search__field, .select2-container--default.select2-container--focus .select2-search--inline .select2-search__field {
    background: transparent;
    height: auto;
    margin: 0;
    padding-left: 0; }
    .select2-container--default .select2-search--inline .select2-search__field:focus, .select2-container--default.select2-container--focus .select2-search--inline .select2-search__field:focus {
      border-bottom: none;
      box-shadow: none; }
  .select2-container--default.select2-container--open .select2-selection__rendered {
    background-color: white; }
  .select2-container .select2-dropdown {
    border: none; }

.tabs li a span {
  display: none; }
  @media (min-width: 601px) {
    .tabs li a span {
      display: inline; } }

.tabs li a i {
  font-size: 24px; }
  @media (min-width: 601px) {
    .tabs li a i {
      display: none; } }

.toast {
  height: auto;
  line-height: inherit;
  padding-top: 12px;
  padding-bottom: 11px; }
  .toast--fixed {
    bottom: 0;
    display: inline-block;
    float: none;
    left: 50%;
    min-width: 300px;
    top: auto;
    -webkit-transform: translateX(-50%);
            transform: translateX(-50%);
    z-index: 9999; }
    .js .toast--fixed {
      position: fixed;
      -webkit-transition: -webkit-transform 0.2s;
      transition: -webkit-transform 0.2s;
      transition: transform 0.2s;
      transition: transform 0.2s, -webkit-transform 0.2s; }
  .js .toast--hidden {
    -webkit-transform: translate(-50%, 100%);
            transform: translate(-50%, 100%); }
/*# sourceMappingURL=dashboard.css.map */